package com.unis.ynls.irpt.client;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.EconomicVO;
import com.unis.ynls.irpt.common.VO.SafetyQueryVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "irpt-server")
@Component
@Api(value = "粮油产业管理子系统", tags = "粮油产业管理子系统")
public interface EconomicFeign {

    @ApiOperation(value = "粮油产业经济统计年报", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/economic/findStatistics")
    public ResponseWrapper findStatistics(@RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestBody EconomicVO vo);


    @ApiOperation(value = "粮油加工转化企业季报", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/economic/findQuarterlyReport")
    public ResponseWrapper findQuarterlyReport(@RequestParam("pageNum") Integer pageNum,
                                                          @RequestParam("pageSize") Integer pageSize,
                                                          @RequestBody EconomicVO vo);


    @ApiOperation(value = "粮油加工转化企业年度表", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/economic/findndChart")
    public ResponseWrapper findndChart(@RequestParam("pageNum") Integer pageNum,
                                                  @RequestParam("pageSize") Integer pageSize,
                                                  @RequestBody EconomicVO vo);


    @ApiOperation(value = "粮油科技基本情况年报", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/economic/findScienceBasic")
    public ResponseWrapper findScienceBasic(@RequestParam("pageNum") Integer pageNum,
                                                       @RequestParam("pageSize") Integer pageSize,
                                                       @RequestBody EconomicVO vo);


    @ApiOperation(value = "年度查询", notes = "参数：zt 1是统计年报2是转化季报3是转化年报4是基本情况年报")
    @PostMapping(value = "/economic/findYearByZt")
    public ResponseWrapper findYearByZt(@RequestParam("zt")Integer zt);


    @ApiOperation(value = "工业总产值TOP5", notes = "参数：开始时间,结束时间")
    @PostMapping(value = "/economic/findProduction")
    public ResponseWrapper findProduction(@RequestBody SafetyQueryVO vo);
}
