package com.unis.ynls.irpt.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.reservereport.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

@FeignClient(name = "irpt-server")
@Component
@Api(value = "财务报表-进销存报表、补贴", tags = "财务报表-进销存报表、补贴")
public interface ReserveReportFeign {

    @ApiOperation(value = "储备粮油进销存报表-填报接口", notes = "参数：PurchaseStockVO")
    @PostMapping(value = "/reserve-report/purchase-stock/save")
    public ResponseWrapper savePurchaseStock(@RequestBody PurchaseStockVO vo);

    @ApiOperation(value = "储备粮油进销存报表-获取填报期数", notes = "参数：PurchaseStockQueryVO")
    @PostMapping(value = "/reserve-report/purchase-stock/getPeriod")
    public ResponseWrapper getPeriod(@RequestBody PurchaseStockQueryVO queryVO);

    @ApiOperation(value = "储备粮油进销存报表-修改||盖章||接收||撤销 接口", notes = "notes = 参数：type:1:修改 2:盖章 3:接收 4:撤销")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 1,修改 2盖章 3接收 4撤销", required = true, dataType = "Integer")
    })
    @PutMapping(value = "/reserve-report/purchase-stock/update/{type}")
    public ResponseWrapper updatePurchaseStock(@PathVariable("type")Integer type,@RequestBody PurchaseStockVO vo);

    //储备粮油进销存报表-分页列表查询
    @ApiOperation(value = "储备粮油进销存报表-分页列表查询【企业端】", notes = "参数：PurchaseStockQueryVO")
    @PostMapping(value = "/reserve-report/purchase-stock/page/{pageNum}/{pageSize}")
    public ResponseWrapper getPurchaseStockPageList(@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize")Integer pageSize,@RequestBody PurchaseStockQueryVO queryVO);

    @ApiOperation(value = "储备粮油进销存报表-列表查询【管理端】", notes = "参数：PurchaseStockQueryVO")
    @PostMapping(value = "/reserve-report/purchase-stock/list/{pageNum}/{pageSize}")
    public ResponseWrapper getPurchaseStockList(@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize")Integer pageSize,@RequestBody PurchaseStockQueryVO queryVO);

    //储备粮油进销存报表-分页列表查询
    @ApiOperation(value = "储备粮油进销存报表-根据ID查看详情", notes = "参数：psId")
    @GetMapping(value = "/reserve-report/purchase-stock/info/{psId}")
    public ResponseWrapper getPurchaseStockInfo(@PathVariable("psId")String psId);

    //储备粮油进销存报表-获取上期期末库存接口
    @ApiOperation(value = "储备粮油进销存报表-获取上期期末库存接口")
    @PostMapping(value = "/reserve-report/purchase-stock/getPreviousStock")
    public ResponseWrapper getPreviousStock(@RequestBody PurchaseStockQueryVO queryVO);


    @ApiOperation(value = "储备粮油进销存汇总报表-生成汇总数据接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "period", value = "汇总期数", dataType = "String"),
            @ApiImplicitParam(name = "dataType", value = "数据类型 0:市级储备粮油 1:市级粮食调节储备 2:异地存储市级粮食调节储备", dataType = "Integer")
    })
    @GetMapping(value = "reserve-report/purchase-stock/summary/generate/{dataType}")
    public ResponseWrapper generatePurchaseStockSummary(@PathVariable("dataType")Integer dataType);

    @ApiOperation(value = "储备粮油进销存汇总报表-填报接口", notes = "参数：PurchaseStockSummaryVO")
    @PostMapping(value = "/reserve-report/purchase-stock/summary/save")
    public ResponseWrapper savePurchaseStockSummary(@RequestBody PurchaseStockSummaryVO summaryVO);

    @ApiOperation(value = "储备粮油进销存汇总报表-复核接口", notes = "参数：PurchaseStockSummaryVO")
    @PostMapping(value = "/reserve-report/purchase-stock/summary/update")
    public ResponseWrapper updatePurchaseStockSummary(@RequestBody PurchaseStockSummaryVO summaryVO);

    //储备粮油进销存汇总报表-分页列表查询接口
    @ApiOperation(value = "储备粮油进销存汇总报表-分页列表查询接口", notes = "参数：queryVO")
    @PostMapping(value = "/reserve-report/purchase-stock/summary/page/{pageNum}/{pageSize}")
    public ResponseWrapper getPurchaseStockSummaryPageList(@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize")Integer pageSize,@RequestBody PurchaseStockQueryVO queryVO);
    //储备粮油进销存汇总报表-数据详情查看接口
    @ApiOperation(value = "储备粮油进销存汇总报表-数据详情查看接口", notes = "参数：queryVO")
    @PostMapping(value = "/reserve-report/purchase-stock/summary/info")
    public ResponseWrapper getPurchaseStockSummaryInfo(@RequestBody PurchaseStockQueryVO queryVO);

    //储备粮油进销存汇总报表-删除接口
    @ApiOperation(value = "储备粮油进销存汇总报表-删除接口")
    @DeleteMapping(value = "/reserve-report/purchase-stock/summary/delete/{id}")
    public ResponseWrapper deletePurchaseStockSummary(@PathVariable("id")String id);

    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-获取填报期数", notes = "参数：StorageSubsidyQueryVO")
    @PostMapping(value = "/reserve-report/storage-subsidy/getPeriod")
    public ResponseWrapper getStorageSubsidyPeriod(@RequestBody StorageSubsidyQueryVO queryVO);

    //市级储备粮油储存费用补贴申请表-保存接口
    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-保存接口")
    @PostMapping(value = "/reserve-report/storage-subsidy/save")
    public ResponseWrapper saveStorageSubsidy(@RequestBody StorageSubsidyVO vo);

    //市级储备粮油储存费用补贴申请表-修改||盖章||接收 接口
    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-修改||盖章||接收||撤销 接口",notes = "参数：type:1:修改 2:盖章 3:接收 4:撤销")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 1修改 2盖章 3接收 4撤销", required = true, dataType = "Integer")
    })
    @PutMapping(value = "/reserve-report/storage-subsidy/update/{type}")
    public ResponseWrapper updateStorageSubsidy(@PathVariable("type")Integer type,@RequestBody StorageSubsidyVO vo);

    //市级储备粮油储存费用补贴申请表-列表分页查询接口
    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-列表分页查询接口")
    @PostMapping(value = "/reserve-report/storage-subsidy/page/{pageNum}/{pageSize}")
    public ResponseWrapper getStorageSubsidyPageList(@PathVariable("pageNum")Integer pageNum,
                                                     @PathVariable("pageSize")Integer pageSize,
                                                     @RequestBody StorageSubsidyQueryVO queryVO);

    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-列表查询接口【管理端】")
    @PostMapping(value = "/reserve-report/storage-subsidy/list/{pageNum}/{pageSize}")
    public ResponseWrapper getStorageSubsidyList(@PathVariable("pageNum")Integer pageNum,
                                                 @PathVariable("pageSize")Integer pageSize,
                                                 @RequestBody StorageSubsidyQueryVO queryVO);

    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-根据申请表ID获取详情接口")
    @GetMapping(value = "/reserve-report/storage-subsidy/info/{ssId}")
    public ResponseWrapper getStorageSubsidyInfo(@PathVariable("ssId")String ssId);

    @ApiOperation(value = "拨付市级储备粮油储存费用-生成汇总数据接口【管理端】")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "period", value = "上报期数 yyyy年MM月", dataType = "String"),
            @ApiImplicitParam(name = "dataType", value = "数据类型 0:市级储备粮油 1:市级粮食调节储备 2:异地存储市级粮食调节储备", dataType = "Integer")
    })
    @GetMapping(value = "/reserve-report/storage-subsidy/summary/generate")
    public ResponseWrapper generateStorageSubsidySummary(@RequestParam("dataType") Integer dataType);

    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据保存接口")
    @PostMapping(value = "/reserve-report/storage-subsidy/summary/save")
    public ResponseWrapper saveStorageSubsidySummary(@RequestBody StorageSubsidySummaryVO storageSubsidySummaryVO);

    //拨付市级储备粮油储存费用-修改接口
    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据 制表||复核||财务领导批示||单位负责人批示 接口 接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 1,制表,修改 2复核 3财务领导批示 4单位负责人批示过", required = true, dataType = "Integer")
    })
    @PutMapping(value = "/reserve-report/storage-subsidy/summary/update/{type}")
    public ResponseWrapper updateStorageSubsidySummary(@PathVariable("type") Integer type,@RequestBody StorageSubsidySummaryVO storageSubsidySummaryVO);

    //拨付市级储备粮油储存费用-列表分页查询
    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据列表分页查询")
    @PostMapping(value = "/reserve-report/storage-subsidy/summary/page/{pageNum}/{pageSize}")
    public ResponseWrapper getStorageSubsidySummaryPageList(@PathVariable("pageNum")Integer pageNum,
                                                            @PathVariable("pageSize")Integer pageSize,
                                                            @RequestBody StorageSubsidySummaryQueryVO queryVO);

    //拨付市级储备粮油储存费用-汇总数据详情查看
    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据详情查看")
    @GetMapping(value = "/reserve-report/storage-subsidy/summary/info/{id}")
    public ResponseWrapper getStorageSubsidySummaryInfo(@PathVariable("id") String id);

    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据删除")
    @DeleteMapping(value = "/reserve-report/storage-subsidy/summary/delete/{id}")
    public ResponseWrapper deleteStorageSubsidySummary(@PathVariable("id") String id);

}
