package com.unis.ynls.irpt.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.RotateProtocolVO;
import com.unis.ynls.irpt.common.VO.rotationreport.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@FeignClient(name = "irpt-server")
@Component
@Api(value = "财务报表-包干轮换补贴", tags = "财务报表-包干轮换补贴")
public interface RotationReportFeign {

    //市级储备粮油轮换费率配置-新增接口
    @ApiOperation(value = "市级储备粮油轮换费率配置-新增接口", notes = "参数：RotationSubsidyRateVO")
    @PostMapping(value = "/rotation-report/subsidy-rate/save")
    public ResponseWrapper saveRotationSubsidyRate(@RequestBody RotationSubsidyRateVO vo) ;

    //市级储备粮油轮换补贴-列表查询接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-列表查询接口【管理端】")
    @GetMapping(value = "/rotation-report/subsidy/list/{pageNum}/{pageSize}")
    public ResponseWrapper getRotationSubsidyList(@PathVariable("pageNum")Integer pageNum,
                                                  @PathVariable("pageSize")Integer pageSize,
                                                  @RequestBody RotationSubsidyQueryVO queryVO);

    //市级储备粮油轮换补贴-轮换粮食查询接口【企业端】
    @ApiOperation(value = "市级储备粮油轮换补贴-轮换粮食查询接口【企业端】",notes = "ccqybm,pzbm")
    @GetMapping(value = "/rotation-report/subsidy/grainInfo/{ccqybm}/{pzbm}")
    public ResponseWrapper getRotationGrain(@PathVariable("ccqybm") String ccqybm,
                                            @PathVariable("pzbm")String pzbm);

    //市级储备粮油轮换费率配置-新增接口
    @ApiOperation(value = "市级储备粮油轮换费率配置-根据品种编码获取有效的费率", notes = "参数：pzbm")
    @GetMapping(value = "/rotation-report/subsidy-rate/enabled/{pzbm}/{typeCode}")
    public ResponseWrapper getEnabledByPzbm(@PathVariable("pzbm")String pzbm,@PathVariable("typeCode") String typeCode) ;

    //市级储备粮油轮换费率配置-列表接口
    @ApiOperation(value = "市级储备粮油轮换费率配置-列表接口", notes = "")
    @GetMapping(value = "/rotation-report/subsidy-rate/list")
    public ResponseWrapper getRotationSubsidyRateList() ;

    //市级储备粮油轮换补贴-新增（填报）接口
    @ApiOperation(value = "市级储备粮油轮换补贴申请-新增（填报）接口", notes = "参数：type,RotationSubsidyVO")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算填报，liquidate-修改法规")
    @PostMapping(value = "/rotation-report/subsidy/{type}/save")
    public ResponseWrapper saveRotationSubsidy(@PathVariable("type") String type,
                                               @RequestBody RotationSubsidyVO vo) ;

    //市级储备粮油轮换补贴-修改||盖章||接收 接口
    @ApiOperation(value = "市级储备粮油轮换补贴-修改||盖章||接收||撤销 接口", notes = "参数：type,RotationSubsidyVO")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算填报，liquidate-修改法规")
    @PutMapping(value = "/rotation-report/subsidy/{type}/update")
    public ResponseWrapper updateRotationSubsidy(@PathVariable("type") String type,
                                                 @RequestBody RotationSubsidyVO vo);

    //市级储备粮油轮换补贴-列表分页查询 接口
    @ApiOperation(value = "市级储备粮油轮换补贴-列表分页查询 接口【企业端】", notes = "参数：pageNum,pageSize,RotationSubsidyQueryVO")
    @PostMapping(value = "/rotation-report/subsidy/list/{pageNum}/{pageSize}")
    public ResponseWrapper getRotationSubsidyPageList(@PathVariable("pageNum") Integer pageNum,
                                                      @PathVariable("pageSize") Integer pageSize,
                                                      @RequestBody RotationSubsidyQueryVO queryVO);

    //市级储备粮油轮换补贴-根据RotationSubsidyId详情查询接口
    @ApiOperation(value = "市级储备粮油轮换补贴-根据RotationSubsidyId详情查询接口",notes = "参数：RotationSubsidyId")
    @GetMapping(value = "/rotation-report/subsidy/info/{rsId}")
    public ResponseWrapper getRotationSubsidyInfo(@PathVariable("rsId") String rsId);

    //市级储备粮油轮换补贴-生成审批表-申报单位列表接【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-生成审批表-申报单位列表【管理端】",notes = "参数：type")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算，liquidate-修改")
    @GetMapping(value = "/rotation-report/subsidy/approval/{type}/list")
    public ResponseWrapper getRotationSubsidyApprovalList(@PathVariable("type") String type);

    //市级储备粮油轮换补贴-生成审批表-根据选择的申报单位列表生成汇总表数据【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-生成审批表-根据选择的申报单位列表生成汇总表数据【管理端】")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算，liquidate-修改")
    @PostMapping(value = "/rotation-report/subsidy/summary/{type}/init")
    public ResponseWrapper initRotationSubsidySummary(@PathVariable("type") String type,@RequestBody List<String> rotationSubsidyIds);

    //市级储备粮油轮换补贴-生成审批表-汇总数据保存接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-生成审批表-汇总数据保存接口【管理端】",notes = "参数：type")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算，liquidate-清算")
    @PostMapping(value = "/rotation-report/subsidy/summary/{type}/save")
    public ResponseWrapper saveRotationSubsidySummary(@PathVariable("type") String type,@RequestBody RotationSubsidySummaryVO summaryVO) ;

    //市级储备粮油轮换补贴-汇总数据 修改||复核||财务批示||领导审核 接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-汇总数据 修改||复核||财务批示||领导审核 接口【管理端】")
    @PutMapping(value = "/rotation-report/subsidy/summary/update/{type}")
    public ResponseWrapper updateRotationSubsidySummary(@PathVariable("type") Integer type,@RequestBody RotationSubsidySummaryVO summaryVO);

    //市级储备粮油轮换补贴-包干轮换补贴审批-列表接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-包干轮换补贴审批-列表接口【管理端】")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算，liquidate-清算")
    @PostMapping(value = "/rotation-report/subsidy/summary/list/{pageNum}/{pageSize}")
    public ResponseWrapper getRotationSubsidySummaryPageList(@PathVariable("pageNum")Integer pageNum,
                                                         @PathVariable("pageSize")Integer pageSize,
                                                         @RequestBody RotationSubsidySummaryQueryVO queryVO) ;

    //市级储备粮油轮换补贴-包干轮换补贴审批-详情查看接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-包干轮换补贴审批-详情查看接口【管理端】")
    @GetMapping(value = "/rotation-report/subsidy/summary/info/{id}")
    public ResponseWrapper getRotationSubsidySummaryInfo(@PathVariable("id")String id);

    @ApiOperation(value = "市级储备粮油轮换补贴-包干轮换补贴审批-删除接口【管理端】")
    @DeleteMapping(value = "/rotation-report/subsidy/summary/delete/{id}")
    public ResponseWrapper deleteRotationSubsidySummary(@PathVariable("id")String id);

    @ApiOperation(value = "市级储备粮油轮换补贴-包干轮换补贴审批-删除接口【管理端】")
    @GetMapping(value = "/rotation-report/subsidy/Protocol/{ccqybm}")
    ResponseWrapper getRotationProtocol(@PathVariable("ccqybm") String ccqybm);

    @ApiOperation(value = "市级储备粮油轮换补贴-包干轮换补贴审批-删除接口【管理端】")
    @PostMapping(value = "/rotation-report//subsidy/ProtocolDetail")
    ResponseWrapper getRotationProtocolDetail(@RequestBody RotateProtocolVO rotateProtocolVO);
}
