package com.unis.ynls.irpt.client;

import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.BaseFilterVO;
import com.unis.ynls.irpt.common.VO.task.CompanyRptFilterVO;
import com.unis.ynls.irpt.common.VO.task.ReportInfoVO;
import com.unis.ynls.irpt.common.VO.task.RptListFilterVO;
import com.unis.ynls.irpt.common.VO.task.RptListVO;
import com.unis.ynls.irpt.common.VO.task.TaskFilterVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@FeignClient(name = "irpt-server")
@Component
public interface TaskInfoFeign {
	
    @PostMapping(value = "/task/queryReportByConditions")
    public ResponseWrapper queryReportByConditions(@RequestBody TaskFilterVO taskFilterVO);
   
    /**
     * 查询指定条件报表已上报信息
     * @param taskFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2018-12-27 14:46:58
     * @version v1.0
     */
    @PostMapping(value = "/task/queryReportInfoByConditions")
    public ResponseWrapper queryReportInfoByConditions(@RequestBody TaskFilterVO taskFilterVO);
  
    /**
     * 查询指定条件下企业是否上报
     * @param companyRptFilterVO 参数：报表真实代码，报表期，企业统一社会信用代码
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-02-18 17:24:28
     * @version v1.0
     */
    @PostMapping( value = "/task/queryCompanyWhetherReport")
    public ResponseWrapper queryCompanyWhetherReport(@RequestBody CompanyRptFilterVO companyRptFilterVO);
    
    /**
     * 获取指定报表新增报表期
     * @param taskId
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-01-25 15:42:28
     * @version v1.0
     */
    @GetMapping(value = "/task/queryReportBbqByTaskId/{taskId}/{unitCode}")
    public ResponseWrapper queryReportBbqByTaskId(@PathVariable("taskId") String taskId,@PathVariable("unitCode") String unitCode);

    /**
     * 指定机构指定报表上报信息
     * @param rptListFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-03-30 14:39:44
     * @version v1.0
     */
    @ApiOperation(value = "指定机构指定报表上报信息", notes = "参数：报表真实代码,机构代码")
    @PostMapping(value = "/task/findAllRptInfo")
    public ResponseWrapper findAllRptInfo(@RequestBody RptListFilterVO rptListFilterVO);
 

    /**
     * 指定机构指定报表上报信息---上集集团
     * @param rptListFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-03-30 14:39:44
     * @version v1.0
     */
    @ApiOperation(value = "指定机构指定报表上报信息---上集集团", notes = "参数：报表真实代码,机构代码")
    @PostMapping(value = "/task/findAllRptInfoShangJiJiTuan")
    public ResponseWrapper findAllRptInfoShangJiJiTuan(@RequestBody RptListFilterVO rptListFilterVO);
  




    /**
     * 指定报表指定报表期上报信息
     * @param rptListFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-04-30 14:45:33
     * @version v1.0
     */
    @ApiOperation(value = "指定报表指定报表期上报信息", notes = "参数：报表真实代码,报表期、用户账号")
    @PostMapping(value = "/task/findRptInfoByBbqAndRptId")
    public ResponseWrapper findRptInfoByBbqAndRptId(@RequestBody RptListFilterVO rptListFilterVO);
     
    /**
     * 根据报表期、报表真实代码、机构代码查询对应报表填报或办理链接
     * @param baseFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-05-07 13:46:36
     * @version v1.0
     */
    @ApiOperation(value = "根据基本条件查询对应报表填报或办理链接", notes = "参数：报表真实代码,报表期、机构代码")
    @PostMapping(value = "/task/findUrlByCondition")
    public ResponseWrapper findUrlByCondition(@RequestBody BaseFilterVO baseFilterVO,@RequestParam("pwd")String pwd);
      
}
