package com.unis.ynls.irpt.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.EconomicVO;
import com.unis.ynls.irpt.common.VO.Report.*;
import com.unis.ynls.irpt.server.service.DividedByYearService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/divided")
@Slf4j
@Api(value = "调节与非调节分项与汇总统计表", tags = "调节与非调节分项与汇总统计表")
public class DividedByYearController {
    @Autowired
    private DividedByYearService dividedByYearService;

    @ApiOperation(value = "非调节报表分项分页接口")
    @PostMapping(value = "/findFeiStatistics")
    public ResponseWrapper getFeiDetails(@RequestParam("hzqs") String hzqs) {
        try {
            List<DividedByYearVO> list=  dividedByYearService.getFeiDetails(hzqs);
            return ResponseWrapper.success(200, "查询成功",list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "调节报表分项分页接口")
    @PostMapping(value = "/findStatistics")
    public ResponseWrapper getDetails(@RequestParam("hzqs") String hzqs) {
        try {
            List<DividedByYearVO> list=  dividedByYearService.getDetails(hzqs);
            return ResponseWrapper.success(200, "查询成功",list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "非调节报表汇总分页接口")
    @PostMapping(value = "/findAllStatistics")
    public ResponseWrapper getAllDetails(@RequestParam("hzqs") String hzqs) {
        try {
            List<DividedAllVO> list=  dividedByYearService.getAllDetails(hzqs);
            return ResponseWrapper.success(200, "查询成功",list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "总合计接口")
    @PostMapping(value = "/findAll")
    public ResponseWrapper getAll(@RequestParam("hzqs") String hzqs) {
        try {
            List<DividedAllVO> list=  dividedByYearService.getAll(hzqs);
            return ResponseWrapper.success(200, "查询成功",list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }
    @ApiOperation(value = "查看带小品类详情接口")
    @PostMapping(value = "/seeAll")
    public ResponseWrapper seeAll(@RequestParam("hzqs") String hzqs) {
        try {
           DivideCountVO divideCountVO=  dividedByYearService.seeAll(hzqs);
            return ResponseWrapper.success(200, "查询成功",divideCountVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "查看合计详情接口")
    @PostMapping(value = "/seeCAll")
    public ResponseWrapper seeCAll(@RequestParam("hzqs") String hzqs) {
        try {
            DivideCountAllVO divideCountVO=  dividedByYearService.seeCAll(hzqs);
            return ResponseWrapper.success(200, "查询成功",divideCountVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "调节报表汇总分页接口")
    @PostMapping(value = "/findTiaoAllStatistics")
    public ResponseWrapper getTiaoAllDetails(@RequestParam("hzqs") String hzqs) {
        try {
            List<DividedAllVO> list=  dividedByYearService.getTiaoAllDetails(hzqs);
            return ResponseWrapper.success(200, "查询成功",list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }
}
