package com.unis.ynls.irpt.server.controller;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.Report.DividedVO;
import com.unis.ynls.irpt.common.VO.reservereport.DivideSelectVO;
import com.unis.ynls.irpt.server.service.DividedByYearService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/summary")
@Slf4j
@Api(value = "按生产年份划分库存报表", tags = "按生产年份划分库存报表")
public class DividedController {
    @Autowired
    private DividedByYearService dividedByYearService;
    @ApiOperation(value = "查询生产年份划分库存报表")
    @PostMapping(value = "/feiDivideDetails")
    public ResponseWrapper getFeiDivideDetails(@RequestBody DivideSelectVO divideSelectVO) {
        try {
           List<DividedVO> dividedVOList =  dividedByYearService.getFeiDivideDetails(divideSelectVO);
            return ResponseWrapper.success(200, "查询成功",dividedVOList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "生成按生产年份划分库存报表")
    @PostMapping(value = "/createDetails")
    public ResponseWrapper createDetails(@RequestParam("hzqs") String hzqs) {
        try {
            DividedVO dividedVO= dividedByYearService.createDetails(hzqs);
            return ResponseWrapper.success(200, "汇总成功",dividedVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "保存按生产年份划分库存报表")
    @PostMapping(value = "/setDetails")
    public ResponseWrapper setDetails(@RequestBody DividedVO dividedVO) {
        try {
            dividedByYearService.setDetails(dividedVO);
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "删除按生产年份划分库存报表")
    @PostMapping(value = "/delDivideDetails")
    public ResponseWrapper delFeiDivideDetails(@RequestParam("hzqs") String hzqs) {
        try {
             dividedByYearService.delFeiDivideDetails(hzqs);
            return ResponseWrapper.success(200, "删除成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除按生产年份汇总统计表失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }
}
