package com.unis.ynls.irpt.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.EconomicVO;
import com.unis.ynls.irpt.common.VO.ProductionVO;
import com.unis.ynls.irpt.common.VO.QuarterVO;
import com.unis.ynls.irpt.common.VO.SafetyQueryVO;
import com.unis.ynls.irpt.server.service.EconomicService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * @Author ChenKai
 * @Date 2019/9/29 15:55
 * @Version 1.0
 */


@RestController
@RequestMapping("/economic")
@Slf4j
@Api(value = "粮油产业管理子系统", tags = "粮油产业管理子系统")
public class EconomicController {

    @Autowired
    private EconomicService economicService;

    @ApiOperation(value = "粮油产业经济统计年报", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/findStatistics")
    public ResponseWrapper findStatistics(@RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestBody EconomicVO vo) {
        try {
            PageInfo<List<EconomicVO>> list = economicService.findStatistics(pageNum,pageSize,vo);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询粮油产业经济统计年报失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }


    @ApiOperation(value = "粮油加工转化企业季报", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/findQuarterlyReport")
    public ResponseWrapper findQuarterlyReport(@RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @RequestBody EconomicVO vo) {
        try {
            PageInfo<List<EconomicVO>> list = economicService.findQuarterlyReport(pageNum,pageSize,vo);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("粮油加工转化企业季报：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }


    @ApiOperation(value = "粮油加工转化企业年度表", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/findndChart")
    public ResponseWrapper findndChart(@RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @RequestBody EconomicVO vo) {
        try {
            PageInfo<List<EconomicVO>> list = economicService.findndChart(pageNum,pageSize,vo);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("粮油加工转化企业年度表：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }


    @ApiOperation(value = "粮油科技基本情况年报", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/findScienceBasic")
    public ResponseWrapper findScienceBasic(@RequestParam("pageNum") Integer pageNum,
                                       @RequestParam("pageSize") Integer pageSize,
                                       @RequestBody EconomicVO vo) {
        try {
            PageInfo<List<EconomicVO>> list = economicService.findScienceBasic(pageNum,pageSize,vo);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("粮油科技基本情况年报：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }


    @ApiOperation(value = "年度查询", notes = "参数：zt 1是统计年报2是转化季报3是转化年报4是基本情况年报")
    @PostMapping(value = "/findYearByZt")
    public ResponseWrapper findYearByZt(@RequestParam("zt") Integer zt) {
        try {
            List<QuarterVO> list = economicService.findYearByZt(zt);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("年度：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }



    @ApiOperation(value = "工业总产值TOP5", notes = "参数：开始时间,结束时间")
    @PostMapping(value = "/findProduction")
    public ResponseWrapper findProduction(@RequestBody SafetyQueryVO vo) {
        try {
            List<ProductionVO> list = economicService.findProduction(vo);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("工业总产值TOP5：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }




}
