package com.unis.ynls.irpt.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.Report.EmergencyBranchReportVo;
import com.unis.ynls.irpt.common.VO.Report.EmergencyBranchReportsVo;
import com.unis.ynls.irpt.common.VO.Report.EmergencyDetailCopyVO;
import com.unis.ynls.irpt.common.VO.Report.EmergencyDetailVO;
import com.unis.ynls.irpt.server.scheduledtasks.EasyExcelUtil;
import com.unis.ynls.irpt.server.scheduledtasks.EasyExcelUtil2;
import com.unis.ynls.irpt.server.service.EmergencyBranchReportService;
import com.unis.ynls.irpt.server.service.EmergencyDetailService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import java.io.IOException;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Locale;

@RestController
@RequestMapping("/emergency")
@Slf4j
@Api(value = "粮食应急供应网点报表和粮食应急加工企业报表", tags = "粮食应急供应网点报表和粮食应急加工企业报表")
public class EmergencyBranchReportControllor {
    @Autowired
    private EmergencyBranchReportService emergencyBranchReportService;
    @Autowired
    private EmergencyDetailService emergencyDetailService;

    @ApiOperation(value = "粮食应急供应网点报表-excel上传接口")
    @PostMapping(value = "/uploadBranch")
    public ResponseWrapper setBranchDetail(MultipartFile file) {
        try {
            EasyExcelUtil.readExcel(file.getInputStream(), EmergencyBranchReportVo.class, emergencyBranchReportService);
        } catch (IOException o){
            log.error(o.getMessage());
        }
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy年MM月dd日", Locale.CHINA);
        LocalDate localDate = LocalDate.now();
        String newdate = localDate.format(formatter);
        return ResponseWrapper.success(200, "导入成功", newdate);
    }

    @ApiOperation(value = "粮食应急加工企业报表-excel上传接口")
    @PostMapping(value = "/uploadEmergency")
    public ResponseWrapper setEmergencyDetail(MultipartFile file) {
        try {
            EasyExcelUtil2.readAllExcel(file.getInputStream(), EmergencyDetailCopyVO.class, emergencyDetailService);
        } catch (IOException o){
            log.error(o.getMessage());
        }
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy年MM月dd日", Locale.CHINA);
        LocalDate localDate = LocalDate.now();
        String newdate = localDate.format(formatter);
        return ResponseWrapper.success(200, "导入成功", newdate);
    }

    @ApiOperation(value = "粮食应急供应网点报表-分页接口")
    @PostMapping(value = "/getBranch")
    public ResponseWrapper findDetail(@RequestParam("pageNum") Integer pageNum,
                                      @RequestParam("pageSize") Integer pageSize,
                                      @RequestParam(value = "location",required = false) String location
                                    ) {
        try {
            PageInfo<EmergencyBranchReportsVo> branchlist = emergencyBranchReportService.getDetail(pageNum, pageSize,location);
            return ResponseWrapper.success(200, "查询成功", branchlist);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("粮食应急供应网点报表：" + e.getMessage());
            return ResponseWrapper.error("您导入的文件错误!");
        }
    }

    @ApiOperation(value = "粮食应急加工企业报表-分页接口")
    @PostMapping(value = "/getEmergency")
    public ResponseWrapper findEmergencyDetail(@RequestParam("pageNum") Integer pageNum,
                                      @RequestParam("pageSize") Integer pageSize,
                                      @RequestParam(value = "location",required = false) String location
    ) {
        try {
            PageInfo<EmergencyDetailVO> branchlist = emergencyDetailService.getEmergencyDetail(pageNum, pageSize,location);
            return ResponseWrapper.success(200, "查询成功", branchlist);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("粮食应急供应网点报表：" + e.getMessage());
            return ResponseWrapper.error("您导入的文件错误!");
        }
    }
}
