package com.unis.ynls.irpt.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.reservereport.*;
import com.unis.ynls.irpt.server.service.ReserveReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/enterprise")
@Slf4j
@Api(value = "财务报表-承储企业报表顺序设置", tags = "财务报表-承储企业报表顺序设置")
public class EnterpriseController {

    @Autowired
    private ReserveReportService reserveReportService;


    @ApiOperation(value = "财务报表-承储企业报表顺序设置-添加库点接口")
    @PostMapping(value = "/save")
    public ResponseWrapper saveEnterprise(@RequestBody EnterpriseVO enterpriseVO) {
        try {
            //判断参数
            if(enterpriseVO == null || StringUtils.isEmpty(enterpriseVO.getCcqy()) || StringUtils.isEmpty(enterpriseVO.getCcqybm())
                    || enterpriseVO.getDetailList() == null || enterpriseVO.getDetailList().size() == 0){
                return ResponseWrapper.invalid();
            }
            if (reserveReportService.saveEnterprise(enterpriseVO) > 0)
                return ResponseWrapper.success();
            else
                return ResponseWrapper.error("添加失败！");
        } catch (Exception e) {
            log.error("ReserveReportController.saveEnterprise{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "财务报表-承储企业报表顺序设置-修改接口")
    @PutMapping(value = "/update")
    public ResponseWrapper updateEnterprise(@RequestBody EnterpriseVO enterpriseVO) {
        try {
            //判断参数
            if(enterpriseVO == null || StringUtils.isEmpty(enterpriseVO.getId())
                    || enterpriseVO.getDetailList() == null || enterpriseVO.getDetailList().size() == 0){
                return ResponseWrapper.invalid();
            }
            if (reserveReportService.updateEnterprise(enterpriseVO) > 0)
                return ResponseWrapper.success();
            else
                return ResponseWrapper.error("修改失败！");
        } catch (Exception e) {
            log.error("ReserveReportController.updateEnterprise{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "财务报表-承储企业报表顺序设置-列表查询接口")
    @PostMapping(value = "/list")
    public ResponseWrapper getEnterpriseList(@RequestBody EnterpriseQueryVO queryVO) {
        try {
            return ResponseWrapper.success(reserveReportService.getEnterpriseList(queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getEnterprisePageList{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "财务报表-承储企业报表顺序设置-分页查询接口")
    @PostMapping(value = "/page/{pageNum}/{pageSize}")
    public ResponseWrapper getEnterprisePage(@PathVariable("pageNum")Integer pageNum,
                                             @PathVariable("pageSize")Integer pageSize,
                                             @RequestBody EnterpriseQueryVO queryVO){
        try {
            return ResponseWrapper.success(reserveReportService.getEnterprisePage(pageNum,pageSize,queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getEnterprisePage{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }
    @ApiOperation(value = "财务报表-承储企业报表顺序设置-删除接口",notes = "参数：ccqybm承储企业编码")
    @DeleteMapping(value = "/delete/{ccqybm}")
    public ResponseWrapper deleteEnterprise(@PathVariable("ccqybm") String ccqybm) {
        try {
            if(reserveReportService.deleteEnterprise(ccqybm) > 0){
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("ReserveReportController.deleteEnterprise{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //财务报表-承储企业报表顺序设置-排序
    @ApiOperation(value = "财务报表-承储企业报表顺序设置-排序")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "enterpriseCode", value = "企业编码", dataType = "String"),
            @ApiImplicitParam(name = "startIndex", value = "起始位置", dataType = "Integer"),
            @ApiImplicitParam(name = "endIndex", value = "目标位置", dataType = "Integer")
    })
    @PostMapping(value = "/sort/{enterpriseCode}/{startIndex}/{endIndex}")
    public ResponseWrapper sortEnterprise(@PathVariable("enterpriseCode") String enterpriseCode, @PathVariable("startIndex") Integer startIndex,@PathVariable("endIndex") Integer endIndex) {
        try {
            if(reserveReportService.sortEnterprise(enterpriseCode, startIndex,endIndex)){
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("ReserveReportController.sortEnterprise{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }
}
