package com.unis.ynls.irpt.server.controller;

import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.FinanceReportQueryVO;
import com.unis.ynls.irpt.common.VO.FinanceReportVO;
import com.unis.ynls.irpt.common.VO.reservereport.PurchaseStockVO;
import com.unis.ynls.irpt.server.service.FinanceReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/finance-report")
@Slf4j
@Api(value = "粮库财务系统-财务报表", tags = "粮库财务系统-财务报表")
public class FinanceReportController {

    @Autowired
    private FinanceReportService financeReportService;

    @ApiOperation(value = "粮库财务系统-财务报表-保存接口", notes = "notes = 参数：type,FinanceReportVO")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 asset:资产负债 cash:现金流量 profit:利润", required = true, dataType = "String")
    })
    @PostMapping(value = "/{type}/save")
    public ResponseWrapper saveFinanceReport(@PathVariable("type")String type, @RequestBody FinanceReportVO vo) {
        try {
            //参数非空判断
            if(vo == null || StringUtils.isEmpty(vo.getBbsj()) || StringUtils.isEmpty(vo.getDwdm())
                    || StringUtils.isEmpty(vo.getKqdm()) || vo.getDetailList() == null || vo.getDetailList().size() == 0){
                return ResponseWrapper.invalid();
            }

            return financeReportService.saveFinanceReport(type,vo);
        } catch (Exception e) {
            log.error("FinanceReportController.saveFinanceReport{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
    }

    //粮库财务系统-财务报表-修改||提交接口
    @ApiOperation(value = "粮库财务系统-财务报表-修改||提交接口")
    @PostMapping(value = "/update")
    public ResponseWrapper updateFinanceReport(@RequestBody FinanceReportVO vo) {
        try {
            //参数预判断
            if(vo == null || StringUtils.isEmpty(vo.getId()) ){
                return ResponseWrapper.invalid();
            }
            return financeReportService.updateFinanceReport(vo);
        } catch (Exception e) {
            log.error("FinanceReportController.updateFinanceReport{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员！");
    }

    //粮库财务系统-财务报表-列表分页查询接口
    @ApiOperation(value = "现釶概册促销-列表分顶查询接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 asset:资产负债 cash:现金流量 profit:利润", required = true, dataType = "String")
    })
    @PostMapping(value = "/{type}/page/{pageNum}/{pageSize}")
    public ResponseWrapper getFinanceReportPageList(@PathVariable("type")String type,
                                                    @PathVariable("pageNum")Integer pageNum,
                                                    @PathVariable("pageSize")Integer pageSize,
                                                    @RequestBody FinanceReportQueryVO queryVO) {
        try {

            return ResponseWrapper.success(financeReportService.getFinanceReportPageList(type,pageNum,pageSize,queryVO));
        } catch (Exception e) {
            log.error("FinanceReportController.getFinanceReportPageList{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员！");
    }

    //粮库财务系统-财务报表-详情查询接口
    @ApiOperation(value = "粮库财务系统-财务报表-详情查询接口")
    @GetMapping(value = "/info/{id}")
    public ResponseWrapper getFinanceReportInfo(@PathVariable("id")String id) {
        try {
            return ResponseWrapper.success(financeReportService.getFinanceReportInfo(id));
        } catch (Exception e) {
            log.error("FinanceReportController.getFinanceReportInfo{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员！");
    }

    //粮库财务系统-财务报表-详情查询接口
    @ApiOperation(value = "粮库财务系统-财务报表-详情查询接口")
    @DeleteMapping(value = "/delete/{id}")
    public ResponseWrapper deleteFinanceReport(@PathVariable("id")String id) {
        try {
            if(financeReportService.deleteFinanceReport(id) > 0){
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("FinanceReportController.deleteFinanceReport{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员！");
    }

}
