package com.unis.ynls.irpt.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.EconomicVO;
import com.unis.ynls.irpt.server.service.HighGradeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author ChenKai
 * @Date 2019/9/30 14:24
 * @Version 1.0
 */


@RestController
@RequestMapping("/highGrade")
@Slf4j
@Api(value = "优质粮食工程", tags = "优质粮食工程")
public class HighGradeController {

    @Autowired
    private HighGradeService highGradeService;

    @ApiOperation(value = "优质粮食工程明细(盟市)", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/findDetail")
    public ResponseWrapper findDetail(@RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestBody EconomicVO vo) {
        try {
            PageInfo<List<EconomicVO>> list = highGradeService.findDetail(pageNum,pageSize,vo);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("优质粮食工程明细(盟市)：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }


    @ApiOperation(value = "优质粮食工程汇总(自治区)", notes = "参数：年度")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/findCollect")
    public ResponseWrapper findCollect(@RequestParam("pageNum") Integer pageNum,
                                      @RequestParam("pageSize") Integer pageSize,
                                      @RequestBody EconomicVO vo) {
        try {
            PageInfo<List<EconomicVO>> list = highGradeService.findCollect(pageNum,pageSize,vo);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("优质粮食工程汇总(自治区)：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }
}
