package com.unis.ynls.irpt.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.Report.*;
import com.unis.ynls.irpt.server.service.ReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 业务报表
 */
@RestController
@Slf4j
@Api(value = "业务报表列表",tags="业务报表列表")
public class ReportController {
    @Autowired
    private ReportService reportService;

    @ApiOperation(value = "条件分页查询地方储备粮收支平衡月报")
    @PostMapping(value = "/page/{pageNum}/{pageSize}")
    public ResponseWrapper page(@RequestBody LocalReservesReportQueryVO vo,
                                @PathVariable(value = "pageNum") Integer pageNum,
                                @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<LocalReservesReportVO> page = null;
        try {
            page = reportService.page(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }

    @ApiOperation(value = "条件分页查询损耗计算")
    @PostMapping(value = "/lossCalculationPage/{pageNum}/{pageSize}")
    public ResponseWrapper lossCalculationPage(@RequestBody LossCalculationQueryVO vo,
                                @PathVariable(value = "pageNum") Integer pageNum,
                                @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<LossCalculationVO> page = null;
        try {
            page = reportService.lossCalculationPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询地方储备粮收支平衡月报")
    @PostMapping(value = "/countryReservesReportPage/{pageNum}/{pageSize}")
    public ResponseWrapper countryReservesReportPage(@RequestBody CountryReservesReportQueryVO vo,
                                @PathVariable(value = "pageNum") Integer pageNum,
                                @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<CountryReservesReportVO> page = null;
        try {
            page = reportService.countryReservesReportPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询小麦购销外省市")
    @PostMapping(value = "/wheatProcurementPage/{pageNum}/{pageSize}")
    public ResponseWrapper wheatProcurementPage(@RequestBody WheatProcurementQueryVO vo,
                                                     @PathVariable(value = "pageNum") Integer pageNum,
                                                     @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<WheatProcurementVO> page = null;
        try {
            page = reportService.wheatProcurementPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市储粮轮换（实际库存）情况表")
    @PostMapping(value = "/grainRotationPage/{pageNum}/{pageSize}")         
    public ResponseWrapper grainRotationPage(@RequestBody GrainRotationQueryVO vo,
                                                     @PathVariable(value = "pageNum") Integer pageNum,
                                                     @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<GrainRotationVO> page = null;
        try {
            page = reportService.grainRotationPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市储粮实际库存分布表")
    @PostMapping(value = "/actualInventoryPage/{pageNum}/{pageSize}")
    public ResponseWrapper actualInventoryPage(@RequestBody ActualInventoryQueryVO vo,
                                             @PathVariable(value = "pageNum") Integer pageNum,
                                             @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<ActualInventoryVO> page = null;
        try {
            page = reportService.actualInventoryPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }

    @ApiOperation(value = "条件分页查询市储粮账面库存分布表")
    @PostMapping(value = "/bookInventoryPage/{pageNum}/{pageSize}")
    public ResponseWrapper bookInventoryPage(@RequestBody BookInventoryQueryVO vo,
                                               @PathVariable(value = "pageNum") Integer pageNum,
                                               @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<BookInventoryVO> page = null;
        try {
            page = reportService.bookInventoryPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市储备粮业务管理表（自动生成）")
    @PostMapping(value = "/grainReservePage/{pageNum}/{pageSize}")
    public ResponseWrapper grainReservePage(@RequestBody GrainReserveQueryVO vo,
                                             @PathVariable(value = "pageNum") Integer pageNum,
                                             @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<GrainReserveVO> page = null;
        try {
            page = reportService.grainReservePage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市储备油业务管理表（自动生成）")
    @PostMapping(value = "/oilReservePage/{pageNum}/{pageSize}")
    public ResponseWrapper oilReservePage(@RequestBody OilReserveQueryVO vo,
                                          @PathVariable(value = "pageNum") Integer pageNum,
                                          @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<OilReserveVO> page = null;
        try {
            page = reportService.oilReservePage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市储备粮油轮换情况季报表")
    @PostMapping(value = "/grainOilRotationPage/{pageNum}/{pageSize}")
    public ResponseWrapper grainOilRotationPage(@RequestBody GrainOilRotationQueryVO vo,
                                          @PathVariable(value = "pageNum") Integer pageNum,
                                          @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<GrainOilRotationVO> page = null;
        try {
            page = reportService.grainOilRotationPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询地方储备粮油进销存报表、补贴表")
    @PostMapping(value = "/localDrpPage/{pageNum}/{pageSize}")
    public ResponseWrapper localDrpPage(@RequestBody LocalDrpQueryVO vo,
                                                @PathVariable(value = "pageNum") Integer pageNum,
                                                @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<LocalDrpVO> page = null;
        try {
            page = reportService.localDrpPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询地方储备粮油进销存报表-总汇总")
    @PostMapping(value = "/localDrpCollectPage/{pageNum}/{pageSize}")
    public ResponseWrapper localDrpCollectPage(@RequestBody LocalDrpCollectQueryVO vo,
                                        @PathVariable(value = "pageNum") Integer pageNum,
                                        @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<LocalDrpCollectVO> page = null;
        try {
            page = reportService.localDrpCollectPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询补贴汇总表-储存费-各单位、每月补贴（汇总表）")
    @PostMapping(value = "/storageFeeSubsidyPage/{pageNum}/{pageSize}")
    public ResponseWrapper storageFeeSubsidyPage(@RequestBody StorageFeeSubsidyQueryVO vo,
                                               @PathVariable(value = "pageNum") Integer pageNum,
                                               @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<StorageFeeSubsidyVO> page = null;
        try {
            page = reportService.storageFeeSubsidyPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市级储备粮轮换补贴清算申请表")
    @PostMapping(value = "/applicationSubsidyPage/{pageNum}/{pageSize}")
    public ResponseWrapper applicationSubsidyPage(@RequestBody ApplicationSubsidyQueryVO vo,
                                                 @PathVariable(value = "pageNum") Integer pageNum,
                                                 @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<ApplicationSubsidyVO> page = null;
        try {
            page = reportService.applicationSubsidyPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市级储备粮库存数量检查抽包检斤法货位明细表")
    @PostMapping(value = "/smokePackageInspectionPage/{pageNum}/{pageSize}")
    public ResponseWrapper smokePackageInspectionPage(@RequestBody SmokePacageInspectionQueryVO vo,
                                                  @PathVariable(value = "pageNum") Integer pageNum,
                                                  @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<SmokePackageInspectionVO> page = null;
        try {
            page = reportService.smokePackageInspectionPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市储备粮业务管理表")
    @PostMapping(value = "/grainBusinessPage/{pageNum}/{pageSize}")
    public ResponseWrapper grainBusinessPage(@RequestBody GrainBusinessQueryVO vo,
                                                      @PathVariable(value = "pageNum") Integer pageNum,
                                                      @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<GrainBusinessVO> page = null;
        try {
            page = reportService.grainBusinessPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市储备油业务管理表")
    @PostMapping(value = "/oilBusinessPage/{pageNum}/{pageSize}")
    public ResponseWrapper oilBusinessPage(@RequestBody OilBusinessQueryVO vo,
                                             @PathVariable(value = "pageNum") Integer pageNum,
                                             @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<OilBusinessVO> page = null;
        try {
            page = reportService.oilBusinessPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询应急管理年报")
    @PostMapping(value = "/emergencyManagementPage/{pageNum}/{pageSize}")
    public ResponseWrapper emergencyManagementPage(@RequestBody EmergencyManagementQueryVO vo,
                                           @PathVariable(value = "pageNum") Integer pageNum,
                                           @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<EmergencyManagementVO> page = null;
        try {
            page = reportService.emergencyManagementPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市级储备粮库存数量检查测量计算法货位明细表")
    @PostMapping(value = "/smokePackageCountPage/{pageNum}/{pageSize}")
    public ResponseWrapper smokePackageCountPage(@RequestBody SmokePacageCountQueryVO vo,
                                                      @PathVariable(value = "pageNum") Integer pageNum,
                                                      @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<SmokePackageCountVO> page = null;
        try {
            page = reportService.smokePackageCountPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询稻谷购、销外省市")
    @PostMapping(value = "/riceProcurementPage/{pageNum}/{pageSize}")
    public ResponseWrapper riceProcurementPage(@RequestBody RiceProcurementQueryVO vo,
                                                 @PathVariable(value = "pageNum") Integer pageNum,
                                                 @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<RiceProcurementVO> page = null;
        try {
            page = reportService.riceProcurementPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
    @ApiOperation(value = "条件分页查询市级储备粮轮换补贴预申请表")
    @PostMapping(value = "/preApplicationSubsidyPage/{pageNum}/{pageSize}")
    public ResponseWrapper preApplicationSubsidyPage(@RequestBody PreApplicationSubsidyQueryVO vo,
                                               @PathVariable(value = "pageNum") Integer pageNum,
                                               @PathVariable(value = "pageSize") Integer pageSize){
        PageInfo<PreApplicationSubsidyVO> page = null;
        try {
            page = reportService.preApplicationSubsidyPage(vo, pageNum, pageSize);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(e.getMessage());
        }
        return ResponseWrapper.success(page);
    }
}
