package com.unis.ynls.irpt.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.reservereport.*;
import com.unis.ynls.irpt.server.entity.reservereport.StorageSubsidyStandardDO;
import com.unis.ynls.irpt.server.service.ReserveReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/reserve-report")
@Slf4j
@Api(value = "财务报表-进销存报表、补贴", tags = "财务报表-进销存报表、补贴")
public class ReserveReportController {

    @Autowired
    private ReserveReportService reserveReportService;

    /******************************财务报表-储备粮油进销存报表*****************************/
    @ApiOperation(value = "储备粮油进销存报表-填报接口", notes = "参数：PurchaseStockVO")
    @PostMapping(value = "/purchase-stock/save")
    public ResponseWrapper savePurchaseStock(@RequestBody PurchaseStockVO vo) {
        try {

            return reserveReportService.savePurchaseStock(vo);
        } catch (Exception e) {
            log.error("ReserveReportController.savePurchaseStock{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "储备粮油进销存报表-获取填报期数", notes = "参数：PurchaseStockQueryVO")
    @PostMapping(value = "/purchase-stock/getPeriod")
    public ResponseWrapper getPeriod(@RequestBody PurchaseStockQueryVO queryVO) {
        try {
            return reserveReportService.getPeriod(queryVO);
        } catch (Exception e) {
            log.error("ReserveReportController.getPeriod{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "储备粮油进销存报表-修改||盖章||接收||撤销 接口", notes = "notes = 参数：type:1:修改,提交 2:盖章 3:接收 4:撤销")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 1修改,提交 2盖章 3接收 4:撤销", required = true, dataType = "Integer")
    })
    @PutMapping(value = "/purchase-stock/update/{type}")
    public ResponseWrapper updatePurchaseStock(@PathVariable("type")Integer type,@RequestBody PurchaseStockVO vo) {
        try {
            return reserveReportService.updatePurchaseStock(type,vo);
        } catch (Exception e) {
            log.error("ReserveReportController.updatePurchaseStock{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    //储备粮油进销存报表-分页列表查询
    @ApiOperation(value = "储备粮油进销存报表-分页列表查询【企业端】", notes = "参数：PurchaseStockQueryVO")
    @PostMapping(value = "/purchase-stock/page/{pageNum}/{pageSize}")
    public ResponseWrapper getPurchaseStockPageList(@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize")Integer pageSize,@RequestBody PurchaseStockQueryVO queryVO) {
        try {
            return ResponseWrapper.success(reserveReportService.getPurchaseStockPageList(pageNum,pageSize,queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getPurchaseStockPageList{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    //储备粮油进销存报表-列表查询【管理端】
    @ApiOperation(value = "储备粮油进销存报表-列表查询【管理端】", notes = "参数：PurchaseStockQueryVO")
    @PostMapping(value = "/purchase-stock/list/{pageNum}/{pageSize}")
    public ResponseWrapper getPurchaseStockList(@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize")Integer pageSize,@RequestBody PurchaseStockQueryVO queryVO) {
        try {
            return ResponseWrapper.success(reserveReportService.getPurchaseStockList(pageNum,pageSize,queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getPurchaseStockList{}:" + e.getMessage());
        }
        return ResponseWrapper.error();
    }



    //储备粮油进销存报表-分页列表查询
    @ApiOperation(value = "储备粮油进销存报表-根据ID查看详情", notes = "参数：psId")
    @GetMapping(value = "/purchase-stock/info/{psId}")
    public ResponseWrapper getPurchaseStockInfo(@PathVariable("psId")String psId) {
        try {
            return ResponseWrapper.success(reserveReportService.getPurchaseStockInfo(psId));
        } catch (Exception e) {
            log.error("ReserveReportController.getPurchaseStockInfo{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    //储备粮油进销存报表-获取上期期末库存接口
    @ApiOperation(value = "储备粮油进销存报表-获取上期期末库存接口")
    @PostMapping(value = "/purchase-stock/getPreviousStock")
    public ResponseWrapper getPreviousStock(@RequestBody PurchaseStockQueryVO queryVO) {
        try {
            if(StringUtils.isEmpty(queryVO.getPeriod()) || StringUtils.isEmpty(queryVO.getSskdbm()) || !reserveReportService.validPeriod(queryVO.getPeriod())){
                return ResponseWrapper.invalid();
            }
            return ResponseWrapper.success(reserveReportService.getPreviousStock(queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getPreviousStock{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "储备粮油进销存汇总报表-生成汇总数据接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "period", value = "汇总期数", dataType = "String"),
            @ApiImplicitParam(name = "dataType", value = "数据类型 0:市级储备粮油 1:市级粮食调节储备 2:异地存储市级粮食调节储备", dataType = "Integer")
    })
    @GetMapping(value = "/purchase-stock/summary/generate/{dataType}")
    public ResponseWrapper generatePurchaseStockSummary(@PathVariable("dataType")Integer dataType) {
        try {
            if(dataType == null){
                return ResponseWrapper.invalid();
            }
            return ResponseWrapper.success(reserveReportService.generatePurchaseStockSummary(dataType));
        } catch (Exception e) {
            log.error("ReserveReportController.generatePurchaseStockSummary{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "储备粮油进销存汇总报表-汇总接口", notes = "参数：PurchaseStockSummaryVO")
    @PostMapping(value = "/purchase-stock/summary/save")
    public ResponseWrapper savePurchaseStockSummary(@RequestBody PurchaseStockSummaryVO summaryVO) {
        try {

            return reserveReportService.savePurchaseStockSummary(summaryVO);
        } catch (Exception e) {
            log.error("ReserveReportController.savePurchaseStockSummary{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "储备粮油进销存汇总报表-复核接口", notes = "参数：PurchaseStockSummaryVO")
    @PostMapping(value = "/purchase-stock/summary/update")
    public ResponseWrapper updatePurchaseStockSummary(@RequestBody PurchaseStockSummaryVO summaryVO){
        try {
            return reserveReportService.updatePurchaseStockSummary(summaryVO);
        } catch (Exception e) {
            log.error("ReserveReportController.savePurchaseStockSummary{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    //储备粮油进销存汇总报表-分页列表查询接口
    @ApiOperation(value = "储备粮油进销存汇总报表-分页列表查询接口", notes = "参数：queryVO")
    @PostMapping(value = "/purchase-stock/summary/page/{pageNum}/{pageSize}")
    public ResponseWrapper getPurchaseStockSummaryPageList(@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize")Integer pageSize,@RequestBody PurchaseStockQueryVO queryVO) {

        try {
            return ResponseWrapper.success(reserveReportService.getPurchaseStockSummaryPageList(pageNum,pageSize,queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getPurchaseStockSummaryPageList{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }
    //储备粮油进销存汇总报表-数据详情查看接口
    @ApiOperation(value = "储备粮油进销存汇总报表-数据详情查看接口", notes = "参数：queryVO")
    @PostMapping(value = "/purchase-stock/summary/info")
    public ResponseWrapper getPurchaseStockSummaryInfo(@RequestBody PurchaseStockQueryVO queryVO) {

        try {
            return ResponseWrapper.success(reserveReportService.getPurchaseStockSummaryInfo(queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getPurchaseStockSummaryInfo{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    //储备粮油进销存汇总报表-删除接口
    @ApiOperation(value = "储备粮油进销存汇总报表-删除接口")
    @DeleteMapping(value = "/purchase-stock/summary/delete/{id}")
    public ResponseWrapper deletePurchaseStockSummary(@PathVariable("id")String id) {
        try {
            if(reserveReportService.deletePurchaseStockSummary(id) > 0){
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("ReserveReportController.deletePurchaseStockSummary{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员！");
    }

    /******************************财务报表-市级储备粮油储存费用补贴*****************************/
    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-获取填报期数", notes = "参数：StorageSubsidyQueryVO")
    @PostMapping(value = "/storage-subsidy/getPeriod")
    public ResponseWrapper getStorageSubsidyPeriod(@RequestBody StorageSubsidyQueryVO queryVO) {
        try {
            if(queryVO == null || StringUtils.isEmpty(queryVO.getSskdbm()) || queryVO.getDataType() == null){
                return ResponseWrapper.invalid();
            }
            String period = reserveReportService.getStorageSubsidyPeriod(queryVO);
            if(StringUtils.isNotEmpty(period)){
                return ResponseWrapper.success(200,"获取成功",period);
            }
        } catch (Exception e) {
            log.error("ReserveReportController.getStorageSubsidyPeriod{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
        return ResponseWrapper.error();
    }

    //市级储备粮油储存费用补贴申请表-保存接口
    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-保存接口")
    @PostMapping(value = "/storage-subsidy/save")
    public ResponseWrapper saveStorageSubsidy(@RequestBody StorageSubsidyVO vo) {
        try {
            //判断参数是否为空
            if(vo == null || StringUtils.isEmpty(vo.getSskdbm()) || vo.getDataType() == null
                    || StringUtils.isEmpty(vo.getPeriod()) || vo.getDetailList() == null || vo.getDetailList().size() == 0){
                return ResponseWrapper.invalid();
            }
            return reserveReportService.saveStorageSubsidy(vo);
        } catch (Exception e) {
            log.error("ReserveReportController.saveStorageSubsidy{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    //市级储备粮油储存费用补贴申请表-修改||盖章||接收 接口
    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-修改||盖章||接收||撤销 接口",notes = "参数：type:1:修改 2:盖章 3:接收 4:撤销")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 1修改 2盖章 3接收 4撤销", dataType = "Integer")
    })
    @PutMapping(value = "/storage-subsidy/update/{type}")
    public ResponseWrapper updateStorageSubsidy(@PathVariable("type")Integer type,@RequestBody StorageSubsidyVO vo) {
        try {
            //判断参数是否为空
            if(vo == null || StringUtils.isEmpty(vo.getId())){
                return ResponseWrapper.invalid();
            }
            return reserveReportService.updateStorageSubsidy(type,vo);
        } catch (Exception e) {
            log.error("ReserveReportController.updateStorageSubsidy{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，联系管理员");
        }
    }

    //市级储备粮油储存费用补贴申请表-列表分页查询接口
    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-列表分页查询接口(企业端)")
    @PostMapping(value = "/storage-subsidy/page/{pageNum}/{pageSize}")
    public ResponseWrapper getStorageSubsidyPageList(@PathVariable("pageNum")Integer pageNum,
                                                     @PathVariable("pageSize")Integer pageSize,
                                                     @RequestBody StorageSubsidyQueryVO queryVO) {
        try {
            //判断参数是否为空
            if (queryVO == null || queryVO.getDataType() == null) {
                return ResponseWrapper.invalid();
            }
            return ResponseWrapper.success(reserveReportService.getStorageSubsidyPageList(pageNum, pageSize, queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getStorageSubsidyPageList{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-列表查询接口【管理端】")
    @PostMapping(value = "/storage-subsidy/list/{pageNum}/{pageSize}")
    public ResponseWrapper getStorageSubsidyList(@PathVariable("pageNum")Integer pageNum,
                                                 @PathVariable("pageSize")Integer pageSize,
                                                 @RequestBody StorageSubsidyQueryVO queryVO) {
        try {
            return ResponseWrapper.success(reserveReportService.getStorageSubsidyList(pageNum, pageSize,queryVO));
        } catch (Exception e) {
            log.error("ReserveReportController.getStorageSubsidyList{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油储存费用补贴申请表-根据申请表ID获取详情接口
    @ApiOperation(value = "市级储备粮油储存费用补贴申请表-根据申请表ID获取详情接口")
    @GetMapping(value = "/storage-subsidy/info/{ssId}")
    public ResponseWrapper getStorageSubsidyInfo(@PathVariable("ssId")String ssId) {
        try {
            return ResponseWrapper.success(reserveReportService.getStorageSubsidyInfo(ssId));
        } catch (Exception e) {
            log.error("ReserveReportController.getStorageSubsidyInfo{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }

    @ApiOperation(value = "拨付市级储备粮油储存费用-生成汇总数据接口【管理端】")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "period", value = "上报期数 yyyy年MM月", dataType = "String"),
            @ApiImplicitParam(name = "dataType", value = "数据类型 0:市级储备粮油 1:市级粮食调节储备 2:异地存储市级粮食调节储备", dataType = "Integer")
    })
    @GetMapping(value = "/storage-subsidy/summary/generate")
    public ResponseWrapper generateStorageSubsidySummary(@RequestParam("dataType") Integer dataType) {
        try {
            return ResponseWrapper.success(reserveReportService.generateStorageSubsidySummary(dataType));
        }catch (Exception e) {
            log.error("ReserveReportController.generateStorageSubsidySummary{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
        }
    }
    //拨付市级储备粮油储存费用-汇总数据接口
    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据保存接口")
    @PostMapping(value = "/storage-subsidy/summary/save")
    public ResponseWrapper saveStorageSubsidySummary(@RequestBody StorageSubsidySummaryVO storageSubsidySummaryVO) {

        try {
            //判断条件 上报期数||数据类型
            if(storageSubsidySummaryVO == null || StringUtils.isEmpty(storageSubsidySummaryVO.getPeriod()) || storageSubsidySummaryVO.getDataType() == null){
                return ResponseWrapper.invalid();
            }
            return reserveReportService.saveStorageSubsidySummary(storageSubsidySummaryVO);

        }catch (Exception e) {
            log.error("ReserveReportController.saveStorageSubsidySummary{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }

    //拨付市级储备粮油储存费用-修改接口
    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据 制表||复核||财务领导批示||单位负责人批示 接口 接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 1,制表,修改 2复核 3财务领导批示 4单位负责人批示", required = true, dataType = "Integer")
    })
    @PutMapping(value = "/storage-subsidy/summary/update/{type}")
    public ResponseWrapper updateStorageSubsidySummary(@PathVariable("type") Integer type,@RequestBody StorageSubsidySummaryVO storageSubsidySummaryVO) {
        try {
            //判断参数不能为空
            if(storageSubsidySummaryVO == null || StringUtils.isEmpty(storageSubsidySummaryVO.getId())){
                return ResponseWrapper.invalid();
            }
            return reserveReportService.updateStorageSubsidySummary(type,storageSubsidySummaryVO);
        }catch (Exception e) {
            log.error("ReserveReportController.updateStorageSubsidySummary{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }

    //拨付市级储备粮油储存费用-列表分页查询
    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据列表分页查询")
    @PostMapping(value = "/storage-subsidy/summary/page/{pageNum}/{pageSize}")
    public ResponseWrapper getStorageSubsidySummaryPageList(@PathVariable("pageNum")Integer pageNum,
                                                            @PathVariable("pageSize")Integer pageSize,
                                                            @RequestBody StorageSubsidySummaryQueryVO queryVO) {
        try {
            return ResponseWrapper.success(reserveReportService.getStorageSubsidySummaryPageList(pageNum, pageSize, queryVO));
        } catch (Exception e) {
            e.printStackTrace();
            log.error("ReserveReportController.getStorageSubsidySummaryPageList{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，联系管理员");
        }
    }

    //拨付市级储备粮油储存费用-汇总数据详情查看
    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据详情查看")
    @GetMapping(value = "/storage-subsidy/summary/info/{id}")
    public ResponseWrapper getStorageSubsidySummaryInfo(@PathVariable("id") String id) {
        try {
            return ResponseWrapper.success(reserveReportService.getStorageSubsidySummaryInfo(id));
        } catch (Exception e) {
            log.error("ReserveReportController.getStorageSubsidySummaryInfo{}:" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
        }
    }

    //拨付市级储备粮油储存费用-汇总数据删除
    @ApiOperation(value = "拨付市级储备粮油储存费用-汇总数据删除")
    @DeleteMapping(value = "/storage-subsidy/summary/delete/{id}")
    public ResponseWrapper deleteStorageSubsidySummary(@PathVariable("id") String id) {
        try {
            if(reserveReportService.deleteStorageSubsidySummary(id) > 0){
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("ReserveReportController.deleteStorageSubsidySummary{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员！");
    }

}
