package com.unis.ynls.irpt.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.RotateProtocolVO;
import com.unis.ynls.irpt.common.VO.rotationreport.*;
import com.unis.ynls.irpt.server.entity.RotatePlanProtocolVO;
import com.unis.ynls.irpt.server.service.RotationReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/rotation-report")
@Slf4j
@Api(value = "财务报表-包干轮换补贴", tags = "财务报表-包干轮换补贴")
public class RotationReportController {

    @Autowired
    private RotationReportService rotationReportService;

    //市级储备粮油轮换费率配置-新增接口
    @ApiOperation(value = "市级储备粮油轮换费率配置-新增接口", notes = "参数：RotationSubsidyRateVO")
    @PostMapping(value = "/subsidy-rate/save")
    public ResponseWrapper saveRotationSubsidyRate(@RequestBody RotationSubsidyRateVO vo) {
        try {
            //判断参数是否为空
            if (vo == null || StringUtils.isEmpty(vo.getPzbm()) || vo.getStandard() == null) {
                return ResponseWrapper.invalid();
            }
            if (rotationReportService.saveRotationSubsidyRate(vo) > 0)
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "添加成功！");
        } catch (Exception e) {
            log.error("RotationReportController.saveRotationSubsidyRate{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换费率配置-新增接口
    @ApiOperation(value = "市级储备粮油轮换费率配置-根据品种编码获取有效的费率", notes = "参数：pzbm")
    @GetMapping(value = "/subsidy-rate/enabled/{pzbm}/{typeCode}")
    public ResponseWrapper getEnabledByPzbm(@PathVariable("pzbm") String pzbm,
                                            @PathVariable("typeCode") String ttshxydm) {
        try {
            RotationSubsidyRateVO enabledByPzbm = rotationReportService.getEnabledByPzbm(pzbm, ttshxydm);
            if (enabledByPzbm == null) {
                return ResponseWrapper.success("请在管理端设置对应的补贴费率");
            }
            return ResponseWrapper.success(enabledByPzbm);
        } catch (Exception e) {
            log.error("RotationReportController.getRotationSubsidyRate{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换费率配置-列表接口
    @ApiOperation(value = "催化剂类轮换计划-列表接口", notes = "")
    @GetMapping(value = "/subsidy-rate/list")
    public ResponseWrapper getRotationSubsidyRateList() {

        try {
            return ResponseWrapper.success(rotationReportService.getRotationSubsidyRateList());
        } catch (Exception e) {
            log.error("RotationReportController.getRotationSubsidyRateList{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-轮换粮食查询接口【企业端】
    @ApiOperation(value = "市级储备粮油轮换补贴-轮换粮食查询接口【企业端】", notes = "ccqybm,pzbm")
    @GetMapping(value = "/subsidy/grainInfo/{ccqybm}/{pzbm}")
    public ResponseWrapper getRotationGrain(@PathVariable("ccqybm") String ccqybm,
                                            @PathVariable("pzbm") String pzbm) {
        // ccqybm 所属企业代码  pzbm 品种编码ccqy
        try {
            return ResponseWrapper.success(rotationReportService.getRotationGrain(ccqybm, pzbm));
        } catch (Exception e) {
            log.error("RotationReportController.getRotationGrain{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    @ApiOperation(value = "市级储备粮油轮换补贴-轮换协议主表查询接口【企业端】", notes = "ccqybm")
    @GetMapping(value = "/subsidy/Protocol/{ccqybm}")
    public ResponseWrapper getRotationProtocol(@PathVariable("ccqybm") String ccqybm) {
        // ccqybm 所属企业代码  pzbm 品种编码ccqy
        try {
            return ResponseWrapper.success(rotationReportService.getRotationProtocol(ccqybm));
        } catch (Exception e) {
            log.error("RotationReportController.getRotationGrain{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    @ApiOperation(value = "市级储备粮油轮换补贴-轮换协议明细查询接口【企业端】")
    @PostMapping(value = "/subsidy/ProtocolDetail")
    public ResponseWrapper getRotationProtocolDetail(@RequestBody RotateProtocolVO rotateProtocolVO) {
        // ccqybm 所属企业代码  pzbm 品种编码ccqy
        try {
            return ResponseWrapper.success(rotationReportService.getRotationProtocolDetail(rotateProtocolVO));
        } catch (Exception e) {
            e.printStackTrace();
            log.error("RotationReportController.getRotationGrain{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-新增（填报）接口
    @ApiOperation(value = "市级储备粮油轮换补贴申请-新增（填报）接口", notes = "参数：type,RotationSubsidyVO")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算填报，liquidate-修改法规")
    @PostMapping(value = "/subsidy/{type}/save")
    public ResponseWrapper saveRotationSubsidy(@PathVariable("type") String type,
                                               @RequestBody RotationSubsidyVO vo) {
        try {
            //参数非空判断
            if (vo == null || StringUtils.isEmpty(vo.getPzbm()) || StringUtils.isEmpty(vo.getCcqy())
                    || StringUtils.isEmpty(vo.getOrgCode()) || StringUtils.isEmpty(vo.getDeptCode())
                    || (vo.getBudgetList() == null && vo.getLiquidateList() == null)) {
                return ResponseWrapper.invalid();
            }
            if (rotationReportService.saveRotationSubsidy(type, vo)) {
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "填报成功！");
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("RotationReportController.saveRotationSubsidy{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-修改||盖章||接收||撤销 接口
    @ApiOperation(value = "市级储备粮油轮换补贴-修改||盖章||接收||撤销 接口", notes = "参数：type,RotationSubsidyVO")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算填报，liquidate-修改法规")
    @PutMapping(value = "/subsidy/{type}/update")
    public ResponseWrapper updateRotationSubsidy(@PathVariable("type") String type,
                                                 @RequestBody RotationSubsidyVO vo) {

        try {
            if (vo == null || StringUtils.isEmpty(vo.getId())) {
                return ResponseWrapper.invalid();
            }
            if (rotationReportService.updateRotationSubsidy(type, vo))
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "操作成功！");

        } catch (Exception e) {
            log.error("RotationReportController.updateRotationSubsidy{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-列表分页查询 接口
    @ApiOperation(value = "市级储备粮油轮换补贴-列表分页查询 接口【企业端】", notes = "参数：pageNum,pageSize,RotationSubsidyQueryVO")
    @PostMapping(value = "/subsidy/list/{pageNum}/{pageSize}")
    public ResponseWrapper getRotationSubsidyPageList(@PathVariable("pageNum") Integer pageNum,
                                                      @PathVariable("pageSize") Integer pageSize,
                                                      @RequestBody RotationSubsidyQueryVO queryVO) {

        try {
            return ResponseWrapper.success(rotationReportService.getRotationSubsidyPageList(pageNum, pageSize, queryVO));
        } catch (Exception e) {
            log.error("RotationReportController.getRotationSubsidyPageList{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-根据RotationSubsidyId详情查询接口
    @ApiOperation(value = "市级储备粮油轮换补贴-根据RotationSubsidyId详情查询接口", notes = "参数：RotationSubsidyId")
    @GetMapping(value = "/subsidy/info/{rsId}")
    public ResponseWrapper getRotationSubsidyInfo(@PathVariable("rsId") String rsId) {
        try {
            return ResponseWrapper.success(rotationReportService.getRotationSubsidyInfo(rsId));
        } catch (Exception e) {
            log.error("RotationReportController.getRotationSubsidyInfo{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-列表查询接口(管理端)
    @ApiOperation(value = "市级储备粮油轮换补贴-列表查询接口【管理端】", notes = "pageNum,pageSize,RotationSubsidyQueryVO")
    @PostMapping(value = "/subsidy/list1/{pageNum}/{pageSize}")
    public ResponseWrapper getRotationSubsidyList(@PathVariable("pageNum") Integer pageNum,
                                                  @PathVariable("pageSize") Integer pageSize,
                                                  @RequestBody RotationSubsidyQueryVO queryVO) {
        try {
            return ResponseWrapper.success(rotationReportService.getRotationSubsidyList(pageNum, pageSize, queryVO));
        } catch (Exception e) {
            log.error("RotationReportController.getRotationSubsidyList{}:" + e.getMessage());

        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");

    }

    //市级储备粮油轮换补贴-生成审批表-申报单位列表接【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-生成审批表-申报单位列表接【管理端】", notes = "参数：type")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算，liquidate-修改")
    @GetMapping(value = "/subsidy/approval/{type}/list")
    public ResponseWrapper getRotationSubsidyApprovalList(@PathVariable("type") String type) {
        try {
            return ResponseWrapper.success(rotationReportService.getRotationSubsidyApprovalList(type));
        } catch (Exception e) {
            log.error("RotationReportController.getRotationSubsidyApprovalList{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }


    //市级储备粮油轮换补贴-生成审批表-根据选择的申报单位列表生成汇总表数据【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-生成审批表-根据选择的申报单位列表生成汇总表数据【管理端】")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算，liquidate-修改")
    @PostMapping(value = "/subsidy/summary/{type}/init")
    public ResponseWrapper initRotationSubsidySummary(@PathVariable("type") String type, @RequestBody List<String> rotationSubsidyIds) {
        try {
            return ResponseWrapper.success(rotationReportService.initRotationSubsidySummary(type, rotationSubsidyIds));
        } catch (Exception e) {
            log.error("RotationReportController.initRotationSubsidySummary{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-生成审批表-汇总数据保存接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-生成审批表-汇总数据保存接口【管理端】", notes = "参数：type")
    @ApiImplicitParam(name = "type", value = "类型：budget-预算，liquidate-清算")
    @PostMapping(value = "/subsidy/summary/{type}/save")
    public ResponseWrapper saveRotationSubsidySummary(@PathVariable("type") String type, @RequestBody RotationSubsidySummaryVO summaryVO) {
        try {
            //参数判断
            if (summaryVO == null || StringUtils.isEmpty(summaryVO.getLhnd())/*|| StringUtils.isEmpty(summaryVO.getPzbm())*/
                    || StringUtils.isEmpty(summaryVO.getOrgCode()) || summaryVO.getDetailList() == null || summaryVO.getDetailList().size() == 0) {
                return ResponseWrapper.invalid();
            }
            if (rotationReportService.saveRotationSubsidySummary(type, summaryVO) > 0) {
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("RotationReportController.saveRotationSubsidySummary{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-汇总数据 修改||复核||财务批示||领导审核 接口【管理端】

    @ApiOperation(value = "市级储备粮油轮换补贴-汇总数据 修改||复核||财务领导批示||单位负责人批示 接口【管理端】")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "type", value = "类型 1制表,修改 2复核 3财务领导批示 4单位负责人批示 ", dataType = "Integer")
    })
    @PutMapping(value = "/subsidy/summary/update/{type}")
    public ResponseWrapper updateRotationSubsidySummary(@PathVariable("type") Integer type, @RequestBody RotationSubsidySummaryVO summaryVO) {
        try {
            //参数判断
            if (summaryVO == null || StringUtils.isEmpty(summaryVO.getId())) {
                return ResponseWrapper.invalid();
            }
            if (rotationReportService.updateRotationSubsidySummary(type, summaryVO) > 0) {
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("RotationReportController.updateRotationSubsidySummary{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-包干轮换补贴审批-列表接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-包干轮换补贴审批-列表接口【管理端】")
    @PostMapping(value = "/subsidy/summary/list/{pageNum}/{pageSize}")
    public ResponseWrapper getRotationSubsidySummaryPageList(@PathVariable("pageNum") Integer pageNum,
                                                             @PathVariable("pageSize") Integer pageSize,
                                                             @RequestBody RotationSubsidySummaryQueryVO queryVO) {
        try {
            return ResponseWrapper.success(rotationReportService.getRotationSubsidySummaryPageList(pageNum, pageSize, queryVO));
        } catch (Exception e) {
            log.error("RotationReportController.getRotationSubsidySummaryPageList{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-包干轮换补贴审批-详情查看接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-包干轮换补贴审批-详情查看接口【管理端】")
    @GetMapping(value = "/subsidy/summary/info/{id}")
    public ResponseWrapper getRotationSubsidySummaryInfo(@PathVariable("id") String id) {
        try {
            return ResponseWrapper.success(rotationReportService.getRotationSubsidySummaryInfo(id));
        } catch (Exception e) {
            log.error("RotationReportController.getRotationSubsidySummaryInfo{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }

    //市级储备粮油轮换补贴-包干轮换补贴审批-删除接口【管理端】
    @ApiOperation(value = "市级储备粮油轮换补贴-包干轮换补贴审批-删除接口【管理端】")
    @DeleteMapping(value = "/subsidy/summary/delete/{id}")
    public ResponseWrapper deleteRotationSubsidySummary(@PathVariable("id") String id) {
        try {
            if (rotationReportService.deleteRotationSubsidySummary(id) > 0) {
                return ResponseWrapper.success();
            }
        } catch (Exception e) {
            log.error("RotationReportController.deleteRotationSubsidySummary{}:" + e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员！");
    }
}
