package com.unis.ynls.irpt.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.SafetyQueryVO;
import com.unis.ynls.irpt.common.VO.SafetyVO;
import com.unis.ynls.irpt.server.service.SafeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author ChenKai
 * @Date 2019/10/18 14:19
 * @Version 1.0
 */
@RestController
@RequestMapping("/safe")
@Slf4j
@Api(value = "安全储量与安全生产", tags = "安全储量与安全生产")
public class SafeController {

    @Autowired
    private SafeService safeService;

    @ApiOperation(value = "安全储量与安全生产", notes = "参数：企业名称,创建时间")
    @ApiImplicitParams({ @ApiImplicitParam(name = "pageNum", value = "起始页", required = true),
            @ApiImplicitParam(name = "pageSize", value = "每页展示行数", required = true) })
    @PostMapping(value = "/findSafeInfo")
    public ResponseWrapper findSafeInfo(@RequestParam("pageNum") Integer pageNum,
                                        @RequestParam("pageSize") Integer pageSize,
                                        @RequestBody SafetyQueryVO vo) {
        try {
            PageInfo<List<SafetyVO>> list = safeService.findSafeInfo(pageNum,pageSize,vo);
            return ResponseWrapper.success(200, "查询成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询粮油产业经济统计年报失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }


    @ApiOperation(value = "获取任务ID主键策略方法 ",notes = "参数：")
    @GetMapping(value = "/maxCodeById")
    public ResponseWrapper maxCodeById(@RequestParam String s){
        try {
            String maxId = safeService.findMaxId(s);
            return ResponseWrapper.success(200, "查询成功", maxId);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("最大主键查询失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }


    @ApiOperation(value = "删除", notes = "参数：bbq")
    @DeleteMapping(value = "/deleteByBbq/{bbq}")
    public ResponseWrapper deleteByBbq(@PathVariable("bbq") String bbq){
        try {
            int i = safeService.deleteByBbq(bbq);
            return ResponseWrapper.success(200, "删除成功", i);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除失败：" + e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }
}
