package com.unis.ynls.irpt.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.BasicVO;
import com.unis.ynls.irpt.common.VO.StatisticalQueryVO;
import com.unis.ynls.irpt.common.VO.StatisticalVO;
import com.unis.ynls.irpt.server.service.StatisticalService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

/**
 * @Version 1.0
 * @author 张琪
 * @Date 2019-10-15
 */

@RestController
@Slf4j
@Api(value = "执法督查机构、人员和经费情况统计表",tags="执法督查机构、人员和经费情况统计表")
public class StatisticalController {
	    @Autowired
	    private StatisticalService statisticalService;
	  
	    /**
	     *  根据条件分页查询 执法督查机构、人员和经费情况统计表
	     * @param statisticalTableQueryVO
	     * @param pageNum
	     * @param pageSize
	     * @return
	     */
	    @ApiOperation(value = "条件分页查询【执法督查机构、人员和经费情况统计表】")
	    @PostMapping(value = "/statisticalTablePageList/{pageNum}/{pageSize}")
	    public ResponseWrapper getStatisticalTablePageList(@RequestBody StatisticalQueryVO statisticalQueryVO,
	                                             @PathVariable(value = "pageNum") Integer pageNum,
	                                             @PathVariable(value = "pageSize") Integer pageSize) {
	        try {
	            PageInfo<StatisticalVO> pageList = statisticalService.getStatisticalTablePageList(statisticalQueryVO, pageNum, pageSize);
	            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", pageList);
	        } catch (Exception e) {
	            log.error(e.getMessage());
	            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
	        }
	    }
	    
	 /**
	  * 
	  * @Title: statisticalInto
	  * @Description: TODO方法描述:(报表信息录入)
	  * @param @param statisticalVO
	  * @param @return    设定文件
	  * @return ResponseWrapper    返回类型
	  * @throws
	  */
	    @ApiOperation(value = "报表信息录入【执法督查机构、人员和经费情况统计表】")
	    @PutMapping(value = "/statisticalInto")
	    public ResponseWrapper statisticalInto(@RequestBody StatisticalVO statisticalVO) {
	    		  try {
	    			int status=statisticalService.statisticalInto(statisticalVO);
	    			if(status!=0) {
	    				  return ResponseWrapper.success(HttpStatus.OK.value(), "保存失败", null);
	    			}
	  	            return ResponseWrapper.success(HttpStatus.OK.value(), "保存成功", null);
	  	        } catch (Exception e) {
	  	            log.error(e.getMessage());
	  	            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "保存失败", null);
	  	        }
	    }
	    
	    /**
	     * 
	     * @Title: statisticalDelete
	     * @Description: TODO方法描述:(报表信息删除【执法督查机构、人员和经费情况统计表】)
	     * @param @param statisticalVO
	     * @param @return    设定文件
	     * @return ResponseWrapper    返回类型
	     * @throws
	     */
	    @ApiOperation(value = "报表信息删除【执法督查机构、人员和经费情况统计表】")
	    @DeleteMapping(value = "/statisticalDelete")
	    public ResponseWrapper statisticalDelete(@RequestBody StatisticalVO statisticalVO) {
	    	 try {
	    			int status=statisticalService.statisticalDelete(statisticalVO);
	    			if(status!=0) {
	    				  return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
	    			}
	  	            return ResponseWrapper.success(HttpStatus.OK.value(), "删除失败", null);
	  	        } catch (Exception e) {
	  	            log.error(e.getMessage());
	  	            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "删除失败", null);
	  	        }
	    }
	    
	    /**
	     * 
	     * @Title: maxCodeById
	     * @Description: TODO方法描述:(这里用一句话描述这个方法的作用)
	     * @param @param jhId
	     * @param @return    设定文件
	     * @return ResponseWrapper    返回类型
	     * @throws
	     */
		@ApiOperation(value = "获取任务ID主键策略方法 ",notes = "参数：jhId-编号")
		@GetMapping(value = "/stmaxCodeById/{jhId}")
		public ResponseWrapper maxCodeById(@PathVariable("jhId")String jhId) {
			try {
				String rwIdString=statisticalService.maxCodeById(jhId);
				if(!StringUtils.isNotBlank(rwIdString)) {
					return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "生成主键策略失败", rwIdString);
				}
	            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), rwIdString);
			  } catch (Exception e) {
		            e.printStackTrace();
		            log.error(e.getMessage());
		        }
		     return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
		}



		@ApiOperation(value = "获取最大的主键ID", notes = "参数：")
		@GetMapping(value = "/findMaxId")
		public ResponseWrapper findMaxId(){
			try {
				String maxId = statisticalService.findMaxId();
				return ResponseWrapper.success(200, "查询成功", maxId);
			} catch (Exception e) {
				e.printStackTrace();
				log.error("最大主键查询失败：" + e.getMessage());
				return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
			}

		}



}
