package com.unis.ynls.irpt.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.BaseFilterVO;
import com.unis.ynls.irpt.common.VO.task.CompanyRptFilterVO;
import com.unis.ynls.irpt.common.VO.task.ReportInfoVO;
import com.unis.ynls.irpt.common.VO.task.RptListFilterVO;
import com.unis.ynls.irpt.common.VO.task.RptListVO;
import com.unis.ynls.irpt.common.VO.task.TaskFilterVO;
import com.unis.ynls.irpt.server.service.TaskInfoService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @ClassName: TaskInfoController
 * @Description: IRPT报表管理
 * @author liyb
 * @version v1.0
 * @date 2018-12-27 14:37:36
 */
@RefreshScope
@RestController
@RequestMapping("/task")
@Slf4j
@Api(value = "IRPT报表管理", tags = "IRPT报表管理")
@SuppressWarnings("all")
public class TaskInfoController  {
    @Autowired
    private TaskInfoService taskInfoService;

    /**
     * 查询指定报表已上报数量
     * @param taskFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2018-12-27 14:46:58
     * @version v1.0
     */
    @ApiOperation(value = "查询指定报表已上报数量", notes = "参数：报表真实代码，报表期")
    @PostMapping(value = "/queryReportByConditions")
    public ResponseWrapper queryReportByConditions(@RequestBody TaskFilterVO taskFilterVO) {
        try {
            Integer i = taskInfoService.queryReportByConditions(taskFilterVO);
            return ResponseWrapper.success(200, "查询指定条件报表已上报数量成功", i==null?0:i);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询指定条件报表已上报数量失败：" + e.getMessage());
            return ResponseWrapper.error(500, "查询指定条件报表已上报数量失败",null);
        }
    }
    /**
     * 查询指定条件报表已上报信息
     * @param taskFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2018-12-27 14:46:58
     * @version v1.0
     */
    @ApiOperation(value = "查询指定条件报表已上报信息", notes = "参数：报表真实代码，报表期")
    @PostMapping(value = "/queryReportInfoByConditions")
    public ResponseWrapper queryReportInfoByConditions(@RequestBody TaskFilterVO taskFilterVO) {
        try {
            List<ReportInfoVO> list = taskInfoService.queryReportInfoByConditions(taskFilterVO);
            return ResponseWrapper.success(200, "查询指定条件报表已上报信息成功", list);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询指定条件报表已上报信息失败：" + e.getMessage());
            return ResponseWrapper.error(500, "查询指定条件报表已上报信息失败",null);
        }
    }
    /**
     * 查询指定条件下企业是否上报
     * @param companyRptFilterVO 参数：报表真实代码，报表期，企业统一社会信用代码
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-02-18 17:24:28
     * @version v1.0
     */
    @ApiOperation(value = "查询指定条件下企业是否上报", notes = "参数：报表真实代码，报表期，企业统一社会信用代码")
    @PostMapping( value = "/queryCompanyWhetherReport")
    public ResponseWrapper queryCompanyWhetherReport(@RequestBody CompanyRptFilterVO companyRptFilterVO){
        try {
            Integer result = taskInfoService.queryCompanyWhetherReport(companyRptFilterVO);
            return ResponseWrapper.success(200, "查询指定条件下企业是否上报成功", result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询指定条件下企业是否上报失败：" + e.getMessage());
            return ResponseWrapper.error(500, "查询指定条件下企业是否上报失败",null);
        }
    }
    /**
     * 获取指定报表新增报表期
     * @param taskId
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-01-25 15:42:28
     * @version v1.0
     */
    @ApiOperation(value = "获取指定报表新增报表期", notes = "参数：报表真实代码")
    @ApiImplicitParams({ @ApiImplicitParam(name = "taskId", value = "报表真实代码", required = true),
            @ApiImplicitParam(name = "unitCode", value = "机构代码", required = true)})
    @GetMapping(value = "/queryReportBbqByTaskId/{taskId}/{unitCode}")
    public ResponseWrapper queryReportBbqByTaskId(@PathVariable("taskId") String taskId,@PathVariable("unitCode") String unitCode) {
        try {
            if(StringUtils.isNotEmpty(taskId)&&StringUtils.isNotEmpty(unitCode)){
                String bbq = taskInfoService.queryReportBbqByTaskId(taskId,unitCode);
                if(StringUtils.isEmpty(bbq)){
                    return ResponseWrapper.error(500, "获取指定报表新增报表期失败",null);
                }else{
                    return ResponseWrapper.success(200, "获取指定报表新增报表期成功", bbq);
                }
            }else{
                return ResponseWrapper.error(320, "参数为空",null);
            }
        } catch (Exception e) {
            log.error("获取指定报表新增报表期失败：" + e.getMessage());
            return ResponseWrapper.error(500, "获取指定报表新增报表期失败",null);
        }
    }
    /**
     * 指定机构指定报表上报信息
     * @param rptListFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-03-30 14:39:44
     * @version v1.0
     */
    @ApiOperation(value = "指定机构指定报表上报信息", notes = "参数：报表真实代码,机构代码")
    @PostMapping(value = "/findAllRptInfo")
    public ResponseWrapper findAllRptInfo(@RequestBody RptListFilterVO rptListFilterVO) {
        try {
            if(StringUtils.isNotEmpty(rptListFilterVO.getRptId())&&StringUtils.isNotEmpty(rptListFilterVO.getUnitCode())){
                List<RptListVO> list= taskInfoService.findAllRptInfo(rptListFilterVO);
                return ResponseWrapper.success(200, "指定机构指定报表上报信息查询成功", list);
            }else{
                return ResponseWrapper.error(320, "指定机构指定报表上报信息查询失败、必填参数为空",null);
            }
        } catch (Exception e) {
        	
        	System.out.println(e.getMessage());
        	
            log.error("指定机构指定报表上报信息查询失败：" + e.getMessage());
            return ResponseWrapper.error(500, "指定机构指定报表上报信息查询失败",null);
        }
    }

    /**
     * 指定机构指定报表上报信息---上集集团
     * @param rptListFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-03-30 14:39:44
     * @version v1.0
     */
    @ApiOperation(value = "指定机构指定报表上报信息---上集集团", notes = "参数：报表真实代码,机构代码")
    @PostMapping(value = "/findAllRptInfoShangJiJiTuan")
    public ResponseWrapper findAllRptInfoShangJiJiTuan(@RequestBody RptListFilterVO rptListFilterVO) {
        try {
            if(StringUtils.isNotEmpty(rptListFilterVO.getRptId())&&StringUtils.isNotEmpty(rptListFilterVO.getUnitCodeJt())){
                List<RptListVO> list= taskInfoService.findAllRptInfoShangJiJiTuan(rptListFilterVO);
                return ResponseWrapper.success(200, "指定机构指定报表上报信息查询成功", list);
            }else{
                return ResponseWrapper.error(320, "指定机构指定报表上报信息查询失败、必填参数为空",null);
            }
        } catch (Exception e) {
            log.error("指定机构指定报表上报信息查询失败：" + e.getMessage());
            return ResponseWrapper.error(500, "指定机构指定报表上报信息查询失败",null);
        }
    }




    /**
     * 指定报表指定报表期上报信息
     * @param rptListFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-04-30 14:45:33
     * @version v1.0
     */
    @ApiOperation(value = "指定报表指定报表期上报信息", notes = "参数：报表真实代码,报表期、用户账号")
    @PostMapping(value = "/findRptInfoByBbqAndRptId")
    public ResponseWrapper findRptInfoByBbqAndRptId(@RequestBody RptListFilterVO rptListFilterVO) {
        try {
            if(StringUtils.isNotEmpty(rptListFilterVO.getRptId())&&StringUtils.isNotEmpty(rptListFilterVO.getBbq())){
                List<RptListVO> list= taskInfoService.findRptInfoByBbqAndRptId(rptListFilterVO);
                return ResponseWrapper.success(200, "指定报表指定报表期上报信息查询成功", list);
            }else{
                return ResponseWrapper.error(320, "指定报表指定报表期上报信息查询失败、必填参数为空",null);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("指定报表指定报表期上报信息查询失败：" + e.getMessage());
            return ResponseWrapper.error(500, "指定报表指定报表期上报信息查询失败",null);
        }
    }
    /**
     * 根据报表期、报表真实代码、机构代码查询对应报表填报或办理链接
     * @param baseFilterVO
     * @return ResponseWrapper
     * @author liyb
     * @date 2019-05-07 13:46:36
     * @version v1.0
     */
    @ApiOperation(value = "根据基本条件查询对应报表填报或办理链接", notes = "参数：报表真实代码,报表期、机构代码")
    @PostMapping(value = "/findUrlByCondition")
    public ResponseWrapper findUrlByCondition(@RequestBody BaseFilterVO baseFilterVO,@RequestParam("pwd")String pwd) {
        try {
            if(StringUtils.isNotEmpty(baseFilterVO.getRptId())&&StringUtils.isNotEmpty(baseFilterVO.getBbq())&&StringUtils.isNotEmpty(baseFilterVO.getUnitCode())){
                String url= taskInfoService.findUrlByCondition(baseFilterVO,pwd);
                return ResponseWrapper.success(200, "根据基本条件查询对应报表填报或办理链接查询成功", url);
            }else{
                return ResponseWrapper.error(320, "根据基本条件查询对应报表填报或办理链接查询失败、必填参数为空",null);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("根据基本条件查询对应报表填报或办理链接查询失败：" + e.getMessage());
            return ResponseWrapper.error(500, "根据基本条件查询对应报表填报或办理链接查询失败",null);
        }
    }
}
