package com.unis.ynls.irpt.server.domain;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.FinanceReportDetailVO;
import com.unis.ynls.irpt.common.VO.FinanceReportQueryVO;
import com.unis.ynls.irpt.common.VO.FinanceReportVO;
import com.unis.ynls.irpt.common.VO.rotationreport.RotationSubsidySummaryVO;
import com.unis.ynls.irpt.server.entity.FinanceReportDO;
import com.unis.ynls.irpt.server.entity.FinanceReportDetailDO;
import com.unis.ynls.irpt.server.entity.rotationreport.RotationSubsidySummaryDO;
import com.unis.ynls.irpt.server.mapper.FinanceReportDetailMapper;
import com.unis.ynls.irpt.server.mapper.FinanceReportMapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.UUID;

@Component
public class FinanceReportDomain {

    @Autowired
    private FinanceReportMapper financeReportMapper;

    @Autowired
    private FinanceReportDetailMapper financeReportDetailMapper;

    private final static String BBM_TYPE1 = "asset";//报表类型 资产负债表
    private final static String BBM_TYPE2 = "cash";//报表类型 现金流量表
    private final static String BBM_TYPE3 = "profit";//报表类型 利润表
    private final static String BBM_TYPE1_VALUE = "01";//报表类型 资产负债表01
    private final static String BBM_TYPE2_VALUE = "02";//报表类型 现金流量表02
    private final static String BBM_TYPE3_VALUE = "03";//报表类型 利润表03

    @Transactional
    public ResponseWrapper saveFinanceReport(String type, FinanceReportVO vo) {
        FinanceReportDO financeReportDO = JSONObject.parseObject(JSONObject.toJSONString(vo), FinanceReportDO.class);
        if(financeReportDO != null){

            if(StringUtils.isEmpty(getBbmValue(type))){
                return ResponseWrapper.error("报表类型错误");
            }
            FinanceReportQueryVO queryVO = new FinanceReportQueryVO();
            queryVO.setBbm(getBbmValue(type));
            queryVO.setKqdm(financeReportDO.getKqdm());
            queryVO.setBbsj(financeReportDO.getBbsj());
            List<FinanceReportDO> financeReportDOList = financeReportMapper.selectByQuery(queryVO);
            if(financeReportDOList != null && financeReportDOList.size() > 0){
                return ResponseWrapper.error("不能重复填报");
            }
            financeReportDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-",""));
            financeReportDO.setBbm(getBbmValue(type));
            financeReportDO.setCreator(CurrentUtil.getUserName());
            financeReportDO.setCreateDate(new Date());
            financeReportDO.setIsDelete(0);
            int res = financeReportMapper.insert(financeReportDO);
            if(res > 0){
                List<FinanceReportDetailDO> detailDOList = JSONObject.parseArray(JSONObject.toJSONString(vo.getDetailList()), FinanceReportDetailDO.class);
                if(detailDOList != null && detailDOList.size() > 0){
                    for (FinanceReportDetailDO detailDO : detailDOList) {
                        detailDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-",""));
                        detailDO.setMainId(financeReportDO.getId());
                    }
                    res = financeReportDetailMapper.insertBatch(detailDOList);
                    if(res > 0){
                        return ResponseWrapper.success("填报成功");
                    }
                }
            }
        }
        return ResponseWrapper.success("填报失败");
    }

    @Transactional
    public ResponseWrapper updateFinanceReport(FinanceReportVO vo) {

        FinanceReportDO financeReportDO = JSONObject.parseObject(JSONObject.toJSONString(vo), FinanceReportDO.class);
        if(financeReportDO == null){
            return ResponseWrapper.error("参数错误");
        }

        FinanceReportQueryVO queryVO = new FinanceReportQueryVO();
        queryVO.setBbm(vo.getBbm());
        queryVO.setKqdm(vo.getKqdm());
        queryVO.setBbsj(vo.getBbsj());
        List<FinanceReportDO> financeReportDOList = financeReportMapper.selectByQuery(queryVO);
        if(financeReportDOList != null && financeReportDOList.size() > 0){
            for(FinanceReportDO fr : financeReportDOList){
                if(!fr.getId().equals(financeReportDO.getId())){
                    return ResponseWrapper.error("不能数重复填报");
                }
            }
        }
        FinanceReportDO updateDO = JSONObject.parseObject(JSONObject.toJSONString(vo), FinanceReportDO.class);
        updateDO.setUpdater(CurrentUtil.getUserName());
        updateDO.setUpdateDate(new Date());
        int res = financeReportMapper.updateByPrimaryKey(updateDO);
        if(res > 0){
            List<FinanceReportDetailDO> detailDOList = JSONObject.parseArray(JSONObject.toJSONString(vo.getDetailList()), FinanceReportDetailDO.class);
            if(detailDOList != null && detailDOList.size() > 0){
                financeReportDetailMapper.deleteByMainId(financeReportDO.getId());
                for (FinanceReportDetailDO detailDO : detailDOList) {
                    detailDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-",""));
                    detailDO.setMainId(financeReportDO.getId());
                }
                res = financeReportDetailMapper.insertBatch(detailDOList);
                if(res > 0){
                    return ResponseWrapper.success("修改成功");
                }
            }else{
                return ResponseWrapper.success("修改成功");
            }
        }
        return ResponseWrapper.success("修改失败");
    }

    public PageInfo<FinanceReportVO> getFinanceReportPageList(String type, Integer pageNum, Integer pageSize, FinanceReportQueryVO queryVO) {

        String bbm = getBbmValue(type);
        if(StringUtils.isEmpty(bbm)){
            return null;
        }
        queryVO.setBbm(bbm);
        PageInfo<FinanceReportVO> pageInfoVO = new PageInfo<FinanceReportVO>();
        PageHelper.startPage(pageNum, pageSize);
        List<FinanceReportDO> list =  financeReportMapper.selectByQuery(queryVO);
        PageInfo<FinanceReportDO> pageInfoDO = new PageInfo<FinanceReportDO>(list);
        LsBeanUtils.copyAllProperties(pageInfoDO,pageInfoVO);
        return pageInfoVO ;
    }

    public FinanceReportVO getFinanceReportInfo(String id) {

        FinanceReportDO  financeReportDO = financeReportMapper.selectByPrimaryKey(id);
        if(financeReportDO != null) {
            FinanceReportVO vo = new FinanceReportVO();
            LsBeanUtils.copyAllProperties(financeReportDO,vo);
            List<FinanceReportDetailDO> detailDOList = financeReportDetailMapper.selectByMainId(id);
            List<FinanceReportDetailVO> detailVOList = new ArrayList<FinanceReportDetailVO>();
            LsBeanUtils.copyCollection(detailDOList,detailVOList,FinanceReportDetailVO.class);
            vo.setDetailList(detailVOList);
            return vo;
        }
        return null;
    }

    public int deleteFinanceReport(String id) {
        return financeReportMapper.deleteById(id);
    }
    private String getBbmValue(String bbmType){
        String bbmValue = null;
        switch (bbmType){
            case BBM_TYPE1:bbmValue = BBM_TYPE1_VALUE;break;
            case BBM_TYPE2:bbmValue = BBM_TYPE2_VALUE;break;
            case BBM_TYPE3:bbmValue = BBM_TYPE3_VALUE;break;
        }
        return bbmValue;
    }


}
