package com.unis.ynls.irpt.server.domain;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.ynls.irpt.common.VO.reservereport.*;
import com.unis.ynls.irpt.common.VO.task.TaskVO;
import com.unis.ynls.irpt.common.contast.ReserveReportConstant;
import com.unis.ynls.irpt.common.util.HelpUtils;
import com.unis.ynls.irpt.server.entity.reservereport.*;
import com.unis.ynls.irpt.server.mapper.*;
import com.unis.ynls.irpt.server.scheduledtasks.DynamicScheduledConfigurer;
import com.unis.ynls.irpt.server.service.BacklogMQService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.transaction.Transactional;
import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.IntStream;

@Component
public class ReserveReportDomain extends BaseDomain {

    @Autowired
    private PurchaseStockMapper purchaseStockMapper;

    @Autowired
    private PurchaseStockDetailMapper purchaseStockDetailMapper;

    @Autowired
    private PurchaseStockSummaryMapper purchaseStockSummaryMapper;

    @Autowired
    private StorageSubsidyMapper storageSubsidyMapper;

    @Autowired
    private StorageSubsidyDetailMapper storageSubsidyDetailMapper;

    @Autowired
    private StorageSubsidySummaryMapper storageSubsidySummaryMapper;

    @Autowired
    private StorageSubsidySummaryDetailMapper storageSubsidySummaryDetailMapper;

    @Autowired
    private StorageSubsidyStandardMapper storageSubsidyStandardMapper;

    @Autowired
    private EnterpriseMapper enterpriseMapper;

    @Autowired
    private BacklogMQService mqService;

    @Autowired
    private DynamicScheduledConfigurer dynamicScheduledConfigurer;

    //未汇总
    private final static Integer NOT_SUMMARIZED = 0;
    //已汇总
    private final static Integer HAS_SUMMARIZED = 1;
    //小麦
    private final static String PZ_XM = "1110000";
    //稻谷
    private final static String PZ_DG = "1130000";
    //大米
    private final static String PZ_DM = "2360000";
    //小麦粉
    private final static String PZ_XMF = "2310000";
    //原油
    private final static String PZ_YY = "1410000";
    //储备油
    private final static String PZ_CPY = "2120000";

    //费率启用状态:已过期
    private final static Integer SUBSIDY_STANDARD_EXPIRED = 0;
    //费率启用状态:待启用
    private final static Integer SUBSIDY_STANDARD_NO_ENABLE = 1;
    //费率启用状态:启用中
    private final static Integer SUBSIDY_STANDARD_ENABLE = 2;


    @Transactional
    public ResponseWrapper savePurchaseStock(PurchaseStockVO vo) {

        if (vo != null && vo.getDetailList() != null && vo.getDetailList().size() > 0) {
            if (StringUtils.isEmpty(vo.getPeriod()) || !validPeriod(vo.getPeriod())) {
                ResponseWrapper.error("上报期数为空或者格式错误！");
            }
            if (StringUtils.isEmpty(vo.getSskdbm()) || StringUtils.isEmpty(vo.getSskdmc())
                    || StringUtils.isEmpty(vo.getDeptCode()) || StringUtils.isEmpty(vo.getOrgCode())) {
                ResponseWrapper.error("参数为空，请确认后重试!");
            }

            String period = vo.getPeriod();
            PurchaseStockQueryVO queryVO = new PurchaseStockQueryVO();
            queryVO.setPeriod(period);
            queryVO.setOrgCode(vo.getOrgCode());
            queryVO.setSskdbm(vo.getSskdbm());
            queryVO.setSskdmc(vo.getSskdmc());
            queryVO.setSummaryStatus(vo.getSummaryStatus());
            queryVO.setDataType(vo.getDataType());

            List<PurchaseStockDO> purchaseStockDOList = purchaseStockMapper.selectByQuery(queryVO);
            if (purchaseStockDOList != null && purchaseStockDOList.size() > 0) {
                return ResponseWrapper.error("不能同一期间重复上报!");
            }
            PurchaseStockDO purchaseStockDO = new PurchaseStockDO();
            LsBeanUtils.copyAllProperties(vo, purchaseStockDO);
            if (purchaseStockDO != null) {
                String psId = UUID.randomUUID().toString().toLowerCase().replaceAll("-", "");
                purchaseStockDO.setId(psId);
                purchaseStockDO.setStatus(ReserveReportConstant.DTJ.getValue());
                purchaseStockDO.setStatusName(ReserveReportConstant.DTJ.getName());
                if (vo.getOperationType() == 1) {
                    purchaseStockDO.setStatus(ReserveReportConstant.DGZ.getValue());
                    purchaseStockDO.setStatusName(ReserveReportConstant.DGZ.getName());
                }
                purchaseStockDO.setIsDelete(0);
                int res = purchaseStockMapper.insert(purchaseStockDO);
                if (res > 0) {
                    List<PurchaseStockDetailVO> detailVOList = vo.getDetailList();
                    List<PurchaseStockDetailDO> detailList = new ArrayList<>();
                    IntStream.range(0, detailVOList.size())
                            .forEach(index -> {
                                PurchaseStockDetailVO detailVO = detailVOList.get(index);
                                PurchaseStockDetailDO detailDO = new PurchaseStockDetailDO();
                                detailDO.setPsId(psId);
                                detailDO.setSort(index + 1);
                                detailDO.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                                detailDO.setPsId(psId);
                                detailDO.setSort(index + 1);
                                detailDO.setPzbm(detailVO.getPzbm());
                                detailDO.setPzmc(detailVO.getPzmc());
                                detailDO.setInitial(detailVO.getInitial() == null ? BigDecimal.ZERO : detailVO.getInitial());
                                detailDO.setPurchase(detailVO.getPurchase() == null ? BigDecimal.ZERO : detailVO.getPurchase());
                                detailDO.setOtherIncome(detailVO.getOtherIncome() == null ? BigDecimal.ZERO : detailVO.getOtherIncome());
                                detailDO.setIncomeTotal(detailVO.getIncomeTotal() == null ? BigDecimal.ZERO : detailVO.getIncomeTotal());
                                detailDO.setSale(detailVO.getSale() == null ? BigDecimal.ZERO : detailVO.getSale());
                                detailDO.setLoss(detailVO.getLoss() == null ? BigDecimal.ZERO : detailVO.getLoss());
                                detailDO.setOtherExpense(detailVO.getOtherExpense() == null ? BigDecimal.ZERO : detailVO.getOtherExpense());
                                detailDO.setExpenseTotal(detailVO.getExpenseTotal() == null ? BigDecimal.ZERO : detailVO.getExpenseTotal());
                                detailDO.setEnding(detailVO.getEnding() == null ? BigDecimal.ZERO : detailVO.getEnding());
                                detailDO.setTypeCode(detailVO.getTypeCode());

                                detailList.add(detailDO);
                            });
                    /*detailVOList.forEach(detailVO->{
                        PurchaseStockDetailDO detailDO = new PurchaseStockDetailDO();
                        LsBeanUtils.copyAllProperties(detailList.get(index),detailDO);
                        detailDO.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                        detailDO.setPsId(psId);
                        detailList.add(detailDO);
                    });*/
                    if (detailList == null || detailList.size() == 0) {
                        throw new RuntimeException("ReserveReportDomain.savePurchaseStock{}:detailVOList is null");
                    }
                    int res1 = purchaseStockDetailMapper.insertList(detailList);
                    if (res1 > 0) {
                        return ResponseWrapper.success("填报成功!");
                    } else {
                        return ResponseWrapper.error();
                    }
                }
            }
        }
        return ResponseWrapper.invalid();
    }

    public Boolean validPeriod(String period) {
        //正则校验 yyyy年MM月
        String pattern = "^\\d{4}年\\d{2}月$";
        return period.matches(pattern);
    }

    public ResponseWrapper getPeriod(PurchaseStockQueryVO queryVO) {
        //判断查询必传参数
        if (queryVO != null || StringUtils.isNotEmpty(queryVO.getSskdbm())) {

            Calendar calendar = Calendar.getInstance();
            int year = calendar.get(Calendar.YEAR);
            //int month = calendar.get(Calendar.MONTH) + 1;
            int day = 15;
            int periodYear = year;
            int periodMonth = calendar.get(Calendar.MONTH) + 1;
            List<PurchaseStockDO> purchaseStockDOList = purchaseStockMapper.selectByQuery(queryVO);
            if (purchaseStockDOList != null && purchaseStockDOList.size() > 0) {
                PurchaseStockDO stockDO = purchaseStockDOList.stream().max((o1, o2) -> o1.getPeriod().compareTo(o2.getPeriod())).get();
                String maxPeriod = stockDO.getPeriod();
                int maxPeriodYear = Integer.parseInt(maxPeriod.substring(0, 4));
                int maxPeriodMonth = Integer.parseInt(maxPeriod.substring(5, 7));

                //已上报期与当前年份比较，
//                if (maxPeriodYear < year) {
//                    periodYear = maxPeriodYear;
//                    periodMonth = maxPeriodMonth + 1;
//                } else if (maxPeriodYear == year) {
//
//                    periodMonth = maxPeriodMonth + 1;
//
//                } else {
//                    ResponseWrapper.error("获取上报期数错误！");
//                }
                if (maxPeriodMonth < 12) {
                    periodYear = maxPeriodYear;
                    periodMonth = maxPeriodMonth + 1;
                } else {
                    periodYear = maxPeriodYear + 1;
                    periodMonth = 1;
                }
            }

            calendar.set(Calendar.YEAR, periodYear);
            calendar.set(Calendar.MONTH, periodMonth - 1);
            int maxDayOfMonth = calendar.getActualMaximum(Calendar.DAY_OF_MONTH); // 获取该月的最大天数
            if (day > maxDayOfMonth) {
                day = maxDayOfMonth;
            }
            calendar.set(Calendar.DAY_OF_MONTH, day); // 设置日期为指定的日期
            Date periodDate = calendar.getTime();
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月");

            return ResponseWrapper.success(200, "获取成功！", sdf.format(periodDate));

        }
        return ResponseWrapper.error("获取上报期数错误！");
    }

    @Transactional
    public ResponseWrapper updatePurchaseStock(Integer type, PurchaseStockVO vo) {

        if (vo == null || StringUtils.isEmpty(vo.getId())) {
            return ResponseWrapper.invalid();
        }
        PurchaseStockDO originDO = purchaseStockMapper.selectById(vo.getId());
        if (originDO != null) {
            //修改
            if (type == 1 && (ReserveReportConstant.DTJ.getValue().equals(originDO.getStatus())
                    || ReserveReportConstant.DGZ.getValue().equals(originDO.getStatus())
                    || ReserveReportConstant.GZBH.getValue().equals(originDO.getStatus()))) {
                PurchaseStockDO updateDO = JSONObject.parseObject(JSONObject.toJSONString(vo), PurchaseStockDO.class);
                if (vo.getOperationType() == 1) {
                    updateDO.setStatus(ReserveReportConstant.DGZ.getValue());
                    updateDO.setStatusName(ReserveReportConstant.DGZ.getName());
                }
                int res = purchaseStockMapper.updateByPrimaryKey(updateDO);
                if (res > 0) {
                    List<PurchaseStockDetailDO> detailList = JSONObject.parseArray(JSONObject.toJSONString(vo.getDetailList()), PurchaseStockDetailDO.class);
                    if (detailList != null && detailList.size() > 0) {
                        purchaseStockDetailMapper.deleteByPsId(updateDO.getId());
                        detailList.forEach(d -> {
                            d.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                            d.setPsId(updateDO.getId());
                        });
                        int res2 = purchaseStockDetailMapper.insertList(detailList);
                        if (res2 > 0) {
                            return ResponseWrapper.success("修政成功！");
                        } else {
                            return ResponseWrapper.error("修政失败！");
                        }
                    }
                    return ResponseWrapper.success("修改成功！");
                }
            } else if (type == 2 && (ReserveReportConstant.DGZ.getValue().equals(originDO.getStatus())
                    || ReserveReportConstant.JSBH.getValue().equals(originDO.getStatus()))) {

                originDO.setSignature(vo.getSignature());
                originDO.setSignatureDate(vo.getSignatureDate());
                originDO.setSignatureStatus(vo.getSignatureStatus());
                if (vo.getSignatureStatus() == 1 && StringUtils.isNotEmpty(vo.getSignature())) {
                    originDO.setStatus(ReserveReportConstant.DJS.getValue());
                    originDO.setStatusName(ReserveReportConstant.DJS.getName());
                } else if (vo.getSignatureStatus() == 0) {
                    originDO.setStatus(ReserveReportConstant.GZBH.getValue());
                    originDO.setStatusName(ReserveReportConstant.GZBH.getName());
                }
            } else if (type == 3 && ReserveReportConstant.DJS.getValue().equals(originDO.getStatus())) {
                originDO.setReceiver(vo.getReceiver());
                originDO.setReceiveStatus(vo.getReceiveStatus());
                originDO.setReceiveDate(vo.getReceiveDate());
                originDO.setReceiver(vo.getReceiver());
                originDO.setReceiveOpinion(vo.getReceiveOpinion());
                if (vo.getReceiveStatus() == 1) {
                    originDO.setStatus(ReserveReportConstant.YJS.getValue());
                    originDO.setStatusName(ReserveReportConstant.YJS.getName());
                } else if (vo.getReceiveStatus() == 0) {
                    originDO.setStatus(ReserveReportConstant.JSBH.getValue());
                    originDO.setStatusName(ReserveReportConstant.JSBH.getName());
                }
                //管理端撤销接收，状态变为”待提交“
            } else if (type == 4 && ReserveReportConstant.YJS.getValue().equals(originDO.getStatus())) {
                originDO.setStatus(ReserveReportConstant.DJS.getValue());
                originDO.setStatusName(ReserveReportConstant.DJS.getName());
            } else {
                return ResponseWrapper.invalid();
            }
            int res = purchaseStockMapper.updateByPrimaryKey(originDO);
            if (res > 0) {
                return ResponseWrapper.success("修政成功！");
            }
            return ResponseWrapper.error("修政失败！");

        }
        return ResponseWrapper.invalid();
    }

    public PageInfo<PurchaseStockVO> getPurchaseStockPageList(Integer pageNum, Integer pageSize, PurchaseStockQueryVO queryVO) {

        PageHelper.startPage(pageNum, pageSize);
        List<PurchaseStockVO> list = purchaseStockMapper.selectPurchaseStockVOByQuery(queryVO);
        PageInfo<PurchaseStockVO> pageInfo = new PageInfo<PurchaseStockVO>(list);
        return pageInfo;

    }

    public PageInfo<PurchaseStockVO> getPurchaseStockList(Integer pageNum, Integer pageSize, PurchaseStockQueryVO queryVO) {
        PageHelper.startPage(pageNum, pageSize);
        List<PurchaseStockVO> list = purchaseStockMapper.selectListByQuery(queryVO);
        if (queryVO.getPeriod() == null) {
            list.stream().forEach(vo -> {
                if (vo.getStatusName().equals("未上报")) {
                    vo.setPeriod("2023年01月");
                }
            });
        } else {
            list.stream().forEach(vo -> {
                if (vo.getStatusName().equals("未上报")) {
                    vo.setPeriod(queryVO.getPeriod());
                }
            });
        }
        PageInfo<PurchaseStockVO> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    public PurchaseStockVO getPurchaseStockInfo(String psId) {
        PurchaseStockDO purchaseStockDO = purchaseStockMapper.selectById(psId);
        if (purchaseStockDO != null) {
            PurchaseStockVO vo = JSONObject.parseObject(JSONObject.toJSONString(purchaseStockDO), PurchaseStockVO.class);
            List<PurchaseStockDetailDO> detailList = purchaseStockDetailMapper.selectByPsId(psId);
            if (detailList != null && detailList.size() > 0) {
                List<PurchaseStockDetailVO> detailVOList = JSONObject.parseArray(JSONObject.toJSONString(detailList), PurchaseStockDetailVO.class);
                vo.setDetailList(detailVOList);
            }
            return vo;
        }
        return null;
    }

    public PurchaseStockSummaryVO generatePurchaseStockSummary(Integer dataType) {
        PurchaseStockSummaryVO vo = new PurchaseStockSummaryVO();
        String period = purchaseStockSummaryMapper.selectByDataType(dataType);
        if (period == null) {
            DateTimeFormatter mm = DateTimeFormatter.ofPattern("MM");
            period = LocalDate.now().getYear() + "年" + mm.format(LocalDate.now()) + "月";
        } else {
            period = getNextPeriod(period);
        }

        vo.setPeriod(period);
        vo.setDataType(dataType);
        PurchaseStockQueryVO queryVO = new PurchaseStockQueryVO();
        queryVO.setPeriod(period);
        queryVO.setDataType(dataType);
        queryVO.setSummaryStatus(NOT_SUMMARIZED);
        List<PurchaseStockDetailDO> detailDOList = purchaseStockDetailMapper.selectSummaryByQuery(queryVO);
        if (detailDOList != null && detailDOList.size() > 0) {
            List<PurchaseStockDetailVO> detailVOList = JSONObject.parseArray(JSONObject.toJSONString(detailDOList), PurchaseStockDetailVO.class);
            vo.setDetailList(detailVOList);
        }
        return vo;
    }

    public ResponseWrapper savePurchaseStockSummary(PurchaseStockSummaryVO summaryVO) {

        if (summaryVO != null && StringUtils.isNotEmpty(summaryVO.getPeriod())) {

            PurchaseStockQueryVO queryVO = new PurchaseStockQueryVO();
            queryVO.setPeriod(summaryVO.getPeriod());
            queryVO.setDataType(summaryVO.getDataType());

            List<PurchaseStockSummaryDO> summaryDOList = purchaseStockSummaryMapper.selectByQuery(queryVO);
            if (summaryDOList != null && summaryDOList.size() > 0) {
                return ResponseWrapper.error("不能同一期间重复汇总");
            }
            PurchaseStockSummaryDO summaryDO = JSONObject.parseObject(JSONObject.toJSONString(summaryVO), PurchaseStockSummaryDO.class);
            if (summaryDO != null) {
                String id = UUID.randomUUID().toString().toLowerCase().replaceAll("-", "");
                summaryDO.setId(id);
                summaryDO.setCreateDate(new Date());
                summaryDO.setTabulatorDate(summaryDO.getTabulatorDate());
                if (summaryVO.getOperationType() != null && summaryVO.getOperationType() == 0) {
                    summaryDO.setStatus(ReserveReportConstant.DTJSH.getValue());
                    summaryDO.setStatusName(ReserveReportConstant.DTJSH.getName());
                } else {
                    summaryDO.setStatus(ReserveReportConstant.DFH.getValue());
                    summaryDO.setStatusName(ReserveReportConstant.DFH.getName());
                }
                summaryDO.setIsDelete(0);
                int res = purchaseStockSummaryMapper.insert(summaryDO);
                if (res > 0) {
                    //更新上报数据表汇总状态：已汇总
                    purchaseStockMapper.updateSummaryStatus(summaryDO.getPeriod(), HAS_SUMMARIZED);
                    return ResponseWrapper.success("填报成功!");
                } else {
                    return ResponseWrapper.error();
                }
            }
        }
        return ResponseWrapper.invalid();
    }

    public PageInfo<PurchaseStockSummaryVO> getPurchaseStockSummaryPageList(Integer pageNum, Integer pageSize, PurchaseStockQueryVO queryVO) {


        PageHelper.startPage(pageNum, pageSize);
        List<PurchaseStockSummaryDO> list = purchaseStockSummaryMapper.selectByQuery(queryVO);
        List<PurchaseStockSummaryVO> volist = new ArrayList<>();
        LsBeanUtils.copyCollection(list, volist, PurchaseStockSummaryVO.class);
        if (volist != null && volist.size() > 0) {
            /*List<String> xmPzbmList = purchaseStockDetailMapper.selectChildByPzbm(PZ_XM);*/

            for (PurchaseStockSummaryVO summaryVO : volist) {
                PurchaseStockQueryVO queryDetailVO = new PurchaseStockQueryVO();
                queryDetailVO.setDataType(summaryVO.getDataType());
                queryDetailVO.setPeriod(summaryVO.getPeriod());
                queryDetailVO.setSummaryStatus(HAS_SUMMARIZED);

                List<PurchaseStockDetailDO> detailDOList = purchaseStockDetailMapper.selectSummaryByQuery(queryDetailVO);
                BigDecimal initial = BigDecimal.ZERO;
                BigDecimal incomeTotal = BigDecimal.ZERO;
                BigDecimal expenseTotal = BigDecimal.ZERO;
                BigDecimal ending = BigDecimal.ZERO;
                if (detailDOList != null && detailDOList.size() > 0) {
                    initial = detailDOList.get(0).getInitial();
                    incomeTotal = detailDOList.get(0).getIncomeTotal();
                    expenseTotal = detailDOList.get(0).getExpenseTotal();
                    ending = detailDOList.get(0).getEnding();
                }
                summaryVO.setInitial(initial);
                summaryVO.setIncomeTotal(incomeTotal);
                summaryVO.setExpenseTotal(expenseTotal);
                summaryVO.setEnding(ending);
            }
        }
        return new PageInfo<PurchaseStockSummaryVO>(volist);
    }

    public PurchaseStockSummaryVO getPurchaseStockSummaryInfo(PurchaseStockQueryVO queryVO) {
        //根据 汇总数据 类型和汇总期查询 汇总记录
        List<PurchaseStockSummaryDO> summaryDOList = purchaseStockSummaryMapper.selectByQuery(queryVO);
        if (summaryDOList != null && summaryDOList.size() > 0) {
            PurchaseStockSummaryDO summaryDO = summaryDOList.get(0);
            PurchaseStockSummaryVO vo = JSONObject.parseObject(JSONObject.toJSONString(summaryDO), PurchaseStockSummaryVO.class);
            PurchaseStockQueryVO queryDetailVO = new PurchaseStockQueryVO();
            queryDetailVO.setDataType(vo.getDataType());
            queryDetailVO.setPeriod(vo.getPeriod());
            queryDetailVO.setSummaryStatus(HAS_SUMMARIZED);
            List<PurchaseStockDetailDO> summaryDetailDOList = purchaseStockDetailMapper.selectSummaryByQuery(queryDetailVO);
            if (summaryDetailDOList != null && summaryDetailDOList.size() > 0) {
                List<PurchaseStockDetailVO> detailVOList = JSONObject.parseArray(JSONObject.toJSONString(summaryDetailDOList), PurchaseStockDetailVO.class);
                vo.setDetailList(detailVOList);
                return vo;
            }
        }
        return null;
    }

    public ResponseWrapper saveStorageSubsidyStandard(StorageSubsidyStandardVO standardVO) {
        if (standardVO != null && standardVO.getStandard() != null) {
            StorageSubsidyStandardDO standardDO = JSONObject.parseObject(JSONObject.toJSONString(standardVO), StorageSubsidyStandardDO.class);
            standardDO.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
            standardDO.setCreateDate(new Date());
            standardDO.setCreator(CurrentUtil.getUserName());
            standardDO.setIsDelete(0);
            standardDO.setIsEnable(SUBSIDY_STANDARD_NO_ENABLE);
            int res = storageSubsidyStandardMapper.insert(standardDO);
            if (res > 0) {
                TaskVO taskVO = new TaskVO();
                taskVO.setName(standardDO.getId());
                taskVO.setStartTime(standardDO.getStartDate());
                dynamicScheduledConfigurer.add(taskVO);
                return ResponseWrapper.success();
            }
        }
        return ResponseWrapper.invalid();
    }

    @Transactional
    public int enableStorageSubsidy(String id) {
        int res = 0;
        StorageSubsidyStandardDO standardDO = storageSubsidyStandardMapper.selectByPrimaryKey(id);
        if (standardDO != null) {
            StorageSubsidyStandardQueryVO queryVO = new StorageSubsidyStandardQueryVO();
            queryVO.setTypeCode(standardDO.getTypeCode());
            queryVO.setPzbm(standardDO.getPzbm());
            queryVO.setPzmc(standardDO.getPzmc());
            queryVO.setIsEnable(SUBSIDY_STANDARD_ENABLE);
            List<StorageSubsidyStandardDO> enableStandardDOList = storageSubsidyStandardMapper.selectByQuery(queryVO);
            if (enableStandardDOList != null && enableStandardDOList.size() > 0) {
                for (StorageSubsidyStandardDO standardDO1 : enableStandardDOList) {
                    standardDO1.setIsEnable(SUBSIDY_STANDARD_EXPIRED);
                    standardDO1.setEndDate(new Date());
                    storageSubsidyStandardMapper.updateByPrimaryKeySelective(standardDO1);
                }
            }
            standardDO.setIsEnable(SUBSIDY_STANDARD_ENABLE);
            res = storageSubsidyStandardMapper.updateByPrimaryKeySelective(standardDO);
        }
        return res;
    }

    public ResponseWrapper updateStorageSubsidyStandard(StorageSubsidyStandardVO standardVO) {
        StorageSubsidyStandardDO standardDO = JSONObject.parseObject(JSONObject.toJSONString(standardVO), StorageSubsidyStandardDO.class);
        standardDO.setUpdater(CurrentUtil.getUserName());
        standardDO.setUpdateDate(new Date());
        int res = storageSubsidyStandardMapper.updateByPrimaryKeySelective(standardDO);
        if (res > 0) {
            TaskVO taskVO = new TaskVO();
            taskVO.setName(standardDO.getId());
            taskVO.setStartTime(standardDO.getStartDate());
            dynamicScheduledConfigurer.add(taskVO);
            return ResponseWrapper.success();
        }
        return ResponseWrapper.invalid();
    }

    public PageInfo<StorageSubsidyStandardVO> getStorageSubsidyStandardPageList(Integer pageNum, Integer pageSize, StorageSubsidyStandardQueryVO queryVO) {

        PageInfo<StorageSubsidyStandardVO> pageInfoVO = new PageInfo<StorageSubsidyStandardVO>();
        PageHelper.startPage(pageNum, pageSize);
        List<StorageSubsidyStandardDO> list = storageSubsidyStandardMapper.selectByQuery(queryVO);
        PageInfo<StorageSubsidyStandardDO> pageInfoDO = new PageInfo<StorageSubsidyStandardDO>(list);
        LsBeanUtils.copyAllProperties(pageInfoDO, pageInfoVO);
        return pageInfoVO;
    }

    public List<StorageSubsidyStandardVO> getStorageSubsidyStandardList(StorageSubsidyStandardQueryVO queryVO) {
        List<StorageSubsidyStandardDO> list = storageSubsidyStandardMapper.selectByQuery(queryVO);
        EnterpriseQueryVO enterpriseQueryVO = new EnterpriseQueryVO();
        enterpriseQueryVO.setCcqybm(queryVO.getTyshxydm());
        List<EnterpriseDO> enterpriseDOS = enterpriseMapper.selectByQuery(enterpriseQueryVO);
        List<StorageSubsidyStandardDO> collect = list.stream().filter(standardDO -> enterpriseDOS.stream().anyMatch(enterpriseDO -> Objects.equals(standardDO.getTypeCode(), enterpriseDO.getBtbzlx()))).collect(Collectors.toList());
        List<StorageSubsidyStandardVO> voList = JSONObject.parseArray(JSONObject.toJSONString(collect), StorageSubsidyStandardVO.class);
        if (voList != null && voList.size() > 0) {
            // 判断voList的typeCode是否含有02或者12,如果存在，将queryVO的sfyd设置成1
            List<String> typeCodeList = voList.stream().map(StorageSubsidyStandardVO::getTypeCode).collect(Collectors.toList());
            if (typeCodeList.contains("02") || typeCodeList.contains("12")) {
                queryVO.setSfyd("1");
            }
        }
        return voList;
    }

    public String getStorageSubsidyPeriod(StorageSubsidyQueryVO queryVO) {

        Calendar calendar = Calendar.getInstance();
        int year = calendar.get(Calendar.YEAR);
        // int month = calendar.get(Calendar.MONTH) + 1;
        int day = 15;
        int periodYear = year;
        int periodMonth = calendar.get(Calendar.MONTH) + 1;
        //获取最后一次上报的期数
        List<StorageSubsidyDO> storageSubsidyDOList = storageSubsidyMapper.selectByQuery(queryVO);
        if (storageSubsidyDOList != null && storageSubsidyDOList.size() > 0) {
            String maxPeriod = storageSubsidyDOList.stream().max((o1, o2) -> o1.getPeriod().compareTo(o2.getPeriod())).get().getPeriod();
            int maxPeriodYear = Integer.parseInt(maxPeriod.substring(0, 4));
            int maxPeriodMonth = Integer.parseInt(maxPeriod.substring(5, 7));

            //已上报期与当前年份比较，
          /*  if(maxPeriodYear < year){
                periodYear = maxPeriodYear;
                periodMonth = maxPeriodMonth + 1;
            }else if(maxPeriodYear == year){
                //补贴本月上报上一个月，
               if((maxPeriodMonth + 1) <= month){
                   periodMonth = maxPeriodMonth + 1;
               }
            }else{
                return null;
            }*/
            //填报期数,不设限制
            if (maxPeriodMonth < 12) {
                periodYear = maxPeriodYear;
                periodMonth = maxPeriodMonth + 1;
            } else {
                periodYear = maxPeriodYear + 1;
                periodMonth = 1;
            }
        }
        calendar.set(Calendar.YEAR, periodYear);
        calendar.set(Calendar.MONTH, periodMonth - 1);
        int maxDayOfMonth = calendar.getActualMaximum(Calendar.DAY_OF_MONTH); // 获取该月的最大天数
        if (day > maxDayOfMonth) {
            day = maxDayOfMonth;
        }
        calendar.set(Calendar.DAY_OF_MONTH, day); // 设置日期为指定的日期
        Date periodDate = calendar.getTime();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月");

        return sdf.format(periodDate);
    }

    public List<PurchaseStockDetailVO> getPreviousStock(PurchaseStockQueryVO queryVO) {
        //根据查询期数获取上期期数
        String period = queryVO.getPeriod();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月");
        Date periodDate = null;
        try {
            periodDate = sdf.parse(period);
        } catch (ParseException e) {
            throw new RuntimeException("ReserveReportDomain.getPreviousStock{}:上期期数格式错误," + e);
        }
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(periodDate);
        calendar.add(Calendar.MONTH, -1);
        Date previousPeriodDate = calendar.getTime();
        String previousPeriod = sdf.format(previousPeriodDate);
        queryVO.setPeriod(previousPeriod);
        List<PurchaseStockDetailVO> purchaseStockDetailVOS = purchaseStockDetailMapper.selectPreviousStock(queryVO);
        return purchaseStockDetailVOS.stream().filter(it -> !it.getPzbm().equals("1410000") && !it.getPzbm().equals("2120000")).collect(Collectors.toList());
    }

    @Transactional
    public ResponseWrapper saveStorageSubsidy(StorageSubsidyVO vo) {
        //判断是否已经上报过
        StorageSubsidyDO subsidyDO = JSONObject.parseObject(JSONObject.toJSONString(vo), StorageSubsidyDO.class);
        subsidyDO.setIsDelete(0);
        subsidyDO.setSummaryStatus(NOT_SUMMARIZED);
        StorageSubsidyQueryVO queryVO = new StorageSubsidyQueryVO();
        queryVO.setSskdbm(vo.getSskdbm());
        queryVO.setDataType(vo.getDataType());
        queryVO.setPeriod(vo.getPeriod());
        List<StorageSubsidyDO> list = storageSubsidyMapper.selectByQuery(queryVO);
        if (list != null && list.size() > 0) {
            return ResponseWrapper.error("不能重复上报！");
        }
        String ssId = UUID.randomUUID().toString().toLowerCase().replaceAll("-", "");
        subsidyDO.setId(ssId);
        subsidyDO.setStatus(ReserveReportConstant.DTJ.getValue());
        subsidyDO.setStatusName(ReserveReportConstant.DTJ.getName());
        if (vo.getOperationType() == 1) {
            subsidyDO.setStatus(ReserveReportConstant.DGZ.getValue());
            subsidyDO.setStatusName(ReserveReportConstant.DGZ.getName());
        }
        subsidyDO.setCreateDate(new Date());
        int res = storageSubsidyMapper.insert(subsidyDO);
        if (res > 0) {
            List<StorageSubsidyDetailVO> detailVOList = vo.getDetailList();
            List<StorageSubsidyDetailDO> detailDOList = JSONObject.parseArray(JSONObject.toJSONString(detailVOList), StorageSubsidyDetailDO.class);

            if (detailDOList != null && detailDOList.size() > 0) {
                /*detailDOList.forEach(d -> {
                    d.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                    d.setSsId(ssId);
                });*/
                IntStream.range(0, detailDOList.size())
                        .forEach(index -> {
                            StorageSubsidyDetailDO detailDO = detailDOList.get(index);
                            detailDO.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                            detailDO.setSsId(ssId);
                            if (detailDO.getPzmc().equals("储备粮油合计")) {
                                detailDO.setSort(1);
                            }
                        });
                res = storageSubsidyDetailMapper.insertList(detailDOList);
                if (res > 0) {
                    return ResponseWrapper.success("填报成功!");
                }
            }
        }
        return ResponseWrapper.error("上报失败！");
    }

    @Transactional
    public ResponseWrapper updateStorageSubsidy(Integer type, StorageSubsidyVO vo) {
        //根据Id获取原来的数据
        StorageSubsidyDO subsidyDO = storageSubsidyMapper.selectById(vo.getId());
        if (subsidyDO != null && subsidyDO.getIsDelete() == 0) {
            //修改，判断状态为待盖章与盖章驳回
            if (type == 1) {
                if (ReserveReportConstant.DTJ.getValue().equals(subsidyDO.getStatus()) || ReserveReportConstant.DGZ.getValue().equals(subsidyDO.getStatus()) || ReserveReportConstant.GZBH.getValue().equals(subsidyDO.getStatus())) {
                    subsidyDO.setPeriod(vo.getPeriod());
                    subsidyDO.setLeader(vo.getLeader());
                    subsidyDO.setAuditor(vo.getAuditor());
                    subsidyDO.setReporter(vo.getReporter());
                    subsidyDO.setReportDate(vo.getReportDate());
                    subsidyDO.setRemark(vo.getRemark());
                    subsidyDO.setUpdater(vo.getUpdater());
                    subsidyDO.setUpdateDate(new Date());
                    if (vo.getOperationType() == 1) {
                        subsidyDO.setStatus(ReserveReportConstant.DGZ.getValue());
                        subsidyDO.setStatusName(ReserveReportConstant.DGZ.getName());
                    }
                    int res = storageSubsidyMapper.updateByPrimaryKey(subsidyDO);
                    if (res > 0) {
                        if (vo.getDetailList() != null && vo.getDetailList().size() > 0) {
                            storageSubsidyDetailMapper.deleteBySsId(vo.getId());

                            List<StorageSubsidyDetailDO> detailDOList = JSONObject.parseArray(JSONObject.toJSONString(vo.getDetailList()), StorageSubsidyDetailDO.class);
                            detailDOList.forEach(d -> {
                                d.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                                d.setSsId(vo.getId());
                            });
                            res = storageSubsidyDetailMapper.insertList(detailDOList);
                            if (res > 0) {
                                return ResponseWrapper.success("修改成功！");
                            } else {
                                return ResponseWrapper.error("修改失败！");
                            }
                        } else {
                            return ResponseWrapper.success("修改成功！");
                        }
                    }
                }
            } else if (type == 2) {
                if (ReserveReportConstant.DGZ.getValue().equals(subsidyDO.getStatus())
                        || ReserveReportConstant.GZBH.getValue().equals(subsidyDO.getStatus())
                        || ReserveReportConstant.JSBH.getValue().equals(subsidyDO.getStatus())) {

                    subsidyDO.setSignatureStatus(vo.getSignatureStatus());
                    subsidyDO.setSignatureUsername(vo.getSignatureUsername());
                    subsidyDO.setSignatureDate(vo.getSignatureDate());

                    if (vo.getSignatureStatus() == 1 && StringUtils.isNotEmpty(vo.getSignature())) {
                        subsidyDO.setSignature(vo.getSignature());
                        subsidyDO.setStatus(ReserveReportConstant.DJS.getValue());
                        subsidyDO.setStatusName(ReserveReportConstant.DJS.getName());
                    } else if (vo.getSignatureStatus() == 0) {
                        subsidyDO.setStatus(ReserveReportConstant.GZBH.getValue());
                        subsidyDO.setStatusName(ReserveReportConstant.GZBH.getName());
                    }
                }
            } else if (type == 3) {
                //判断接收状态
                if (ReserveReportConstant.DJS.getValue().equals(subsidyDO.getStatus())) {
                    subsidyDO.setReceiveStatus(vo.getReceiveStatus());
                    subsidyDO.setReceiver(vo.getReceiver());
                    subsidyDO.setReceiveDate(vo.getReceiveDate());
                    subsidyDO.setReceiveOpinion(vo.getReceiveOpinion());
                    if (vo.getReceiveStatus() == 1) {
                        subsidyDO.setStatus(ReserveReportConstant.YJS.getValue());
                        subsidyDO.setStatusName(ReserveReportConstant.YJS.getName());
                    } else if (vo.getReceiveStatus() == 0) {
                        subsidyDO.setStatus(ReserveReportConstant.JSBH.getValue());
                        subsidyDO.setStatusName(ReserveReportConstant.JSBH.getName());
                    }
                }
            } else if (type == 4) {
                if (ReserveReportConstant.YJS.getValue().equals(subsidyDO.getStatus())) {
                    subsidyDO.setStatus(ReserveReportConstant.DJS.getValue());
                    subsidyDO.setStatusName(ReserveReportConstant.DJS.getName());
                }
            } else {
                return ResponseWrapper.invalid();
            }
            int res = storageSubsidyMapper.updateByPrimaryKey(subsidyDO);
            if (res > 0) {
                return ResponseWrapper.success("操作成功！");
            }
            return ResponseWrapper.error("操作失败！");
        }
        return ResponseWrapper.invalid();
    }

    public PageInfo<StorageSubsidyVO> getStorageSubsidyPageList(Integer pageNum, Integer pageSize, StorageSubsidyQueryVO queryVO) {

        PageHelper.startPage(pageNum, pageSize);
        List<StorageSubsidyDO> list = storageSubsidyMapper.selectByQuery(queryVO);
        List<StorageSubsidyVO> voList = new ArrayList<>();
        LsBeanUtils.copyCollection(list, voList, StorageSubsidyVO.class);
        voList.forEach(vo -> {
            List<StorageSubsidyDetailDO> detailDOList = storageSubsidyDetailMapper.selectBySsId(vo.getId());
            BigDecimal syyqmkc = BigDecimal.ZERO;
            BigDecimal byyb = BigDecimal.ZERO;
            BigDecimal bnljygb = BigDecimal.ZERO;
            BigDecimal qmwb = BigDecimal.ZERO;
            if (detailDOList != null && detailDOList.size() > 0) {
                for (StorageSubsidyDetailDO detailDO : detailDOList) {
                    if (detailDO.getPzmc().equals("储备粮油合计")) {
                        syyqmkc = syyqmkc.add(detailDO.getSyyqmkc() != null ? detailDO.getSyyqmkc() : BigDecimal.ZERO);
                        byyb = byyb.add(detailDO.getByyb() != null ? detailDO.getByyb() : BigDecimal.ZERO);
                        bnljygb = bnljygb.add(detailDO.getBnljygb() != null ? detailDO.getBnljygb() : BigDecimal.ZERO);
                        qmwb = (detailDO.getQmwb() != null ? detailDO.getQmwb() : BigDecimal.ZERO);
                    }
                }
            }
            vo.setSyyqmkc(syyqmkc);
            vo.setByyb(byyb);
            vo.setBnljygb(bnljygb);
            vo.setQmwb(qmwb);
        });
        PageInfo<StorageSubsidyVO> pageInfoVO = new PageInfo<>(voList);
        return pageInfoVO;
    }

    public PageInfo<StorageSubsidyVO> getStorageSubsidyList(Integer pageNum, Integer pageSize, StorageSubsidyQueryVO queryVO) {
        PageHelper.startPage(pageNum, pageSize);
        List<StorageSubsidyVO> voList = storageSubsidyMapper.selectListByQuery1(queryVO);
        List<StorageSubsidyDO> subsidyDOList = storageSubsidyMapper.selectByQuery(queryVO);

        if (voList != null && voList.size() >= 1 && subsidyDOList != null && subsidyDOList.size() >= 1) {
            for (StorageSubsidyDO aDo : subsidyDOList) {
                for (StorageSubsidyVO vo : voList) {
                    if (vo.getPeriod() != null && vo.getSskdbm() != null && vo.getPeriod().equals(aDo.getPeriod()) && aDo.getSskdbm().contains(vo.getSskdbm())) {
                        vo.setId(aDo.getId());
                        vo.setRemark(aDo.getRemark());
                        vo.setReceiveOpinion(aDo.getReceiveOpinion());
                    }
                }
            }
        }
        if (queryVO.getPeriod() == null) {
            voList.stream().forEach(vo -> {
                if (vo.getStatusName().equals("未上报")) {
                    vo.setPeriod("2023年01月");
                }
            });
        } else {
            voList.stream().forEach(vo -> {
                if (vo.getStatusName().equals("未上报")) {
                    vo.setPeriod(queryVO.getPeriod());
                }
            });
        }

        return new PageInfo<>(voList);
    }

    public StorageSubsidyVO getStorageSubsidyInfo(String ssId) {
        StorageSubsidyDO subsidyDO = storageSubsidyMapper.selectById(ssId);
        StorageSubsidyVO vo = JSONObject.parseObject(JSONObject.toJSONString(subsidyDO), StorageSubsidyVO.class);
        if (vo != null) {
            StorageSubsidyDetailDO detailQueryDO = new StorageSubsidyDetailDO();
            detailQueryDO.setSsId(ssId);
            List<StorageSubsidyDetailDO> detailDOList = storageSubsidyDetailMapper.selectBySsId(ssId);
            List<StorageSubsidyDetailVO> detailVOList = JSONObject.parseArray(JSONObject.toJSONString(detailDOList), StorageSubsidyDetailVO.class);
            if (detailDOList != null && detailDOList.size() > 0) {
                vo.setDetailList(detailVOList);
            }
            return vo;
        }
        return null;
    }

    public StorageSubsidySummaryVO generateStorageSubsidySummary(Integer dataType) {

        //获取对应的上报数据
        StorageSubsidySummaryQueryVO queryVO = new StorageSubsidySummaryQueryVO();
        String period = storageSubsidySummaryMapper.selectByDataType(dataType);
        if (period == null) {
            DateTimeFormatter mm = DateTimeFormatter.ofPattern("MM");
            period = LocalDate.now().getYear() + "年" + mm.format(LocalDate.now()) + "月";
        } else {
            period = getNextPeriod(period);
        }
        queryVO.setPeriod(period);
        queryVO.setDataType(dataType);
        List<StorageSubsidySummaryDetailVO> detailVOList = storageSubsidySummaryMapper.getSummaryByPeriod(queryVO);

        StorageSubsidySummaryVO summaryVO = new StorageSubsidySummaryVO();
        summaryVO.setPeriod(period);
        summaryVO.setDataType(dataType);
        //dolist 用于去除重复数据

        List<StorageSubsidyDO> doList = storageSubsidyMapper.selectByPeriod(dataType, period);
        List<StorageSubsidySummaryInfoVO> infoVOList = getSummaryInfoVO(detailVOList);
        //去除多余数据
        infoVOList = summaryInfo(doList, infoVOList);
        summaryVO.setInfoList(infoVOList);
        List<StorageSubsidySummaryDetailVO> detailList = detailVOList.stream()
                .filter(detailVO -> doList.stream()
                        .anyMatch(subsidyDO ->
                                subsidyDO.getSskdmc().equals(detailVO.getCcqy()))).collect(Collectors.toList());
        List<StorageSubsidySummaryDetailVO> distinctClass
                = detailList.stream()
                .collect(Collectors.collectingAndThen(Collectors.toCollection(() ->
                        new TreeSet<>(Comparator.comparing(o -> o.getCcqybm() + ";" + o.getCcqy() + ";" + o.getPzmc() + ";" + o.getPzbm() + ";" +  o.getFl()))), ArrayList::new));
        summaryVO.setDetailList(distinctClass);
        return summaryVO;
    }

    private List<StorageSubsidySummaryInfoVO> summaryInfo(List<StorageSubsidyDO> doList, List<StorageSubsidySummaryInfoVO> infoVOList1) {
        List<StorageSubsidySummaryInfoVO> infoVOList = new ArrayList<>();
        for (StorageSubsidySummaryInfoVO vo : infoVOList1) {
            for (StorageSubsidyDO subsidyDO : doList) {
                if (subsidyDO.getSskdmc().equals(vo.getCcqy()) && !subsidyDO.getStatus().equals("91000000")) {
                    infoVOList.add(vo);
                }
            }
        }
        for (StorageSubsidySummaryInfoVO infoVO : infoVOList) {
            Iterator<Map<String, Object>> iterator1 = infoVO.getDataList().iterator();
            while (iterator1.hasNext()) {
                Map<String, Object> map = iterator1.next();
                if (map.get("pzmc").equals("原油")) {
                    Map<String, Object> map1 = iterator1.next();
                    Object sl = map.get("sl");
                    Object o_sl = map1.get("sl");
                    BigDecimal number = (BigDecimal) sl;
                    BigDecimal number_1 = (BigDecimal) o_sl;

                    map.replace("sl", number.add(number_1));
                    Object je = map.get("je");
                    Object o_je = map1.get("je");
                    BigDecimal num = (BigDecimal) je;
                    BigDecimal num_1 = (BigDecimal) o_je;
                    map.replace("je", num.add(num_1));
                    if (number.compareTo(BigDecimal.ZERO) == 0) {
                        map.replace("fl", map1.get("fl"));
                    }
                    iterator1.remove();
                }
            }
        }
        return infoVOList;
    }

    private String getNextPeriod(String maxPeriod) {
        Calendar calendar = Calendar.getInstance();
        int year = calendar.get(Calendar.YEAR);
        int periodYear = year;
        int periodMonth = 1;
        int day = 15;

        int maxPeriodYear = Integer.parseInt(maxPeriod.substring(0, 4));
        int maxPeriodMonth = Integer.parseInt(maxPeriod.substring(5, 7));
        //已上报期与当前年份比较，
//        if (maxPeriodYear < year) {
//            periodYear = maxPeriodYear;
//            periodMonth = maxPeriodMonth + 1;
//        } else if (maxPeriodYear == year) {
//
//            periodMonth = maxPeriodMonth + 1;
//
//        } else {
//            ResponseWrapper.error("获取上报期数错误！");
//        }
        if (maxPeriodMonth < 12) {
            periodYear = maxPeriodYear;
            periodMonth = maxPeriodMonth + 1;
        } else {
            periodYear = maxPeriodYear + 1;
            periodMonth = 1;
        }
        calendar.set(Calendar.YEAR, periodYear);
        calendar.set(Calendar.MONTH, periodMonth - 1);
        int maxDayOfMonth = calendar.getActualMaximum(Calendar.DAY_OF_MONTH); // 获取该月的最大天数
        if (day > maxDayOfMonth) {
            day = maxDayOfMonth;
        }
        calendar.set(Calendar.DAY_OF_MONTH, day); // 设置日期为指定的日期
        Date periodDate = calendar.getTime();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy年MM月");
        return sdf.format(periodDate);
    }

    @Transactional
    public ResponseWrapper saveStorageSubsidySummary(StorageSubsidySummaryVO storageSubsidySummaryVO) {

        StorageSubsidySummaryQueryVO queryVO = new StorageSubsidySummaryQueryVO();
        queryVO.setPeriod(storageSubsidySummaryVO.getPeriod());
        queryVO.setDataType(storageSubsidySummaryVO.getDataType());
        //判断汇总期数是否重复
        List<StorageSubsidySummaryDO> subsidySummaryList = storageSubsidySummaryMapper.selectByQuery(queryVO);
        if (subsidySummaryList != null && subsidySummaryList.size() > 0) {
            return ResponseWrapper.error("不能重复汇总数据");
        }
        StorageSubsidySummaryDO summaryDO = JSONObject.parseObject(JSONObject.toJSONString(storageSubsidySummaryVO), StorageSubsidySummaryDO.class);
        summaryDO.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
        summaryDO.setCreateDate(new Date());
        summaryDO.setTabulatorDate(storageSubsidySummaryVO.getTabulatorDate());
        summaryDO.setCreator(storageSubsidySummaryVO.getTabulator());
        if (storageSubsidySummaryVO.getOperationType() == 0) {
            summaryDO.setStatus(ReserveReportConstant.DTJSH.getValue());
            summaryDO.setStatusName(ReserveReportConstant.DTJ.getName());
        } else if (storageSubsidySummaryVO.getOperationType() == 1) {
            summaryDO.setStatus(ReserveReportConstant.DFH.getValue());
            summaryDO.setStatusName(ReserveReportConstant.DFH.getName());
        }

        int res = storageSubsidySummaryMapper.insertSelective(summaryDO);
        if (res > 0) {
            //保存汇总明细数据
            List<StorageSubsidySummaryDetailVO> detailVOList = storageSubsidySummaryVO.getDetailList();
            if (detailVOList != null && detailVOList.size() > 0) {
                List<StorageSubsidySummaryDetailDO> detailDOList = JSONObject.parseArray(JSONObject.toJSONString(detailVOList), StorageSubsidySummaryDetailDO.class);
                detailDOList.forEach(detailDO -> {
                    detailDO.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                    detailDO.setSssId(summaryDO.getId());
                });
                int res2 = storageSubsidySummaryDetailMapper.insertList(detailDOList);
                if (res2 > 0) {
                    storageSubsidyMapper.updateSummaryStatus(summaryDO.getPeriod(), HAS_SUMMARIZED);
                    return ResponseWrapper.success("汇总成功！");
                }
            }
        }
        return ResponseWrapper.error("汇总失败！");
    }

    @Transactional
    public ResponseWrapper updateStorageSubsidySummary(Integer type, StorageSubsidySummaryVO summaryVO) {

        StorageSubsidySummaryDO originSummaryDO = storageSubsidySummaryMapper.selectById(summaryVO.getId());
        if (originSummaryDO == null) {
            return ResponseWrapper.error("汇总数据不存在，请确认后重试！");
        }
        if (type == 1) {
            //修改
            StorageSubsidySummaryDO summaryDO = JSONObject.parseObject(JSONObject.toJSONString(summaryVO), StorageSubsidySummaryDO.class);
            summaryDO.setUpdateDate(new Date());
            summaryDO.setUpdater(CurrentUtil.getUserName());
            if (summaryVO.getOperationType() == 1) {
                summaryDO.setStatus(ReserveReportConstant.DFH.getValue());
                summaryDO.setStatusName(ReserveReportConstant.DFH.getName());
            }
            int res = storageSubsidySummaryMapper.updateByPrimaryKeySelective(summaryDO);
            if (res > 0) {
                //根据申请表，获取汇总数据
                //先删除原来汇总数据，再插入新的汇总数据
                List<StorageSubsidySummaryDetailVO> detailVOList = summaryVO.getDetailList();
                storageSubsidySummaryDetailMapper.deleteBySssId(summaryDO.getId());


                if (detailVOList != null && detailVOList.size() > 0) {
                    List<StorageSubsidySummaryDetailDO> detailDOList = JSONObject.parseArray(JSONObject.toJSONString(detailVOList), StorageSubsidySummaryDetailDO.class);
                    detailDOList.forEach(detailDO -> {
                        detailDO.setId(UUID.randomUUID().toString().toLowerCase().replaceAll("-", ""));
                        detailDO.setSssId(summaryDO.getId());
                    });
                    int res2 = storageSubsidySummaryDetailMapper.insertList(detailDOList);
                    if (res2 > 0) {
                        return ResponseWrapper.success("更新成功！");
                    }
                }
            }

        } else if (type == 2) {//复核
            //判断复核状态
            if (ReserveReportConstant.DFH.getValue().equals(originSummaryDO.getStatus()) || ReserveReportConstant.CWPSBH.getValue().equals(originSummaryDO.getStatus())) {
                originSummaryDO.setStatus(ReserveReportConstant.FHBH.getValue());
                originSummaryDO.setStatusName(ReserveReportConstant.FHBH.getName());
                originSummaryDO.setReviewer(summaryVO.getReviewer());
                originSummaryDO.setReviewDate(summaryVO.getReviewDate());
                originSummaryDO.setReviewStatus(summaryVO.getReviewStatus());
                originSummaryDO.setReviewOpinion(summaryVO.getReviewOpinion());
                if (summaryVO.getReviewStatus() == 1) {
                    originSummaryDO.setStatus(ReserveReportConstant.DCWPS.getValue());
                    originSummaryDO.setStatusName(ReserveReportConstant.DCWPS.getName());
                }
            }
        } else if (type == 3) {//复核
            //判断财务批示
            if (ReserveReportConstant.DCWPS.getValue().equals(originSummaryDO.getStatus()) || ReserveReportConstant.DWFZRPSBH.getValue().equals(originSummaryDO.getStatus())) {
                originSummaryDO.setStatus(ReserveReportConstant.CWPSBH.getValue());
                originSummaryDO.setStatusName(ReserveReportConstant.CWPSBH.getName());
                originSummaryDO.setFinanceUsername(summaryVO.getFinanceUsername());
                originSummaryDO.setFinanceDate(summaryVO.getFinanceDate());
                originSummaryDO.setFinanceStatus(summaryVO.getFinanceStatus());
                originSummaryDO.setFinanceOpinion(summaryVO.getFinanceOpinion());
                if (summaryVO.getFinanceStatus() == 1) {
                    originSummaryDO.setStatus(ReserveReportConstant.DDWFZRPS.getValue());
                    originSummaryDO.setStatusName(ReserveReportConstant.DDWFZRPS.getName());
                }
            }
        } else if (type == 4) {//复核
            //判断单位领导
            if (ReserveReportConstant.DDWFZRPS.getValue().equals(originSummaryDO.getStatus())) {
                originSummaryDO.setStatus(ReserveReportConstant.DWFZRPSBH.getValue());
                originSummaryDO.setStatusName(ReserveReportConstant.DWFZRPSBH.getName());
                originSummaryDO.setLeaderUsername(summaryVO.getLeaderUsername());
                originSummaryDO.setLeaderDate(summaryVO.getLeaderDate());
                originSummaryDO.setLeaderStatus(summaryVO.getLeaderStatus());
                originSummaryDO.setLeaderOpinion(summaryVO.getLeaderOpinion());
                if (summaryVO.getLeaderStatus() == 1) {
                    originSummaryDO.setStatus(ReserveReportConstant.YWC.getValue());
                    originSummaryDO.setStatusName(ReserveReportConstant.YWC.getName());
                }
            }
        } else {
            return ResponseWrapper.invalid();
        }
        int res = storageSubsidySummaryMapper.updateByPrimaryKeySelective(originSummaryDO);
        if (res > 0) {
            return ResponseWrapper.success("操作成功！");
        }
        return ResponseWrapper.error("操作失败！");
    }

    public PageInfo<StorageSubsidySummaryVO> getStorageSubsidySummaryPageList(Integer pageNum, Integer pageSize, StorageSubsidySummaryQueryVO queryVO) {

        PageHelper.startPage(pageNum, pageSize);
        List<StorageSubsidySummaryDO> list = storageSubsidySummaryMapper.selectByQuery(queryVO);
        List<StorageSubsidySummaryVO> voList = new ArrayList<>();
        LsBeanUtils.copyCollection(list, voList, StorageSubsidySummaryVO.class);
        voList.forEach(vo -> {
            List<StorageSubsidySummaryDetailDO> detailDOList = storageSubsidySummaryDetailMapper.selectBySssId(vo.getId());
            BigDecimal wheat = BigDecimal.ZERO;
            BigDecimal paddy = BigDecimal.ZERO;
            BigDecimal Rice = BigDecimal.ZERO;
            BigDecimal flour = BigDecimal.ZERO;
            BigDecimal eatOil = BigDecimal.ZERO;
            if (detailDOList != null && detailDOList.size() > 0) {
                List<StorageSubsidySummaryDetailDO> distinctClass
                        = detailDOList.stream()
                        .collect(Collectors.collectingAndThen(Collectors.toCollection(() ->
                                new TreeSet<>(Comparator.comparing(o -> o.getCcqybm() + ";" + o.getCcqy() + ";" + o.getPzmc() + ";" + o.getPzbm() + ";" +  o.getFl()))), ArrayList::new));
                for (StorageSubsidySummaryDetailDO detailDO : distinctClass) {
                    if (detailDO.getPzbm() != null) {
                        if (detailDO.getPzbm().equals(new BigDecimal(1110000))) {
                            wheat = wheat.add(detailDO.getJe() != null ? detailDO.getJe() : BigDecimal.ZERO);
                        } else if (detailDO.getPzbm().equals(new BigDecimal(1130000))) {
                            paddy = paddy.add(detailDO.getJe() != null ? detailDO.getJe() : BigDecimal.ZERO);
                        } else if (detailDO.getPzbm().equals(new BigDecimal(2360000))) {
                            Rice = Rice.add(detailDO.getJe() != null ? detailDO.getJe() : BigDecimal.ZERO);
                        } else if (detailDO.getPzbm().equals(new BigDecimal(2310000))) {
                            flour = flour.add(detailDO.getJe() != null ? detailDO.getJe() : BigDecimal.ZERO);
                        } else if (detailDO.getPzbm().equals(new BigDecimal(9980000))) {
                            eatOil = eatOil.add(detailDO.getJe() != null ? detailDO.getJe() : BigDecimal.ZERO);
                        }
//                        else if (detailDO.getPzbm().equals(new BigDecimal(1410000)) || detailDO.getPzbm().equals(new BigDecimal(2120000))) {
//                            eatOil = eatOil.add(detailDO.getJe() != null ? detailDO.getJe() : BigDecimal.ZERO);
//                        }
                    }
                    /*syyqmkc = syyqmkc.add(detailDO.getSl() != null ? detailDO.getSl() : BigDecimal.ZERO);
                    byyb = byyb.add(detailDO.getJe() != null ? detailDO.getJe() : BigDecimal.ZERO);
                    bnljyb = bnljyb.add(detailDO.getBnljyb() != null ? detailDO.getBnljyb() : BigDecimal.ZERO);*/
                }
            }

            vo.setWheat(wheat);
            vo.setPaddy(paddy);
            vo.setRice(Rice);
            vo.setFlour(flour);
            vo.setEatOil(eatOil);
        });
        return new PageInfo<>(voList);
    }

    public StorageSubsidySummaryVO getStorageSubsidySummaryInfo(String id) {
        StorageSubsidySummaryDO summaryDO = storageSubsidySummaryMapper.selectById(id);
        if (summaryDO != null) {
            StorageSubsidySummaryVO vo = JSONObject.parseObject(JSONObject.toJSONString(summaryDO), StorageSubsidySummaryVO.class);
            List<StorageSubsidySummaryDetailDO> detailDOList = storageSubsidySummaryDetailMapper.selectBySssId(id);
            List<StorageSubsidySummaryDetailVO> detailVOList = JSONObject.parseArray(JSONObject.toJSONString(detailDOList), StorageSubsidySummaryDetailVO.class);
            List<StorageSubsidyDO> doList = storageSubsidyMapper.selectByPeriod(summaryDO.getDataType(), summaryDO.getPeriod());

            List<StorageSubsidySummaryInfoVO> infoVOList = new ArrayList<>();

            for (StorageSubsidyDO subsidyDO : doList) {
                StorageSubsidySummaryInfoVO infoVO = new StorageSubsidySummaryInfoVO();
                infoVO.setCcqy(subsidyDO.getSskdmc());
                infoVO.setCcqybm(subsidyDO.getSskdbm());
                BigDecimal ccf = new BigDecimal(0);
                BigDecimal cblccf = new BigDecimal(0);
                List<Map<String, Object>> detaList = new ArrayList<>();
                for (StorageSubsidySummaryDetailVO detailVO : detailVOList) {

                    if (subsidyDO.getSskdmc().equals(detailVO.getCcqy())) {
                        Map<String, Object> map = new HashMap<>();
                        map.put("pzbm", detailVO.getPzbm());
                        map.put("pzmc", detailVO.getPzmc());
                        map.put("sl", detailVO.getSl());
                        map.put("fl", detailVO.getFl());
                        map.put("je", detailVO.getJe());
                        map.put("typeCode", detailVO.getTypeCode());
                        ccf = ccf.add(detailVO.getJe());
//                        if (!"1410000".equals(detailVO.getPzbm()) && !"2120000".equals(detailVO.getPzbm())) {
//                            cblccf = cblccf.add(detailVO.getJe());
//                        }
                        if (!"9980000".equals(detailVO.getPzbm())) {
                            cblccf = cblccf.add(detailVO.getJe());
                        }
                        detaList.add(map);

                    }
                }
                infoVO.setDataList(detaList);
                infoVO.setCcf(ccf);
                infoVO.setCblccf(cblccf);
                infoVOList.add(infoVO);
            }
            //List<StorageSubsidySummaryInfoVO> infoVOList = getSummaryInfoVO(detailVOList);
            infoVOList = summaryInfo(doList, infoVOList);
            vo.setInfoList(infoVOList);

            vo.setDetailList(detailVOList);
            return vo;
        }
        return null;
    }

    private List<StorageSubsidySummaryInfoVO> getSummaryInfoVO(List<StorageSubsidySummaryDetailVO> detailVOList) {
        List<StorageSubsidySummaryInfoVO> infoVOList = new ArrayList<>();

        if (detailVOList != null && detailVOList.size() > 0) {
            List<StorageSubsidySummaryDetailVO> distinctEnterpriseList = detailVOList.stream()
                    .collect(Collectors.collectingAndThen(
                            Collectors.toCollection(() -> new ArrayList<>()),
                            list -> list.stream()
                                    .distinct()
                                    .collect(Collectors.toList())
                    ));
            /*List<StorageSubsidySummaryDetailVO> detailVOList1 = new ArrayList<>();
            for (StorageSubsidySummaryDetailVO detailVO : detailVOList) {
                boolean containsElement = detailVOList1.stream()
                        .anyMatch(vo -> vo.getCcqybm().equals(detailVO.getCcqybm()) && vo.getPzbm().equals(detailVO.getPzbm()));
                if (!containsElement){
                    detailVOList1.add(detailVO);
                }else {
                    Optional<StorageSubsidySummaryDetailVO> matchingVO = detailVOList1.stream()
                            .filter(vo -> vo.getCcqybm().equals(detailVO.getCcqybm())*//* && vo.getPzbm().equals(detailVO.getPzbm())*//*)
                            .findAny();

                    // 输出结果
                    if (matchingVO.isPresent()) {
                        StorageSubsidySummaryDetailVO detailVO1 = matchingVO.get();

                        detailVO1.setFl(detailVO.getSl());
                        detailVO1.setBnljyb(detailVO.getBnljyb());
                        detailVO1.setJe(detailVO.getJe());
                        Iterator<StorageSubsidySummaryDetailVO> iterator = detailVOList1.iterator();
                        while (iterator.hasNext()) {
                            StorageSubsidySummaryDetailVO summaryDetailVO = iterator.next();
                            if (summaryDetailVO.getCcqybm().equals(detailVO1.getCcqybm()) && summaryDetailVO.getPzbm().equals(detailVO1.getPzbm())) {
                                iterator.remove();
                            }
                        }
                        detailVOList1.add(detailVO1);
                    }
                }
            }*/

            for (StorageSubsidySummaryDetailVO enterpriseVO : distinctEnterpriseList) {
                StorageSubsidySummaryInfoVO infoVO = new StorageSubsidySummaryInfoVO();
                infoVO.setCcqy(enterpriseVO.getCcqy());
                infoVO.setCcqybm(enterpriseVO.getCcqybm());
                BigDecimal ccf = new BigDecimal(0);
                BigDecimal cblccf = new BigDecimal(0);
                List<Map<String, Object>> detaList = new ArrayList<>();
                for (StorageSubsidySummaryDetailVO detailVO : detailVOList) {

                    if (detailVO.getCcqybm().equals(enterpriseVO.getCcqybm())) {
                        Map<String, Object> map = new HashMap<>();
                        map.put("pzbm", detailVO.getPzbm());
                        map.put("pzmc", detailVO.getPzmc());
                        map.put("sl", detailVO.getSl());
                        map.put("fl", detailVO.getFl());
                        map.put("je", detailVO.getJe());
                        map.put("typeCode", detailVO.getTypeCode());
                        ccf = ccf.add(detailVO.getJe());
//                        if (!"1410000".equals(detailVO.getPzbm()) || !"2120000".equals(detailVO.getPzbm())) {
//                            cblccf = cblccf.add(detailVO.getJe());
//                        }
                        if (!"9980000".equals(detailVO.getPzbm())) {
                            cblccf = cblccf.add(detailVO.getJe());
                        }
                        detaList.add(map);

                    }
                }
                List<Map<String, Object>> collect = detaList.stream().distinct().collect(Collectors.toList());
                infoVO.setDataList(collect);
                infoVO.setCcf(ccf);
                infoVO.setCblccf(cblccf);
                infoVOList.add(infoVO);
            }
        }
        return infoVOList;
    }

    //待办已办消息
    public void addBacklog(BacklogItemVO itemVO, UrlVO vo) {
        if (ReserveReportConstant.DGZ.equals(itemVO.getStatus())) {

        }
    }

    @Transactional
    public int deletePurchaseStockSummary(String id) {
        PurchaseStockSummaryDO summaryDO = purchaseStockSummaryMapper.selectByPrimaryKey(id);
        int res = 0;
        if (summaryDO != null) {
            res = purchaseStockSummaryMapper.deleteByPrimaryKey(id);
            if (res > 0) {
                purchaseStockMapper.updateSummaryStatus(summaryDO.getPeriod(), NOT_SUMMARIZED);
            }
        }
        return res;
    }

    @Transactional
    public int deleteStorageSubsidySummary(String id) {
        StorageSubsidySummaryDO summaryDO = storageSubsidySummaryMapper.selectByPrimaryKey(id);
        int res = storageSubsidySummaryMapper.deleteByPrimaryKey(id);
        if (res > 0) {
            res = storageSubsidySummaryDetailMapper.deleteBySssId(id);

            if (res > 0) {
                storageSubsidyMapper.updateSummaryStatus(summaryDO.getPeriod(), NOT_SUMMARIZED);
            }
        }
        return res > 0 ? 1 : 0;
    }


    @Transactional
    public int saveEnterprise(EnterpriseVO enterpriseVO) {
        List<EnterpriseDetailVO> detailVOList = enterpriseVO.getDetailList();
        int res = 0;
        for (EnterpriseDetailVO detailVO : detailVOList) {
            EnterpriseDO enterpriseDO = new EnterpriseDO();
            enterpriseDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-", ""));
            enterpriseDO.setCcqy(enterpriseVO.getCcqy());
            enterpriseDO.setCcqybm(enterpriseVO.getCcqybm());
            enterpriseDO.setSort(enterpriseVO.getSort());
            enterpriseDO.setBtbblx(detailVO.getBtbblx());
            enterpriseDO.setBtbblxmc(detailVO.getBtbblxmc());
            enterpriseDO.setBtbzlx(detailVO.getBtbzlx());
            enterpriseDO.setBtbzlxmc(detailVO.getBtbzlxmc());
            enterpriseDO.setIsDelete(0);
            enterpriseDO.setCreator(CurrentUtil.getUserName());
            enterpriseDO.setCreateDate(new Date());
            res = enterpriseMapper.insertSelective(enterpriseDO);
            if (res <= 0) {
                return res;
            }
        }
        return res;
    }

    @Transactional
    public int updateEnterprise(EnterpriseVO enterpriseVO) {
        //删除旧数据，重新添加
        EnterpriseDO queryDO = new EnterpriseDO();
        queryDO.setCcqybm(enterpriseVO.getCcqybm());
        int res = enterpriseMapper.delete(queryDO);
        if (res > 0) {
            return saveEnterprise(enterpriseVO);
        }
        return res;
    }

    public List<EnterpriseVO> getEnterpriseList(EnterpriseQueryVO queryVO) {
        List<EnterpriseVO> enterpriseVOList = getEnterpriseVOList(queryVO);
        return enterpriseVOList;
    }

    private List<EnterpriseVO> getEnterpriseVOList(EnterpriseQueryVO queryVO) {
        List<EnterpriseDO> enterpriseDOList = enterpriseMapper.selectByQuery(queryVO);
        List<EnterpriseVO> enterpriseVOList = new ArrayList<>();
        if (enterpriseDOList != null && enterpriseDOList.size() > 0) {
            // 根据元素的属性进行去重
            List<EnterpriseDO> distinctList = enterpriseDOList.stream()
                    .collect(Collectors.collectingAndThen(
                            Collectors.toCollection(() -> new ArrayList<>()),
                            list -> list.stream()
                                    .distinct()
                                    .collect(Collectors.toList())
                    ));
            distinctList.forEach(distinct -> {
                EnterpriseVO enterpriseVO = JSONObject.parseObject(JSONObject.toJSONString(distinct), EnterpriseVO.class);
                enterpriseVO.setDetailList(new ArrayList<>());
                enterpriseDOList.forEach(el -> {
                    if (distinct.getCcqybm().equals(el.getCcqybm())) {
                        EnterpriseDetailVO detailVO = new EnterpriseDetailVO();
                        detailVO.setBtbblx(el.getBtbblx());
                        detailVO.setBtbblxmc(el.getBtbblxmc());
                        detailVO.setBtbzlx(el.getBtbzlx());
                        detailVO.setBtbzlxmc(el.getBtbzlxmc());
                        enterpriseVO.getDetailList().add(detailVO);
                    }
                });
                enterpriseVOList.add(enterpriseVO);
            });
        }
        return enterpriseVOList;
    }

    public PageInfo<EnterpriseVO> getEnterprisePage(Integer pageNum, Integer pageSize, EnterpriseQueryVO queryVO) {
        PageHelper.startPage(pageNum, pageSize);
        List<EnterpriseDO> enterpriseDOList = enterpriseMapper.selectByQuery(queryVO);
        List<EnterpriseVO> enterpriseVOList = new ArrayList<>();
        if (enterpriseDOList != null && enterpriseDOList.size() > 0) {
            // 根据元素的属性进行去重
            List<EnterpriseDO> distinctList = enterpriseDOList.stream()
                    .collect(Collectors.collectingAndThen(
                            Collectors.toCollection(() -> new ArrayList<>()),
                            list -> list.stream()
                                    .distinct()
                                    .collect(Collectors.toList())
                    ));
            distinctList.forEach(distinct -> {
                EnterpriseVO enterpriseVO = JSONObject.parseObject(JSONObject.toJSONString(distinct), EnterpriseVO.class);
                enterpriseVO.setDetailList(new ArrayList<>());
                enterpriseDOList.forEach(el -> {
                    if (distinct.getCcqybm().equals(el.getCcqybm())) {
                        EnterpriseDetailVO detailVO = new EnterpriseDetailVO();
                        detailVO.setBtbblx(el.getBtbblx());
                        detailVO.setBtbblxmc(el.getBtbblxmc());
                        detailVO.setBtbzlx(el.getBtbzlx());
                        detailVO.setBtbzlxmc(el.getBtbzlxmc());
                        enterpriseVO.getDetailList().add(detailVO);
                    }
                });
                enterpriseVOList.add(enterpriseVO);
            });
        }
        PageInfo<EnterpriseDO> pageInfoDO = new PageInfo<EnterpriseDO>(enterpriseDOList);
        PageInfo<EnterpriseVO> pageInfo = new PageInfo<>(enterpriseVOList);
        pageInfo.setTotal(pageInfoDO.getTotal());
        return pageInfo;
    }

    public int deleteEnterprise(String ccqybm) {
        EnterpriseDO enterpriseDO = new EnterpriseDO();
        enterpriseDO.setCcqybm(ccqybm);
        return enterpriseMapper.delete(enterpriseDO);
    }

    public boolean sortEnterprise(String enterpriseCode, Integer startIndex, Integer endIndex) {
        List<EnterpriseDO> enterpriseDOList = enterpriseMapper.selectAll();
        if (enterpriseDOList != null && enterpriseDOList.size() > 0) {
            try {
                List<EnterpriseDO> distinctList = enterpriseDOList.stream()
                        .collect(Collectors.collectingAndThen(
                                Collectors.toCollection(() -> new ArrayList<>()),
                                list -> list.stream()
                                        .distinct()
                                        .collect(Collectors.toList())
                        ));
                Collections.sort(distinctList, (obj1, obj2) -> {
                    Integer score1 = obj1.getSort();
                    Integer score2 = obj2.getSort();
                    return score1.compareTo(score2); // 降序排列
                });
                List<EnterpriseDO> updateList = HelpUtils.getNeedUpdateSortList(distinctList, enterpriseCode, startIndex, endIndex, "ccqybm", "sort", true);
                if (updateList != null && updateList.size() > 0) {
                    updateList.forEach(e -> {
                        enterpriseMapper.sortByCcqybm(e.getCcqybm(), e.getSort());
                    });
                }
                return true;
            } catch (IllegalAccessException e) {
                throw new RuntimeException(e);

            }
        }
        return false;

    }


    public ResponseWrapper updatePurchaseStockSummary(PurchaseStockSummaryVO summaryVO) {
        if (summaryVO == null || StringUtils.isEmpty(summaryVO.getId())) {
            return ResponseWrapper.invalid();
        }
        if (StringUtils.isEmpty(summaryVO.getRecevier()) && StringUtils.isEmpty(summaryVO.getStatus()) && StringUtils.isEmpty(summaryVO.getStatusName())) {
            return ResponseWrapper.error("复核人不存在，请确认后重试！");
        }

        PurchaseStockSummaryDO summaryDO = LsBeanUtils.copyProperties(summaryVO, PurchaseStockSummaryDO.class);
        if (summaryVO.getOperationType() == 0) {
            summaryDO.setIsDelete(0);
            int res = purchaseStockSummaryMapper.updateByPrimaryKey(summaryDO);
            if (res > 0) {
                return ResponseWrapper.success("保存成功！");
            }
            return ResponseWrapper.error("保存失败！");
        }
        if (summaryVO.getOperationType() == 1) {
            summaryDO.setIsDelete(0);
            int res = purchaseStockSummaryMapper.updateByPrimaryKey(summaryDO);
            if (res > 0) {
                return ResponseWrapper.success("提交成功！");
            }
            return ResponseWrapper.error("提交失败！");
        }
        if (summaryVO.getOperationType() == 2) {
            summaryDO.setIsDelete(0);
            summaryDO.setRecevieDate(summaryVO.getRecevieDate());
            int res = purchaseStockSummaryMapper.updateByPrimaryKey(summaryDO);
            if (res > 0) {
                return ResponseWrapper.success("复核成功！");
            }
            return ResponseWrapper.error("复核失败！");
        }
        return null;

    }
}
