package com.unis.ynls.irpt.server.domain;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.common.utils.UUIDUtils;
import com.unis.ynls.irpt.common.VO.RotateProtocolVO;
import com.unis.ynls.irpt.common.VO.reservereport.EnterpriseQueryVO;
import com.unis.ynls.irpt.common.VO.rotationreport.*;
import com.unis.ynls.irpt.common.contast.ReserveReportConstant;
import com.unis.ynls.irpt.server.entity.RotatePlanProtocolDetailVO;
import com.unis.ynls.irpt.server.entity.RotatePlanProtocolVO;
import com.unis.ynls.irpt.server.entity.reservereport.EnterpriseDO;
import com.unis.ynls.irpt.server.entity.reservereport.StorageSubsidyStandardDO;
import com.unis.ynls.irpt.server.entity.rotationreport.*;
import com.unis.ynls.irpt.server.mapper.*;
import com.unis.ynls.irpt.server.remote.RotatePlanProtocoFeign1;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

@Component
public class RotationReportDomain {

    @Autowired
    private RotationSubsidyRateMapper rotationSubsidyRateMapper;


    @Autowired
    private RotationSubsidyMapper rotationSubsidyMapper;

    @Autowired
    private RotationSubsidyDetailMapper rotationSubsidyDetailMapper;

    @Autowired
    private RotationSubsidySummaryMapper rotationSubsidySummaryMapper;

    @Autowired
    private RotationSubsidySummaryDetailMapper rotationSubsidySummaryDetailMapper;

    @Autowired
    private RotatePlanProtocoFeign1 rotatePlanProtocoFeign1;
    @Autowired
    private RotatePlanProtocolRecordMapper rotatePlanProtocolRecordMapper;
    @Autowired
    private EnterpriseMapper enterpriseMapper;

    //数据类型 预算
    private final static String ROTATION_SUBSIDY_TYPE1 = "budget";
    //数据类型 清算
    private final static String ROTATION_SUBSIDY_TYPE2 = "liquidate";

    //数据类型 预算
    private final static Integer SJLX_BUDGET = 1;
    //数据类型 清算
    private final static Integer SJLX_LIQUIDATE = 2;

    //预算 未拨付状态
    private final static Integer BUDGET_UNALLOCATED = 0;

    //清算 未拨付状态
    private final static Integer LIQUIDATE_UNALLOCATED = 0;

    @Transactional
    public Integer saveRotationSubsidyRate(RotationSubsidyRateVO vo) {
        RotationSubsidyRateDO rateDO = JSONObject.parseObject(JSONObject.toJSONString(vo), RotationSubsidyRateDO.class);
        if (rateDO != null) {
            RotationSubsidyRateDO enabledRateDO = rotationSubsidyRateMapper.selectEnabledByPzbm(rateDO.getPzbm(), rateDO.getTypeCode());
            if (enabledRateDO != null) {
                enabledRateDO.setIsEnable(0);
                enabledRateDO.setEndDate(new Date());
                enabledRateDO.setUpdater(CurrentUtil.getUserName());
                enabledRateDO.setUpdateDate(new Date());
                int res = rotationSubsidyRateMapper.updateByPrimaryKey(enabledRateDO);
                if (res < 1) {
                    return null;
                }
            }
            rateDO.setStartDate(new Date());
            rateDO.setIsEnable(1);
            rateDO.setIsDelete(0);
            rateDO.setCreator(CurrentUtil.getUserName());
            rateDO.setCreateDate(new Date());
            rateDO.setId(UUID.randomUUID().toString().replace("-", "").toLowerCase());
            return rotationSubsidyRateMapper.insert(rateDO);
        }
        return null;
    }

    public RotationSubsidyRateVO getEnabledByPzbm(String pzbm, String tyshxydm) {
//        RotationSubsidyRateDO enabledRateDO = rotationSubsidyRateMapper.selectEnabledByPzbm(pzbm, typeCode);
        if ("2120000".equals(pzbm) || "1410000".equals(pzbm)) {
            pzbm = "9980000";
        }
        List<RotationSubsidyRateDO> rotationSubsidyRateDO = rotationSubsidyRateMapper.selectEnabledByPzbmOnly(pzbm);
        EnterpriseQueryVO enterpriseQueryVO = new EnterpriseQueryVO();
        enterpriseQueryVO.setCcqybm(tyshxydm);
        List<EnterpriseDO> enterpriseDOS = enterpriseMapper.selectByQuery(enterpriseQueryVO);
        List<EnterpriseDO> collect1 = enterpriseDOS.stream().filter(enterpriseDO -> Objects.equals("21", enterpriseDO.getBtbzlx()) || Objects.equals("22", enterpriseDO.getBtbzlx())).collect(Collectors.toList());
        List<RotationSubsidyRateDO> collect = rotationSubsidyRateDO.stream().filter(standardDO -> collect1.stream().anyMatch(enterpriseDO -> Objects.equals(standardDO.getTypeCode(), enterpriseDO.getBtbzlx()))).collect(Collectors.toList());
        if (CollectionUtils.isEmpty(collect)) {
            return null;
        }
        RotationSubsidyRateDO rotationSubsidyRateDO1 = collect.get(0);
        if (rotationSubsidyRateDO1 != null) {
            return JSONObject.parseObject(JSONObject.toJSONString(rotationSubsidyRateDO1), RotationSubsidyRateVO.class);
        }
        return null;
    }

    public List<RotationSubsidyRateVO> getRotationSubsidyRateList() {

        List<RotationSubsidyRateDO> rateDOList = rotationSubsidyRateMapper.selectList();
        if (rateDOList != null) {
            return JSONObject.parseArray(JSONObject.toJSONString(rateDOList), RotationSubsidyRateVO.class);
        }
        return null;
    }

    @Transactional
    public Boolean saveRotationSubsidy(String type, RotationSubsidyVO vo) {

        if (ROTATION_SUBSIDY_TYPE1.equals(type)) {
            RotationSubsidyDO rotationSubsidyDO = JSONObject.parseObject(JSONObject.toJSONString(vo), RotationSubsidyDO.class);
            rotationSubsidyDO.setId(UUID.randomUUID().toString().replace("-", "").toLowerCase());
            rotationSubsidyDO.setCreator(CurrentUtil.getUserName());
            rotationSubsidyDO.setCreateDate(new Date());
            rotationSubsidyDO.setIsDelete(0);
            if (vo.getOperationType() == 0) {
                rotationSubsidyDO.setYsZt(ReserveReportConstant.DTJ.getValue());
                rotationSubsidyDO.setYsZtmc(ReserveReportConstant.DTJ.getName());
            } else if (vo.getOperationType() == 1) {
                rotationSubsidyDO.setYsZt(ReserveReportConstant.DGZ.getValue());
                rotationSubsidyDO.setYsZtmc(ReserveReportConstant.DGZ.getName());
            }
            rotationSubsidyDO.setQsZt(ReserveReportConstant.DSB.getValue());
            rotationSubsidyDO.setQsZtmc(ReserveReportConstant.DSB.getName());
            rotationSubsidyDO.setYsbfzt(BUDGET_UNALLOCATED);
            List<RotationSubsidyDetailVO> detailList = vo.getBudgetList();
            int res = rotationSubsidyMapper.insert(rotationSubsidyDO);
            if (res > 0) {
                for (String lhxybm : vo.getLhxybmList()) {
                    RotatePlanProtocolRecordDO rotatePlanProtocolRecordDO = new RotatePlanProtocolRecordDO();
                    rotatePlanProtocolRecordDO.setCcqy(vo.getCcqybm());
                    rotatePlanProtocolRecordDO.setCcqymc(vo.getCcqy());
                    rotatePlanProtocolRecordDO.setLhxybm(lhxybm);
                    rotatePlanProtocolRecordDO.setHaveReport(1);
                    rotatePlanProtocolRecordDO.setRotationSubsidyId(rotationSubsidyDO.getId());
                    rotatePlanProtocolRecordMapper.insertSelective(rotatePlanProtocolRecordDO);
                }
                return saveBatchDetail(rotationSubsidyDO.getId(), detailList, SJLX_BUDGET) > 0;
            }
        }
        if (ROTATION_SUBSIDY_TYPE2.equals(type)) {
            RotationSubsidyDO subsidyDO = rotationSubsidyMapper.selectByPrimaryKey(vo.getId());
            if (vo.getOperationType() == 0) {
                subsidyDO.setQsZt(ReserveReportConstant.DTJ.getValue());
                subsidyDO.setQsZtmc(ReserveReportConstant.DTJ.getName());
            } else if (vo.getOperationType() == 1) {
                subsidyDO.setQsZt(ReserveReportConstant.DGZ.getValue());
                subsidyDO.setQsZtmc(ReserveReportConstant.DGZ.getName());
            }
            subsidyDO.setQsDwfzr(vo.getQsDwfzr());
            subsidyDO.setQsShr(vo.getQsShr());
            subsidyDO.setQsZbr(vo.getQsZbr());
            subsidyDO.setQsTbrq(vo.getQsTbrq());
            subsidyDO.setUpdateDate(new Date());
            subsidyDO.setUpdater(CurrentUtil.getUserName());
            subsidyDO.setQsbfzt(LIQUIDATE_UNALLOCATED);
            List<RotationSubsidyDetailVO> detailList = vo.getLiquidateList();
            int res = rotationSubsidyMapper.updateByPrimaryKey(subsidyDO);
            if (res > 0) {
                return saveBatchDetail(subsidyDO.getId(), detailList, SJLX_LIQUIDATE) > 0;
            }
        }
        return false;
    }

    public Boolean updateRotationSubsidy(String type, RotationSubsidyVO vo) {
        RotationSubsidyDO rotationSubsidyDO = rotationSubsidyMapper.selectByPrimaryKey(vo.getId());
        if (rotationSubsidyDO == null) {
            return false;
        }
        switch (type) {
            case ROTATION_SUBSIDY_TYPE1:
                if (ReserveReportConstant.GZBH.getValue().equals(rotationSubsidyDO.getYsZt())
                        || ReserveReportConstant.DTJ.getValue().equals(rotationSubsidyDO.getYsZt())) {
                    rotationSubsidyDO.setYsDwfzr(vo.getYsDwfzr());
                    rotationSubsidyDO.setYsShr(vo.getYsShr());
                    rotationSubsidyDO.setYsZbr(vo.getYsZbr());
                    rotationSubsidyDO.setYsTbrq(vo.getYsTbrq());
                    if (Objects.equals(1, vo.getOperationType())) {
                        rotationSubsidyDO.setYsZt(ReserveReportConstant.DGZ.getValue());
                        rotationSubsidyDO.setYsZtmc(ReserveReportConstant.DGZ.getName());
                    }
                    rotationSubsidyDO.setUpdateDate(new Date());
                    rotationSubsidyDO.setUpdater(CurrentUtil.getUserName());
                    int res = rotationSubsidyMapper.updateByPrimaryKey(rotationSubsidyDO);
                    if (res > 0 && vo.getBudgetList() != null && vo.getBudgetList().size() > 0) {
                        return saveBatchDetail(rotationSubsidyDO.getId(), vo.getBudgetList(), SJLX_BUDGET) > 0;
                    }
                } else if (ReserveReportConstant.DGZ.getValue().equals(rotationSubsidyDO.getYsZt())
                        || ReserveReportConstant.JSBH.getValue().equals(rotationSubsidyDO.getYsZt())) {

                    if (vo.getYsGzzt() != null && vo.getYsGzzt() == 1 && StringUtils.isNotEmpty(vo.getYsGz())) {
                        rotationSubsidyDO.setYsZt(ReserveReportConstant.DJS.getValue());
                        rotationSubsidyDO.setYsZtmc(ReserveReportConstant.DJS.getName());
                    } else if (vo.getYsGzzt() != null && vo.getYsGzzt() == 0) {
                        rotationSubsidyDO.setYsZt(ReserveReportConstant.GZBH.getValue());
                        rotationSubsidyDO.setYsZtmc(ReserveReportConstant.GZBH.getName());
                    } else {
                        return false;
                    }
                    rotationSubsidyDO.setYsGzzt(vo.getYsGzzt());
                    rotationSubsidyDO.setYsGz(vo.getYsGz());
                    rotationSubsidyDO.setYsGzsj(vo.getYsGzsj());
                    rotationSubsidyDO.setYsGzr(vo.getYsGzr());
                } else if (ReserveReportConstant.DJS.getValue().equals(rotationSubsidyDO.getYsZt())) {
                    if (vo.getYsJszt() != null && vo.getYsJszt() == 1) {
                        rotationSubsidyDO.setYsReceiveOpinion(vo.getYsReceiveOpinion());
                        rotationSubsidyDO.setYsZt(ReserveReportConstant.YJS.getValue());
                        rotationSubsidyDO.setYsZtmc(ReserveReportConstant.YJS.getName());
                    } else if (vo.getYsJszt() != null && vo.getYsJszt() == 0) {
                        rotationSubsidyDO.setYsZt(ReserveReportConstant.JSBH.getValue());
                        rotationSubsidyDO.setYsZtmc(ReserveReportConstant.JSBH.getName());
                    } else {
                        return false;
                    }
                    rotationSubsidyDO.setYsJszt(vo.getYsJszt());
                    rotationSubsidyDO.setYsJsr(vo.getYsJsr());
                    rotationSubsidyDO.setYsJsrq(vo.getYsJsrq());
                } else if (ReserveReportConstant.YJS.getValue().equals(rotationSubsidyDO.getYsZt())) { //撤销
                    rotationSubsidyDO.setYsZt(ReserveReportConstant.DJS.getValue());
                    rotationSubsidyDO.setYsZtmc(ReserveReportConstant.DJS.getName());
                } else {
                    return false;
                }
                break;
            case ROTATION_SUBSIDY_TYPE2:
                if (ReserveReportConstant.GZBH.getValue().equals(rotationSubsidyDO.getQsZt())
                        || ReserveReportConstant.DTJ.getValue().equals(rotationSubsidyDO.getQsZt())) {
                    rotationSubsidyDO.setQsDwfzr(vo.getQsDwfzr());
                    rotationSubsidyDO.setQsShr(vo.getQsShr());
                    rotationSubsidyDO.setQsZbr(vo.getQsZbr());
                    rotationSubsidyDO.setQsTbrq(vo.getQsTbrq());
                    if (Objects.equals(1, vo.getOperationType())) {
                        rotationSubsidyDO.setQsZt(ReserveReportConstant.DGZ.getValue());
                        rotationSubsidyDO.setQsZtmc(ReserveReportConstant.DGZ.getName());
                    }
                    rotationSubsidyDO.setUpdateDate(new Date());
                    rotationSubsidyDO.setUpdater(CurrentUtil.getUserName());
                    int res = rotationSubsidyMapper.updateByPrimaryKey(rotationSubsidyDO);
                    if (res > 0) {
                        return saveBatchDetail(rotationSubsidyDO.getId(), vo.getLiquidateList(), SJLX_LIQUIDATE) > 0;
                    }
                } else if (ReserveReportConstant.DGZ.getValue().equals(rotationSubsidyDO.getQsZt())
                        || ReserveReportConstant.JSBH.getValue().equals(rotationSubsidyDO.getQsZt())) {
                    if (vo.getQsGzzt() != null && vo.getQsGzzt() == 1 && StringUtils.isNotEmpty(vo.getQsGz())) {
                        rotationSubsidyDO.setQsZt(ReserveReportConstant.DJS.getValue());
                        rotationSubsidyDO.setQsZtmc(ReserveReportConstant.DJS.getName());
                    } else if (vo.getQsGzzt() != null && vo.getQsGzzt() == 0) {
                        rotationSubsidyDO.setQsZt(ReserveReportConstant.GZBH.getValue());
                        rotationSubsidyDO.setQsZtmc(ReserveReportConstant.GZBH.getName());
                    } else {
                        return false;
                    }
                    rotationSubsidyDO.setQsGzzt(vo.getQsGzzt());
                    rotationSubsidyDO.setQsGz(vo.getQsGz());
                    rotationSubsidyDO.setQsGzsj(vo.getQsGzsj());
                    rotationSubsidyDO.setQsGzr(vo.getQsGzr());
                } else if (ReserveReportConstant.DJS.getValue().equals(rotationSubsidyDO.getQsZt())) {
                    if (vo.getQsJszt() != null && vo.getQsJszt() == 1) {
                        rotationSubsidyDO.setQsReceiveOpinion(vo.getQsReceiveOpinion());
                        rotationSubsidyDO.setQsZt(ReserveReportConstant.YJS.getValue());
                        rotationSubsidyDO.setQsZtmc(ReserveReportConstant.YJS.getName());
                    } else if (vo.getQsJszt() != null && vo.getQsJszt() == 0) {
                        rotationSubsidyDO.setQsZt(ReserveReportConstant.JSBH.getValue());
                        rotationSubsidyDO.setQsZtmc(ReserveReportConstant.JSBH.getName());
                    } else {
                        return false;
                    }
                    rotationSubsidyDO.setQsJszt(vo.getQsJszt());
                    rotationSubsidyDO.setQsJsr(vo.getQsJsr());
                    rotationSubsidyDO.setQsJsrq(vo.getQsJsrq());
                } else if (ReserveReportConstant.YJS.getValue().equals(rotationSubsidyDO.getQsZt())) {
                    rotationSubsidyDO.setQsZt(ReserveReportConstant.DJS.getValue());
                    rotationSubsidyDO.setQsZtmc(ReserveReportConstant.DJS.getName());
                } else {
                    return false;
                }
                break;
            default:
                return false;
        }
        return rotationSubsidyMapper.updateByPrimaryKey(rotationSubsidyDO) > 0;

    }

    private Integer saveBatchDetail(String rsId, List<RotationSubsidyDetailVO> detailVOList, Integer sjlx) {
        rotationSubsidyDetailMapper.deleteByRsIdAndSjlx(rsId, sjlx);
        detailVOList.forEach(rotationSubsidyDetailVO -> {
            rotationSubsidyDetailVO.setId(UUIDUtils.uuid());
            rotationSubsidyDetailVO.setRsId(rsId);
            rotationSubsidyDetailVO.setSjlx(sjlx);
        });
        List<RotationSubsidyDetailDO> detailDOList = JSONObject.parseArray(JSONObject.toJSONString(detailVOList), RotationSubsidyDetailDO.class);
        return rotationSubsidyDetailMapper.insertBatch(detailDOList);
    }

    public PageInfo<RotationSubsidyVO> getRotationSubsidyPageList(Integer pageNum, Integer pageSize, RotationSubsidyQueryVO queryVO) {
        PageInfo<RotationSubsidyVO> pageInfoVO = new PageInfo<RotationSubsidyVO>();
        PageHelper.startPage(pageNum, pageSize);
        List<RotationSubsidyDO> list = rotationSubsidyMapper.selectByQuery(queryVO);
        PageInfo<RotationSubsidyDO> pageInfoDO = new PageInfo<RotationSubsidyDO>(list);
        LsBeanUtils.copyAllProperties(pageInfoDO, pageInfoVO);
        return pageInfoVO;
    }

    public RotationSubsidyVO getRotationSubsidyInfo(String rsId) {
        RotationSubsidyDO rotationSubsidyDO = rotationSubsidyMapper.selectByPrimaryKey(rsId);
        if (rotationSubsidyDO != null) {
            RotationSubsidyVO vo = JSONObject.parseObject(JSONObject.toJSONString(rotationSubsidyDO), RotationSubsidyVO.class);
            List<RotationSubsidyDetailDO> budgetList = rotationSubsidyDetailMapper.selectByRsIdAndSjlx(rsId, SJLX_BUDGET);
            if (budgetList != null && budgetList.size() > 0) {
                List<RotationSubsidyDetailVO> budgetVOList = JSONObject.parseArray(JSONObject.toJSONString(budgetList), RotationSubsidyDetailVO.class);
                vo.setBudgetList(budgetVOList);
            }
            List<RotationSubsidyDetailDO> liquidateList = rotationSubsidyDetailMapper.selectByRsIdAndSjlx(rsId, SJLX_LIQUIDATE);
            if (liquidateList != null && liquidateList.size() > 0) {
                List<RotationSubsidyDetailVO> liquidateVOList = JSONObject.parseArray(JSONObject.toJSONString(liquidateList), RotationSubsidyDetailVO.class);
                vo.setLiquidateList(liquidateVOList);
            }
            // 查询轮换协议编码
            RotatePlanProtocolRecordDO rotatePlanProtocolRecordDO = new RotatePlanProtocolRecordDO();
            rotatePlanProtocolRecordDO.setRotationSubsidyId(rsId);
            List<RotatePlanProtocolRecordDO> select = rotatePlanProtocolRecordMapper.select(rotatePlanProtocolRecordDO);
            List<String> collect = select.stream().map(RotatePlanProtocolRecordDO::getLhxybm).distinct().collect(Collectors.toList());
            vo.setLhxybmList(collect);
            return vo;
        }
        return null;
    }


    public List<RotationSubsidyVO> getRotationSubsidyApprovalList(String type) {
        RotationSubsidyQueryVO queryVO = new RotationSubsidyQueryVO();
        switch (type) {
            case ROTATION_SUBSIDY_TYPE1:
                queryVO.setYsZt(ReserveReportConstant.YJS.getValue());
                //queryVO.setYsbfzt(BUDGET_UNALLOCATED);
                break;
            case ROTATION_SUBSIDY_TYPE2:
                queryVO.setQsZt(ReserveReportConstant.YJS.getValue());
                //queryVO.setQsbfzt(LIQUIDATE_UNALLOCATED);
                break;
            default:
                return null;
        }
        List<RotationSubsidyDO> rotationSubsidyDOList = rotationSubsidyMapper.selectByQuery(queryVO);
        if (rotationSubsidyDOList != null && rotationSubsidyDOList.size() > 0) {
            return JSONObject.parseArray(JSONObject.toJSONString(rotationSubsidyDOList), RotationSubsidyVO.class);
        }
        return null;
    }

    public RotationSubsidySummaryVO initRotationSubsidySummary(String type, List<String> rotationSubsidyIds) {
        RotationSubsidyQueryVO queryVO = new RotationSubsidyQueryVO();
        queryVO.setRotationSubsidyIds(rotationSubsidyIds);
        Integer dataType = null;
        switch (type) {
            case ROTATION_SUBSIDY_TYPE1:
                queryVO.setYsZt(ReserveReportConstant.YJS.getValue());
                queryVO.setYsbfzt(BUDGET_UNALLOCATED);
                queryVO.setSjlx(SJLX_BUDGET);
                dataType = SJLX_BUDGET;
                break;
            case ROTATION_SUBSIDY_TYPE2:
                queryVO.setQsZt(ReserveReportConstant.YJS.getValue());
                queryVO.setQsbfzt(LIQUIDATE_UNALLOCATED);
                queryVO.setSjlx(SJLX_LIQUIDATE);
                dataType = SJLX_LIQUIDATE;
                break;
            default:
                return null;
        }

        List<RotationSubsidySummaryDetailVO> summaryDetailVOList = rotationSubsidySummaryDetailMapper.initRotationSubsidySummary(queryVO);
        RotationSubsidySummaryVO summaryVO = new RotationSubsidySummaryVO();
        List<String> pzbmList = new ArrayList<>();
        summaryVO.setPzbm(summaryDetailVOList.get(0).getPzbm());
        pzbmList.add(summaryVO.getPzbm().toString());
        summaryVO.setPzmc(summaryDetailVOList.get(0).getPzmc());
        if (summaryDetailVOList != null && summaryDetailVOList.size() > 0) {
            for (RotationSubsidySummaryDetailVO detailVO : summaryDetailVOList) {
                detailVO.setBcybje((detailVO.getYgbflhbt().multiply(new BigDecimal(0.7))).setScale(2, BigDecimal.ROUND_HALF_UP));
                if (!pzbmList.contains(detailVO.getPzbm())) {
                    pzbmList.add(detailVO.getPzbm());
                    summaryVO.setPzmc(summaryVO.getPzmc() + "," + detailVO.getPzmc());
                }
                if (type.equals("liquidate")) {
                    detailVO.setQsybje(detailVO.getYgbflhbt().subtract(detailVO.getBcybje()));
                }
            }
        }

        summaryVO.setBfrq(new Date());
        summaryVO.setDataType(dataType);
        summaryVO.setTabulator(CurrentUtil.getUserName());

        //默认本年度
        Calendar calendar = Calendar.getInstance();
        summaryVO.setLhnd(String.valueOf(calendar.get(Calendar.YEAR)));
        summaryVO.setOrgCode(CurrentUtil.getOrgId());
        summaryVO.setOrgName(CurrentUtil.getOrgName());
        summaryVO.setDetailList(summaryDetailVOList);
        return summaryVO;
    }

    @Transactional
    public Integer saveRotationSubsidySummary(String type, RotationSubsidySummaryVO summaryVO) {
        Integer dataType = null;
        switch (type) {
            case ROTATION_SUBSIDY_TYPE1:
                dataType = SJLX_BUDGET;
                break;
            case ROTATION_SUBSIDY_TYPE2:
                dataType = SJLX_LIQUIDATE;
                break;
            default:
                return null;
        }
        List<RotationSubsidySummaryDetailVO> detailVOList = summaryVO.getDetailList();
        Integer sbqysl = 0;
        BigDecimal ygbflhbt = new BigDecimal(0);
        BigDecimal bcybje = new BigDecimal(0);
        BigDecimal qsybje = new BigDecimal(0);

        List<String> ccqyList = new ArrayList<>();
        List<String> idList = new ArrayList<>();
        for (RotationSubsidySummaryDetailVO detailVO : detailVOList) {
            idList.add(detailVO.getRsId());
            if (!ccqyList.contains(detailVO.getCcqy())) {
                ccqyList.add(detailVO.getCcqy());
            }
            ygbflhbt = ygbflhbt.add(detailVO.getYgbflhbt());
            if (detailVO.getBcybje() != null) {
                bcybje = bcybje.add(detailVO.getBcybje());
            }
            if (detailVO.getQsybje() != null) {
                qsybje = qsybje.add(detailVO.getQsybje());
            }
        }
        sbqysl = ccqyList.size();
        RotationSubsidySummaryDO summaryDO = JSONObject.parseObject(JSONObject.toJSONString(summaryVO), RotationSubsidySummaryDO.class);
        summaryDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-", ""));
        summaryDO.setDataType(dataType);
        summaryDO.setIsDelete(0);
        summaryDO.setSbqysl(sbqysl);
        summaryDO.setBcybje(bcybje);
        summaryDO.setYgbflhbt(ygbflhbt);
        summaryDO.setQsybje(qsybje);
        if (summaryVO.getOperationType() != null && summaryVO.getOperationType() == 0) {
            summaryDO.setStatus(ReserveReportConstant.DTJSH.getValue());
            summaryDO.setStatusName(ReserveReportConstant.DTJSH.getName());
        } else {
            summaryDO.setStatus(ReserveReportConstant.DFH.getValue());
            summaryDO.setStatusName(ReserveReportConstant.DFH.getName());
        }
        summaryDO.setCreateDate(new Date());
//        summaryDO.setCreator(CurrentUtil.getUserName());
        Integer res = rotationSubsidySummaryMapper.insert(summaryDO);
        Integer bfzt = 1;
        if (dataType == 1) {
            rotationSubsidyMapper.updateStatus(idList, bfzt);
        } else if (dataType == 2) {
            rotationSubsidyMapper.updateStatus1(idList, bfzt);
        }
        if (res > 0) {
            for (RotationSubsidySummaryDetailVO detailVO : detailVOList) {
                RotationSubsidySummaryDetailDO detailDO = JSONObject.parseObject(JSONObject.toJSONString(detailVO), RotationSubsidySummaryDetailDO.class);
                detailDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-", ""));
                detailDO.setRssId(summaryDO.getId());
                rotationSubsidySummaryDetailMapper.insert(detailDO);
            }
            return res;
        }
        return null;
    }

    public Integer updateRotationSubsidySummary(Integer type, RotationSubsidySummaryVO summaryVO) {
        RotationSubsidySummaryDO originSummaryDO = rotationSubsidySummaryMapper.selectByPrimaryKey(summaryVO.getId());
        if (originSummaryDO == null) {
            return null;
        }
        if (type == 1) {
            //修改
            RotationSubsidySummaryDO summaryDO = JSONObject.parseObject(JSONObject.toJSONString(summaryVO), RotationSubsidySummaryDO.class);
            summaryDO.setUpdateDate(new Date());
            summaryDO.setUpdater(CurrentUtil.getUserName());
            if (summaryVO.getOperationType() != null && summaryVO.getOperationType().equals(1)) {
                summaryDO.setStatus(ReserveReportConstant.DFH.getValue());
                summaryDO.setStatusName(ReserveReportConstant.DFH.getName());
            }
            List<RotationSubsidySummaryDetailVO> detailVOList = summaryVO.getDetailList();
            int res = rotationSubsidySummaryMapper.updateByPrimaryKeySelective(summaryDO);
            if (res > 0) {
                if (detailVOList != null && detailVOList.size() > 0) {
                    RotationSubsidySummaryDetailDO detailQueryDO = new RotationSubsidySummaryDetailDO();
                    detailQueryDO.setRssId(summaryDO.getId());
                    //先删除原来汇总数据，再插入新的汇总数据
                    rotationSubsidySummaryDetailMapper.delete(detailQueryDO);
                    for (RotationSubsidySummaryDetailVO detailVO : detailVOList) {
                        RotationSubsidySummaryDetailDO detailDO = JSONObject.parseObject(JSONObject.toJSONString(detailVO), RotationSubsidySummaryDetailDO.class);
                        detailDO.setId(UUID.randomUUID().toString().toLowerCase().replace("-", ""));
                        detailDO.setRssId(summaryDO.getId());
                        rotationSubsidySummaryDetailMapper.insert(detailDO);
                    }
                }

            }
            return res;

        } else if (type == 2) {//复核
            //判断复核状态
            if (ReserveReportConstant.DFH.getValue().equals(originSummaryDO.getStatus()) || ReserveReportConstant.CWPSBH.getValue().equals(originSummaryDO.getStatus())) {
                originSummaryDO.setStatus(ReserveReportConstant.FHBH.getValue());
                originSummaryDO.setStatusName(ReserveReportConstant.FHBH.getName());
                originSummaryDO.setReviewer(summaryVO.getReviewer());
                originSummaryDO.setReviewDate(summaryVO.getReviewDate());
                originSummaryDO.setReviewStatus(summaryVO.getReviewStatus());
                originSummaryDO.setReviewOpinion(summaryVO.getReviewOpinion());
                if (summaryVO.getReviewStatus() == 1) {
                    originSummaryDO.setStatus(ReserveReportConstant.DCWPS.getValue());
                    originSummaryDO.setStatusName(ReserveReportConstant.DCWPS.getName());
                }
            }
        } else if (type == 3) {//复核
            //判断财务批示
            if (ReserveReportConstant.DCWPS.getValue().equals(originSummaryDO.getStatus()) || ReserveReportConstant.DWFZRPSBH.getValue().equals(originSummaryDO.getStatus())) {
                originSummaryDO.setStatus(ReserveReportConstant.CWPSBH.getValue());
                originSummaryDO.setStatusName(ReserveReportConstant.CWPSBH.getName());
                originSummaryDO.setFinanceUsername(summaryVO.getFinanceUsername());
                originSummaryDO.setFinanceDate(summaryVO.getFinanceDate());
                originSummaryDO.setFinanceStatus(summaryVO.getFinanceStatus());
                originSummaryDO.setFinanceOpinion(summaryVO.getFinanceOpinion());
                if (summaryVO.getFinanceStatus() == 1) {
                    originSummaryDO.setStatus(ReserveReportConstant.DDWFZRPS.getValue());
                    originSummaryDO.setStatusName(ReserveReportConstant.DDWFZRPS.getName());
                }
            }
        } else if (type == 4) {//复核
            //判断单位领导
            if (ReserveReportConstant.DDWFZRPS.getValue().equals(originSummaryDO.getStatus())) {
                originSummaryDO.setStatus(ReserveReportConstant.DWFZRPSBH.getValue());
                originSummaryDO.setStatusName(ReserveReportConstant.DWFZRPSBH.getName());
                originSummaryDO.setLeaderUsername(summaryVO.getLeaderUsername());
                originSummaryDO.setLeaderDate(summaryVO.getLeaderDate());
                originSummaryDO.setLeaderStatus(summaryVO.getLeaderStatus());
                originSummaryDO.setLeaderOpinion(summaryVO.getLeaderOpinion());
                if (summaryVO.getLeaderStatus() == 1) {
                    originSummaryDO.setStatus(ReserveReportConstant.YWC.getValue());
                    originSummaryDO.setStatusName(ReserveReportConstant.YWC.getName());
                }
            }
        } else {
            return null;
        }
        return rotationSubsidySummaryMapper.updateByPrimaryKeySelective(originSummaryDO);
    }

    public PageInfo<RotationSubsidySummaryVO> getRotationSubsidySummaryPageList(Integer pageNum, Integer pageSize, RotationSubsidySummaryQueryVO queryVO) {

        PageInfo<RotationSubsidySummaryVO> pageInfoVO = new PageInfo<RotationSubsidySummaryVO>();
        PageHelper.startPage(pageNum, pageSize);
        List<RotationSubsidySummaryDO> list = rotationSubsidySummaryMapper.selectByQuery(queryVO);
        List<RotationSubsidySummaryDO> collect = list.stream().distinct().collect(Collectors.toList());
        PageInfo<RotationSubsidySummaryDO> pageInfoDO = new PageInfo<RotationSubsidySummaryDO>(collect);
        LsBeanUtils.copyAllProperties(pageInfoDO, pageInfoVO);
        return pageInfoVO;
    }

    public RotationSubsidySummaryVO getRotationSubsidySummaryInfo(String id) {
        RotationSubsidySummaryDO rotationSubsidySummaryDO = rotationSubsidySummaryMapper.selectByPrimaryKey(id);
        if (rotationSubsidySummaryDO == null) {
            return null;
        }
        RotationSubsidySummaryVO rotationSubsidySummaryVO = new RotationSubsidySummaryVO();
        LsBeanUtils.copyAllProperties(rotationSubsidySummaryDO, rotationSubsidySummaryVO);
        RotationSubsidySummaryDetailDO detailQueryDO = new RotationSubsidySummaryDetailDO();
        detailQueryDO.setRssId(rotationSubsidySummaryDO.getId());
        List<RotationSubsidySummaryDetailDO> detailList = rotationSubsidySummaryDetailMapper.select(detailQueryDO);
        List<RotationSubsidySummaryDetailVO> detailVOList = new ArrayList<RotationSubsidySummaryDetailVO>();
        LsBeanUtils.copyCollection(detailList, detailVOList, RotationSubsidySummaryDetailVO.class);
        rotationSubsidySummaryVO.setDetailList(detailVOList);
        return rotationSubsidySummaryVO;
    }

    @Transactional
    public Integer deleteRotationSubsidySummary(String id) {
        try {
            int re = rotationSubsidySummaryMapper.updateStatus(id);
        } catch (Exception e) {
            e.printStackTrace();
        }

        int res = rotationSubsidySummaryMapper.deleteByPrimaryKey(id);

        if (res > 0) {
            RotationSubsidySummaryDetailDO detailQueryDO = new RotationSubsidySummaryDetailDO();
            detailQueryDO.setRssId(id);
            res = rotationSubsidySummaryDetailMapper.delete(detailQueryDO);
        }
        return res > 0 ? 1 : 0;
    }

    public PageInfo<RotationSubsidyVO> getRotationSubsidyList(Integer pageNum,
                                                              Integer pageSize,
                                                              RotationSubsidyQueryVO queryVO) {
        PageHelper.startPage(pageNum, pageSize);
        List<RotationSubsidyDO> doList = rotationSubsidyMapper.selectByQuery(queryVO);
        List<RotationSubsidyVO> voList = new ArrayList<>();
        LsBeanUtils.copyCollection(doList, voList, RotationSubsidyVO.class);
        return new PageInfo<>(voList);
    }

    public List<RotationSubsidyGrainVO> getRotationSubsidyGrainList(String ccqybm, String pzbm) {
        // 查询 签订轮换协议-包干轮换：状态为双方已确认 查库代码
        // sskddm 所属库点代码
//        List<String> sskddm = rotationSubsidyMapper.selectSskddm(ccqybm);
//        System.out.println("所属库点代码" + sskddm);
        // 查询品种的存储年限
        String ccnx = rotationSubsidyMapper.selectScnd(pzbm);
        // 查询子品种代码
        List<String> childPzCode = rotationSubsidyMapper.selectChildCode(pzbm);
        // 查询轮换协议
        List<RotatePlanProtocolDetailVO> detailVOList = rotationSubsidyMapper.selectDetail(ccqybm, childPzCode);
        // 详情明细
        ArrayList<RotationSubsidyGrainVO> rotationSubsidyGrainVOS = new ArrayList<>();
        // 查详情
        List<RotationSubsidyGrainVO> collect = detailVOList.stream().map(detail -> {
            RotationSubsidyGrainVO rotationSubsidyGrainVO = new RotationSubsidyGrainVO();
            rotationSubsidyGrainVO.setPzbm(detail.getPzbm());
            rotationSubsidyGrainVO.setLhsl(detail.getSqlczl());
            rotationSubsidyGrainVO.setCcqy(detail.getKdmc());
            rotationSubsidyGrainVO.setSftj("0");
            rotationSubsidyGrainVO.setScnd(detail.getScnf());
            rotationSubsidyGrainVO.setCcqybm(detail.getSskd());
            rotationSubsidyGrainVO.setCcnx(ccnx);
            return rotationSubsidyGrainVO;
        }).collect(Collectors.toList());
        rotationSubsidyGrainVOS.addAll(collect);
        return rotationSubsidyGrainVOS;
    }

    public List<RotatePlanProtocolVO> getRotationProtocol(String ccqybm) {
        List<RotatePlanProtocolVO> rotationProtocol = rotationSubsidyMapper.getRotationProtocol(ccqybm);
        RotatePlanProtocolRecordDO rotatePlanProtocolRecordDO = new RotatePlanProtocolRecordDO();
        rotatePlanProtocolRecordDO.setCcqy(ccqybm.substring(0, ccqybm.length() - 3));
        List<RotatePlanProtocolRecordDO> select = rotatePlanProtocolRecordMapper.select(rotatePlanProtocolRecordDO);
        for (RotatePlanProtocolVO rotatePlanProtocolVO : rotationProtocol) {
            rotatePlanProtocolVO.setHaveReport(0);
            for (RotatePlanProtocolRecordDO planProtocolRecordDO : select) {
                if (StringUtils.equals(rotatePlanProtocolVO.getCcqymc(), planProtocolRecordDO.getCcqymc())
                        && Objects.equals(1, planProtocolRecordDO.getHaveReport())
                        && Objects.equals(rotatePlanProtocolVO.getLhxybm(), planProtocolRecordDO.getLhxybm())) {
                    rotatePlanProtocolVO.setHaveReport(1);
                }
            }
        }
//        rotationProtocol.stream().map(it -> select.forEach(protocol -> {
//            it.setHaveReport(0);
//            if (it.getCcqymc().equals(protocol.getCcqymc())
//                    && Objects.equals(1, protocol.getHaveReport())
//                    && Objects.equals(it.getLhxybm(), protocol.getLhxybm())) {
//                it.setHaveReport(1);
//            }
//            return it;
//        }));
        return rotationProtocol;
    }

    public List<RotationSubsidyGrainVO> getRotationProtocolDetail(RotateProtocolVO rotateProtocolVO) {
        // 查询品种的存储年限
        String ccnx = rotationSubsidyMapper.selectScnd(rotateProtocolVO.getPzbm());
        List<RotatePlanProtocolVO> rotatePlanProtocolVOS = rotateProtocolVO.getLhxybm().stream().map(it -> {
            ResponseWrapper responseWrapper = rotatePlanProtocoFeign1.protocolDetail(it);
            RotatePlanProtocolVO rotatePlanProtocolVO = JSONObject.parseObject(JSON.toJSONString(responseWrapper.getData()), RotatePlanProtocolVO.class);
            return rotatePlanProtocolVO;
        }).collect(Collectors.toList());
        // 轮换协议明细
        ArrayList<RotatePlanProtocolDetailVO> detailVOList = new ArrayList<>();
        rotatePlanProtocolVOS.stream().forEach(it -> {
            detailVOList.addAll(it.getProtocolDetailList());
        });
        detailVOList.removeIf(Objects::isNull);
        // 返回结果
        ArrayList<RotationSubsidyGrainVO> rotationSubsidyGrainVOS = new ArrayList<>();
        // 分组
        Map<String, List<RotatePlanProtocolDetailVO>> scnfList = detailVOList.stream().collect(Collectors.groupingBy(RotatePlanProtocolDetailVO::getScnf));
        scnfList.forEach((k, v) -> {
            RotationSubsidyGrainVO rotationSubsidyGrainVO = new RotationSubsidyGrainVO();
            rotationSubsidyGrainVO.setScnd(k);
            rotationSubsidyGrainVO.setPzbm(v.get(0).getPzbm());
            rotationSubsidyGrainVO.setLhsl(v.stream().mapToDouble(RotatePlanProtocolDetailVO::getSqlczl).sum());
            rotationSubsidyGrainVO.setCcnx(ccnx);
            rotationSubsidyGrainVO.setSftj("0");
            rotationSubsidyGrainVO.setCcqybm(v.get(0).getSskd());
            rotationSubsidyGrainVO.setCcqy(v.get(0).getKdmc());
            rotationSubsidyGrainVOS.add(rotationSubsidyGrainVO);
        });
        return rotationSubsidyGrainVOS;
    }
}
