package com.unis.ynls.irpt.server.entity;

import com.unis.common.utils.UUIDUtils;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.MappedSuperclass;
import java.io.Serializable;
import java.util.Date;





/**
 * 基础实体类
 * 所有继承该实体类的实体在映射成表的时候会自动加入该类中的字段
 *
 * @author Garfield
 */
@Getter
@Setter
@MappedSuperclass
public abstract class BaseEntity implements Serializable {
    private static final long serialVersionUID = -5082401234492420871L;

    @Id
    @Column(name="ID")
    private String id = UUIDUtils.uuid();

    /**
     * 创建时间
     */
    @Column(name="CREATE_TIME")
    private Date createTime;
    
    /**
     * 创建人id
     */
    @Column(name="CREATE_BY")
    private String createBy;

    /**
     * 修改时间
     */
    @Column(name="UPDATE_TIME")
    private Date updateTime;
    
    /**
     * 修改人
     */
    @Column(name="UPDATE_BY")
    private String updateBy;
    
    /**
     * 删除时间
     */
    @Column(name="DELETE_TIME")
    private Date deleteTime;
    
    /**
     * 删除人
     */
    @Column(name="DELETE_BY")
    private String deleteBy;
    
    /**
     * 组织机构id
     */
    @Column(name="ORG_ID")
    private String orgId;
    
    /**
     * 部门ID
     */
    @Column(name="DEPT_ID")
    private String deptId;

    /**
     * 行政区划
     */
    @Column(name="AREA_CODE")
    private String areaCode;

    
    /**
     * 状态默认为1
     */
    @ApiModelProperty(value="状态")
    @Column(name="STATUS")
    private Integer status = 1;
    
    /**
     * 创建人
     */
    @Column(name="CREATOR")
    @ApiModelProperty(value="创建者")
    private String creator;
    
    /**
     * 创建人编号
     */
    @Column(name="CREATORCODE")
    @ApiModelProperty(value="创建人编号")
    private String creatorCode;

    /**
     * 创建时间
     */
    @Column(name="CREATEDATE")
    @ApiModelProperty(value="创建时间")
    private Date createDate;

    /**
     * 刷新时间
     */
    @Column(name="REFRESHTIME")
    @ApiModelProperty(value="刷新时间")
    private Date refreshTime;
    
    /**
     * 刷新人
     */
    @Column(name="REFRESHER")
    @ApiModelProperty(value="刷新人")
    private String refresher;
    
    /**
     * 刷新人编号
     */
    @Column(name="REFRESHERCODE")
    @ApiModelProperty(value="刷新人编号")
    private String refresherCode;

    /**
     * 备注
     */
    @Column(name="REMARK")
    @ApiModelProperty(value="备注")
    private String remark;
}
