package com.unis.ynls.irpt.server.listener;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.unis.ynls.irpt.server.common.ActionConstant;
import com.unis.ynls.irpt.server.config.IntegrationProcess;
import com.unis.ynls.irpt.server.entity.sys.MqUserDTO;
import com.unis.ynls.irpt.server.entity.sys.OrganizationDTO;
import com.unis.ynls.irpt.server.entity.sys.RabbitObjectTO;
import com.unis.ynls.irpt.server.service.OrgUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.stream.annotation.EnableBinding;
import org.springframework.cloud.stream.annotation.StreamListener;

/**
 * 
 * @ClassName: MessageListener
 * @Description: 监听rabbitmq生产者
 * @author xmpu
 * @date 2018年8月21日 下午7:54:56
 * 
 * @version v1.0
 */
@EnableBinding(value = { IntegrationProcess.class })
public class MessageListener {

	@Autowired
	private OrgUserService orgUserService;

	/**
	 * 
	 * @Description: 入口方法，根据动作区分具体业务
	 *
	 * @date 2018年11月27日,上午11:03:50
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param json
	 */
	@StreamListener(IntegrationProcess.INPUT)
	public void input(String json) {
		RabbitObjectTO rabbitObjectTO = JSON.parseObject(json, new TypeReference<RabbitObjectTO>() {
		});
		String action = rabbitObjectTO.getAction();
		MqUserDTO userDTO;
		OrganizationDTO organizationDTO;
		switch (action) {
			case ActionConstant.USER_ADD:
				userDTO = JSON.parseObject(rabbitObjectTO.getObject().toString(), MqUserDTO.class);
				orgUserService.saveUserByMq(userDTO);
				break;
			case ActionConstant.USER_DELETE:
				userDTO = JSON.parseObject(rabbitObjectTO.getObject().toString(), MqUserDTO.class);
				orgUserService.deleteUserByMq(userDTO.getUsername());
				break;
			case ActionConstant.USER_EDIT:
				userDTO = JSON.parseObject(rabbitObjectTO.getObject().toString(), MqUserDTO.class);
				orgUserService.saveUserByMq(userDTO);
				break;
			case ActionConstant.ORG_ADD:
				organizationDTO = JSON.parseObject(rabbitObjectTO.getObject().toString(), OrganizationDTO.class);
				orgUserService.saveOrgByMq(organizationDTO);
				break;
			case ActionConstant.ORG_DELETE:
				organizationDTO = JSON.parseObject(rabbitObjectTO.getObject().toString(), OrganizationDTO.class);
				orgUserService.deleteOrgByMq(organizationDTO);
				break;
			case ActionConstant.ORG_EDIT:
				organizationDTO = JSON.parseObject(rabbitObjectTO.getObject().toString(), OrganizationDTO.class);
				orgUserService.saveOrgByMq(organizationDTO);
				break;
			default:
				break;
		}
	}
}
