package com.unis.ynls.irpt.server.mapper;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import com.unis.ynls.irpt.common.VO.task.ReportInfoVO;
import com.unis.ynls.irpt.common.VO.task.RptListVO;
import com.unis.ynls.irpt.common.VO.task.TaskInfoVO;

import java.util.List;
import java.util.Map;

/**
 * @InterfaceName: TaskInfoMapper
 * @Description: IRPT报表管理
 * @author liyb
 * @version v1.0
 * @date 2018-12-27 14:37:36
 */
@Transactional(rollbackFor = Exception.class)
@org.apache.ibatis.annotations.Mapper
@Repository
public interface TaskInfoMapper {
    /**
     * 根据报表ID获取报表信息
     * @param taskId
     * @return Map
     * @author liyb
     * @date 2018-12-27 14:46:58
     * @version v1.0
     */
    Map getTaskInfoById(String taskId);
    /**
     * 查询指定调教报表已上报数量
     * @param sql
     * @return int
     * @author liyb
     * @date 2018-12-27 14:46:58
     * @version v1.0
     */
    Integer queryReportByConditions(@Param("sql") String sql);
    /**
     * 查询指定调教报表已上报信息
     * @param sql
     * @return List<ReportInfoVO>
     * @author liyb
     * @date 2018-12-27 14:46:58
     * @version v1.0
     */
    List<ReportInfoVO> queryReportInfoByConditions(@Param("sql") String sql);

    /**
     * 根据报表ID获取报表信息
     * @param taskId
     * @return List<TaskInfoVO>
     * @author liyb
     * @date 2018-12-27 14:46:58
     * @version v1.0
     */
    List<TaskInfoVO> queryTaskInfoByTaskId(String taskId);
    /**
     * 根据组织机构代码获取最新报表期
     * @param sql
     * @return List<Map>
     * @author liyb
     * @date 2018-12-27 14:46:58
     * @version v1.0
     */
    List<Map> queryBbqFromXxbByUnitCode(@Param("sql") String sql);
    /**
     * 查询上报信息
     * @param sql
     * @return Map
     * @author liyb
     * @date 2019-03-21 15:28:29
     * @version v1.0
     */
    Map queryCompanyWhetherReport(@Param("sql") String sql);
    /**
     * 指定机构指定报表上报信息
     * @param sql
     * @return List<RptListVO>
     * @author liyb
     * @date 2019-03-30 14:39:44
     * @version v1.0
     */
    List<RptListVO> findAllRptInfo(@Param("sql") String sql);
}
