package com.unis.ynls.irpt.server.scheduledtasks;

import cn.hutool.core.util.StrUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.alibaba.excel.exception.ExcelAnalysisException;
import com.alibaba.excel.metadata.CellExtra;
import com.alibaba.fastjson.JSON;
import com.unis.ynls.irpt.common.VO.Report.EmergencyDetailCopyVO;
import com.unis.ynls.irpt.server.service.CommonExcelReadService;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
@Slf4j
public class CommonReadListener2<T> extends AnalysisEventListener<EmergencyDetailCopyVO> {
    private static final Logger LOGGER = LoggerFactory.getLogger(CommonReadListener2.class);

    List<Map<Integer, String>> dataList = new ArrayList<>();
    private static final int BATCH_COUNT = 1000;
    List<EmergencyDetailCopyVO> list = new ArrayList<>();
    private Integer headRowNumber;
    /**
     * 合并单元格
     */
    private List<CellExtra> extraMergeInfoList = new ArrayList<>();
    /**
     * 假设这个是一个DAO，当然有业务逻辑这个也可以是一个service。当然如果不用存储这个对象没用。
     */
    private CommonExcelReadService service;


    public CommonReadListener2(CommonExcelReadService service) {
        this.service = service;
    }


    @Override
    public void invoke(EmergencyDetailCopyVO data, AnalysisContext context) {
        LOGGER.info("解析到一条数据:{}", JSON.toJSONString(data));
        list.add(data);
        // 达到BATCH_COUNT了，需要去存储一次数据库，防止数据几万条数据在内存，容易OOM
        if (list.size() >= BATCH_COUNT) {
            saveData();
            // 存储完成清理 list
            list.clear();
        }

       /* validChoiceInfo(data, context);

    }

    private void validChoiceInfo(EmergencyDetailCopyVO data, AnalysisContext context) {
        if(data.getAddress().matches("[!@#$%^&*(),.?\\\":{}|<>]")){
            throw new ExcelAnalysisException(StrUtil.format("导入文件不对",context.readRowHolder().getRowIndex()));
        }
        if(data.getBusinessname().matches("[!@#$%^&*(),.?\\\":{}|<>]")){
            throw new ExcelAnalysisException(StrUtil.format("导入文件不对",context.readRowHolder().getRowIndex()));
        }
        if(data.getContactname().matches("[!@#$%^&*(),.?\\\":{}|<>]")){
            throw new ExcelAnalysisException(StrUtil.format("导入文件不对",context.readRowHolder().getRowIndex()));
        }
        if(data.getContactphone().matches("(13[0-9]|14[01456879]|15[0-35-9]|16[2567]|17[0-8]|18[0-9]|19[0-35-9])\\d{8}")){
            throw new ExcelAnalysisException(StrUtil.format("导入文件不对",context.readRowHolder().getRowIndex()));
        }
        if(data.getLocation().matches("[!@#$%^&*(),.?\\\":{}|<>]")){
            throw new ExcelAnalysisException(StrUtil.format("导入文件不对",context.readRowHolder().getRowIndex()));
        }
        if(data.getCreditcode().matches("[!@#$%^&*(),.?\\\":{}|<>]")){
            throw new ExcelAnalysisException(StrUtil.format("导入文件不对",context.readRowHolder().getRowIndex()));
        }
        if(data.getDimension().matches("[!@#$%^&*(),.?\\\":{}|<>]")){
            throw new ExcelAnalysisException(StrUtil.format("导入文件不对",context.readRowHolder().getRowIndex()));
        }
        if(data.getLongitude().matches("[!@#$%^&*(),.?\\\":{}|<>]")){
            throw new ExcelAnalysisException(StrUtil.format("导入文件不对",context.readRowHolder().getRowIndex()));
        }*/
    }
    /**
     * 所有数据解析完成了 都会来调用
     *
     * @param context context
     */
    @Override
    public void extra(CellExtra extra, AnalysisContext context) {
        log.info("读取到了一条额外信息:{}", JSON.toJSONString(extra));
        switch (extra.getType()) {
            case MERGE: {
                if (extra.getRowIndex() >= headRowNumber) {
                    extraMergeInfoList.add(extra);
                }
                break;
            }
            default: break;
        }
    }
    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        // 这里也要保存数据，确保最后遗留的数据也存储到数据库
        list.remove(0);
        saveData();
        LOGGER.info("所有数据解析完成！");
    }

    /**
     * 加上存储数据库
     */
    private void saveData() {
        LOGGER.info("{}条数据，开始存储数据库！", list.size());
        Integer num = service.saveAllBatchData(list);
        LOGGER.info("存储数据库成功数量为：{}", num);
    }
    public List<Map<Integer, String>> getData() {
        return dataList;
    }
    public List<CellExtra> getExtraMergeInfoList() {
        return extraMergeInfoList;
    }
}
