package com.unis.ynls.irpt.server.service;

import com.unis.ynls.irpt.common.VO.system.CompanyEditVO;
import com.unis.ynls.irpt.common.VO.system.CompanyVO;
import com.unis.ynls.irpt.common.VO.system.OrgVO;
import com.unis.ynls.irpt.common.VO.system.UserVO;
import com.unis.ynls.irpt.server.entity.sys.*;

import java.util.List;

/**
 * @InterfaceName: OrgUserService
 * @author liyb
 * @version v1.0
 * @Description: IRPT机构用户
 * @date 2018-11-22 09:46:08
 */
public interface OrgUserService {
    /**
     * 保存组织机构
     * @param orgVO
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    boolean saveOrg(OrgVO orgVO);
    /**
     * 根据ID删除组织机构
     * @param orgId
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    int delOrgById(String orgId);
    /**
     * 根据ID查询组织机构
     * @param orgId
     * @return Es10OrgDO
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    Es10OrgDO findOrgById(String orgId);
    /**
     * 新增用户
     * @param userVO
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    boolean saveUser(UserVO userVO);
    /**
     * 根据ID删除用户
     * @param userId
     * @return int
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    int delUserById(String userId);
    /**
     * 根据ID查询用户
     * @param userId
     * @return Es10UserDO
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    Es10UserDO findUserById(String userId);
    /**
     * 根据用户账号查询用户机构关系
     * @param userId
     * @return Es10UserOrgDO
     * @author liyb
     * @date 2019-05-30 09:46:08
     * @version v1.0
     */
    Es10UserOrgDO findUserOrgById(String userId);
    /**
     * 企业新增（创建机构、用户）
     * @param companyVO
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    boolean addCompanyOrg(CompanyVO companyVO);
    /**
     * 企业变更登录账号、机构名称
     * @param companyEditVO
     * @return boolean
     * @author liyb
     * @date 2018-12-07 11:11:40
     * @version v1.0
     */
    boolean updateCompanyAccountInfo(CompanyEditVO companyEditVO);
    /**
     * 修改用户密码
     * @param userVO
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    boolean updateUserPWD(UserVO userVO);
    /**
     * 根据平台部门名称获取IRPT对应部门代码
     * @param departmentName
     * @return String
     */
    String getRptDeptCodeByName(String departmentName);
    /**
     * 【RabbitMQ】保存用户
     * @param userDTO
     * @author liyb
     * @date 2019-02-21 13:59:36
     * @version v1.0
     */
    void saveUserByMq(MqUserDTO userDTO);
    /**
     * 【RabbitMQ】删除用户
     * @param username
     * @author liyb
     * @date 2019-02-21 13:59:36
     * @version v1.0
     */
    void deleteUserByMq(String username);
    /**
     * 【RabbitMQ】保存机构
     * @param organizationDTO
     * @author liyb
     * @date 2019-02-21 13:59:36
     * @version v1.0
     */
    void saveOrgByMq(OrganizationDTO organizationDTO);
    /**
     * 【RabbitMQ】删除机构
     * @param organizationDTO
     * @author liyb
     * @date 2019-02-21 13:59:36
     * @version v1.0
     */
    void deleteOrgByMq(OrganizationDTO organizationDTO);
    /**
     * 获取粮食局机构
     * @return List<OrgVO>
     * @author liyb
     * @date 2019-05-05 13:40:00
     * @version v1.0
     */
    List<OrgVO> findAllManageOrg();
}
