package com.unis.ynls.irpt.server.service.impl;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.ynls.irpt.common.VO.EconomicVO;
import com.unis.ynls.irpt.common.VO.ProductionVO;
import com.unis.ynls.irpt.common.VO.QuarterVO;
import com.unis.ynls.irpt.common.VO.SafetyQueryVO;
import com.unis.ynls.irpt.server.mapper.EconomicMapper;
import com.unis.ynls.irpt.server.service.EconomicService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;


/**
 * @Author ChenKai
 * @Date 2019/9/29 16:08
 * @Version 1.0
 */

@Service
@Slf4j
public class EconomicServiceImpl  implements EconomicService {

    @Autowired
    private EconomicMapper economicMapper;

    @Override
    public PageInfo<List<EconomicVO>> findStatistics(Integer pageNum, Integer pageSize, EconomicVO vo) {
        Page<List<EconomicVO>> listPage = PageHelper.startPage(pageNum, pageSize);
        String voNd = vo.getNd();
        if (voNd!=null){
            vo.setNd(voNd+"____");
        }
        List<EconomicVO> resultList= economicMapper.findStatistics(vo);
        for (EconomicVO economicVO : resultList) {
            String nd = economicVO.getNd();
            economicVO.setNd(nd.substring(0,4));
        }
        return listPage.toPageInfo();
    }

    @Override
    public PageInfo<List<EconomicVO>> findQuarterlyReport(Integer pageNum, Integer pageSize, EconomicVO vo) {
        Page<List<EconomicVO>> listPage = PageHelper.startPage(pageNum, pageSize);
        List<EconomicVO> resultList= economicMapper.findQuarterlyReport(vo);
        for (EconomicVO economicVO : resultList) {
            String nd = economicVO.getNd();
            String s = nd.substring(0, 4);
            String s1 = nd.substring(5, 6);
            Integer s2 = Integer.parseInt(s1);
            String jd="";
            String njd="";
            if (s2==1){
                jd=s+"年第一季度";
                economicVO.setNdmc(jd);
                njd=s+"0"+s2;
                economicVO.setNd(njd);
            }else if (s2==2){
                jd=s+"年第二季度";
                economicVO.setNdmc(jd);
                njd=s+"0"+s2;
                economicVO.setNd(njd);
            } else if (s2==3){
                jd=s+"年第三季度";
                economicVO.setNdmc(jd);
                njd=s+"0"+s2;
                economicVO.setNd(njd);
            }else {
                jd=s+"年第四季度";
                economicVO.setNdmc(jd);
                njd=s+"0"+s2;
                economicVO.setNd(njd);
            }

        }
        return listPage.toPageInfo();
    }

    @Override
    public PageInfo<List<EconomicVO>> findndChart(Integer pageNum, Integer pageSize, EconomicVO vo) {
        Page<List<EconomicVO>> listPage = PageHelper.startPage(pageNum, pageSize);
        String voNd = vo.getNd();
        if (voNd!=null){
            vo.setNd(voNd+"____");
        }
        List<EconomicVO> resultList= economicMapper.findndChart(vo);
        for (EconomicVO economicVO : resultList) {
            String nd = economicVO.getNd();
            economicVO.setNd(nd.substring(0,4));
        }
        return listPage.toPageInfo();
    }

    @Override
    public PageInfo<List<EconomicVO>> findScienceBasic(Integer pageNum, Integer pageSize, EconomicVO vo) {
        Page<List<EconomicVO>> listPage = PageHelper.startPage(pageNum, pageSize);
        String voNd = vo.getNd();
        if (voNd!=null){
            vo.setNd(voNd+"____");
        }
        List<EconomicVO> resultList= economicMapper.findScienceBasic(vo);
        for (EconomicVO economicVO : resultList) {
            String nd = economicVO.getNd();
            economicVO.setNd(nd.substring(0,4));
        }
        return listPage.toPageInfo();
    }

    @Override
    public List<QuarterVO> findYearByZt(Integer zt) {
        /*1是粮食产业经济统计年报
        2是粮油加工转化企业季报
        3是粮油加工转化企业年度表
        4是粮油科技基本情况年报
        5是优质粮食工程明细（盟市）
        6是优质粮食工程汇总（自治区）*/
        if (zt == 1 || zt == 2 || zt == 3) {
            List<String> list = economicMapper.findYearByZt(zt);
            List<QuarterVO> voList = new ArrayList<>();

            String jd = "";
            for (String s : list) {
                QuarterVO vo = new QuarterVO();
                String nd = s.substring(0, 4);
                String yf = s.substring(5, 6);
                Integer s2 = Integer.parseInt(yf);
                if (s2 == 1) {
                    jd = nd + "年第一季度";
                    vo.setLabel(jd);
                    vo.setValue(s);
                } else if (s2 == 2) {
                    jd = nd + "年第二季度";
                    vo.setLabel(jd);
                    vo.setValue(s);
                } else if (s2 == 3) {
                    jd = nd + "年第三季度";
                    vo.setLabel(jd);
                    vo.setValue(s);
                } else {
                    jd = nd + "年第四季度";
                    vo.setLabel(jd);
                    vo.setValue(s);
                }
                voList.add(vo);
            }
            return voList;
        }else {
            return null;
        }


    }

    @Override
    public List<ProductionVO> findProduction(SafetyQueryVO vo) {
        return economicMapper.findProduction(vo);
    }


}
