package com.unis.ynls.irpt.server.service.impl;

import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.MD5Util;
import com.unis.common.utils.StringUtil;
import com.unis.ynls.irpt.common.VO.system.CompanyEditVO;
import com.unis.ynls.irpt.common.VO.system.CompanyVO;
import com.unis.ynls.irpt.common.VO.system.OrgVO;
import com.unis.ynls.irpt.common.VO.system.UserVO;
import com.unis.ynls.irpt.common.util.IdWorker;
import com.unis.ynls.irpt.server.common.GeneralConstant;
import com.unis.ynls.irpt.server.entity.sys.*;
import com.unis.ynls.irpt.server.mapper.OrgMapper;
import com.unis.ynls.irpt.server.mapper.UserMapper;
import com.unis.ynls.irpt.server.mapper.UserOrgMapper;
import com.unis.ynls.irpt.server.service.OrgUserService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: OrgUserServiceImpl
 * @author liyb
 * @version v1.0
 * @Description: IRPT机构用户
 * @date 2018-11-22 09:46:08
 */
@Service
@Slf4j
@SuppressWarnings("all")
public class OrgUserServiceImpl  implements OrgUserService {
    @Autowired
    private OrgMapper orgMapper;
    @Autowired
    private UserMapper userMapper;
    @Autowired
    private UserOrgMapper userOrgMapper;
    @Autowired
    private IdWorker idWorker;

    /**
     * 【RabbitMQ】保存机构
     * @param organizationDTO
     * @author liyb
     * @date 2019-02-21 13:59:36
     * @version v1.0
     */
    @Override
    public void saveOrgByMq(OrganizationDTO organizationDTO) {
        log.info(">>>>>>>>>【RabbitMQ】同步机构信息："+organizationDTO.toString()+"<<<<<<<<");
        try{
            //判断机构还是部门
            if(organizationDTO.getTypeCode().equals(GeneralConstant.ORG_TYPE_CODE)){
                //String parentArea = getParentAreaCode();
                if (!organizationDTO.getAreaCode().equals(organizationDTO.getParentAreaCode())){
                    OrgVO orgVO = new OrgVO();
                    orgVO.setOrgName(organizationDTO.getName());
                    //质检单位
                    if(organizationDTO.getOrgType().equals(GeneralConstant.ORG_UNIT_TYPE_QUALITY)){
                        if(organizationDTO.getAreaCode().equals(GeneralConstant.PROVINCE_AREA_CODE)){
                            orgVO.setOrgId(GeneralConstant.PROVINCE_AREA_CODE+"90");
                            orgVO.setParent(GeneralConstant.PROVINCE_AREA_CODE);
                        }else{
                            orgVO.setOrgId(organizationDTO.getAreaCode()+"90");
                            orgVO.setParent(organizationDTO.getParentAreaCode()+"90");
                        }
                    }else{
                        orgVO.setOrgId(organizationDTO.getAreaCode());
                        //String parentAreaCode = getParentAreaCode(organizationDTO.getParentAreaCode());
                        orgVO.setParent(organizationDTO.getParentAreaCode());
                    }
                    log.info(">>>>>>>>>【RabbitMQ】同步机构--开始："+orgVO.toString()+"<<<<<<<<");
                    boolean result=saveOrg(orgVO);
                    log.info(">>>>>>>>>【RabbitMQ】同步机构--结束："+result+"<<<<<<<<");
                }
            }else{
                log.info(">>>>>>>>>【RabbitMQ】同步机构--结果：部门无需插入<<<<<<<<");
            }
        } catch (Exception e) {
            log.info(">>>>>>>>>【RabbitMQ】同步机构<<<<<<<<:"+e.getMessage());
            e.printStackTrace();
        }
    }
    /**
     * 【RabbitMQ】禁用机构
     * @param organizationDTO
     * @author liyb
     * @date 2019-02-21 13:59:36
     * @version v1.0
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteOrgByMq(OrganizationDTO organizationDTO) {
        try{
            //判断是机构还是部门
            if(organizationDTO.getTypeCode().equals(GeneralConstant.ORG_TYPE_CODE)){
                Es10OrgDO orgDO=new Es10OrgDO();
                orgDO.setCaption_(organizationDTO.getName());
                //质检单位
                if(organizationDTO.getOrgType().equals(GeneralConstant.ORG_UNIT_TYPE_QUALITY)){
                    if(organizationDTO.getAreaCode().equals(GeneralConstant.PROVINCE_AREA_CODE)){
                        orgDO.setOrgid_(GeneralConstant.PROVINCE_AREA_CODE+"90");
                        orgDO.setParent_(GeneralConstant.PROVINCE_AREA_CODE);
                    }else{
                        orgDO.setOrgid_(organizationDTO.getAreaCode()+"90");
                        orgDO.setParent_(organizationDTO.getParentAreaCode()+"90");
                    }
                }else{
                    orgDO.setOrgid_(organizationDTO.getAreaCode());
                    //String parentAreaCode = getParentAreaCode(organizationDTO.getParentAreaCode());
                    orgDO.setParent_(organizationDTO.getParentAreaCode());
                }
                orgDO.setEnabled_("0");
                int result=orgMapper.updateByPrimaryKey(orgDO);
                log.info(">>>>>>>>>RabbitMQ禁用机构结果：<<<<<<<<"+result);
            }else{
                log.info(">>>>>>>>>RabbitMQ禁用机构结果：部门无需禁用<<<<<<<<");
            }
        } catch (Exception e) {
            log.info(">>>>>>>>>RabbitMQ禁用机构<<<<<<<<:"+e.getMessage());
            e.printStackTrace();
        }
    }
    /**
     * 获取粮食局机构
     * @return List<OrgVO>
     * @author liyb
     * @date 2019-05-05 13:40:00
     * @version v1.0
     */
    @Override
    public List<OrgVO> findAllManageOrg() {
        return orgMapper.findAllManageOrg();
    }

    /**
     * 保存组织机构
     * @param orgVO
     * @return boolean
     * @author liyb
     * @date 2019-03-04 10:33:12
     * @version v1.0
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean saveOrg(OrgVO orgVO) {
        //查询操作机构是否存在
        Es10OrgDO orgDO1 = findOrgById(orgVO.getOrgId());
        //新增
        if (ObjectUtils.equals(orgDO1, null)) {
            //判断机构是否为根节点，父节点为空即为根节点
            if(StringUtils.isNotEmpty(orgVO.getParent())){
                //查询操作机构父节点是否存在
                Es10OrgDO orgDO2 = findOrgById(orgVO.getParent());
                if (ObjectUtils.notEqual(orgDO2, null)) {
                    log.info(">>>>>>>>>【新增】保存机构，机构信息为<<<<<<<<"+appendOrgDO(orgVO,orgDO2).toString());
                    int result=orgMapper.insert(appendOrgDO(orgVO,orgDO2));
                    if(result==GeneralConstant.UPDATE_RESULT){
                        Map<String,String> param = new HashMap<String, String>();
                        param.put("parent",orgVO.getParent());
                        String upId= orgMapper.queryOrgUpId(param);
                        Map<String,String> params = new HashMap<String, String>();
                        params.put("parent","'"+orgVO.getParent()+"'");
                        params.put("orgId","'"+orgVO.getOrgId()+"'");
                        params.put("upId",upId);
                        log.info(">>>>>>>>>保存机构，机构信息为<<<<<<<<"+params);
                        orgMapper.updateOrg(params);
                        return  true;
                    }
                }else{
                    log.info(">>>>>>>>>保存组织机构失败，机构父节点不存在<<<<<<<<父节点机构代码为："+orgVO.getParent());
                    return false;
                }
            }else{
                /*int result=orgMapper.insert(appendOrgDO(orgVO,null));
                if(result==GeneralConstant.UPDATE_RESULT){
                    return  true;
                }*/
                log.info(">>>>>>>>>父节点为空，根节点不作处理<<<<<<<<父节点机构代码为");
                return  true;
            }
        }else{
            //判断机构是否为根节点
            if(StringUtils.isNotEmpty(orgVO.getParent())){
                //查询操作机构父节点是否存在
                Es10OrgDO orgDO2 = findOrgById(orgVO.getParent());
                if (ObjectUtils.notEqual(orgDO2, null)) {
                    log.info(">>>>>>>>>【更新】保存机构，机构信息为<<<<<<<<"+appendOrgDO(orgVO,orgDO2).toString());
                    int result=orgMapper.updateByPrimaryKey(appendOrgDO(orgVO,orgDO1));
                    if(result==GeneralConstant.UPDATE_RESULT){
                        Map<String,String> param = new HashMap<String, String>();
                        param.put("parent",orgVO.getParent());
                        String upId= orgMapper.queryOrgUpId(param);
                        Map<String,String> params = new HashMap<String, String>();
                        params.put("parent","'"+orgVO.getParent()+"'");
                        params.put("orgId","'"+orgVO.getOrgId()+"'");
                        params.put("upId",upId);
                        log.info(">>>>>>>>>保存机构，机构信息为<<<<<<<<"+params);
                        orgMapper.updateOrg(params);
                        return  true;
                    }
                }else{
                    log.info(">>>>>>>>>保存组织机构失败，机构父节点不存在<<<<<<<<父节点机构代码为："+orgVO.getParent());
                    return false;
                }
            }else{
               /* int result=orgMapper.updateByPrimaryKey(appendOrgDO(orgVO,null));
                if(result==GeneralConstant.UPDATE_RESULT){
                    return  true;
                }*/
                log.info(">>>>>>>>>父节点为空，根节点不作处理<<<<<<<<");
                return  true;
            }
        }
        return false;
    }
    /**
     * 根据组织机构代码删除组织机构
     * @param orgId
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int delOrgById(String orgId){
        Example example = new Example(Es10OrgDO.class);
        example.createCriteria().andEqualTo("orgid_",orgId);
        return orgMapper.deleteByExample(example);
    }
    /**
     * 根据平台部门名称获取IRPT对应部门代码
     * @param deptName
     * @return String
     */
    @Override
    public String getRptDeptCodeByName(String deptName){
        if(StringUtils.isNotEmpty(deptName)){
            String deptCode = orgMapper.getRptDeptCodeByName(deptName);
            if(StringUtils.isNotEmpty(deptCode)){
                return deptCode;
            }else{
                return "";
            }
        } else{
            return "";
        }
    }

    /**
     * 【RabbitMQ】保存用户
     * @param userDTO
     * @author liyb
     * @date 2019-02-21 13:59:36
     * @version v1.0
     */
    @Override
    public void saveUserByMq(MqUserDTO userDTO) {
        log.info(">>>>>>>>>【RabbitMQ】同步用户信息："+userDTO.toString()+"<<<<<<<<");
        String orgType = userDTO.getOrgType();
        try{
            if(orgType.equals(GeneralConstant.ORG_UNIT_TYPE_GRAIN)
                || orgType.equals(GeneralConstant.ORG_UNIT_TYPE_CITY)
                || orgType.equals(GeneralConstant.ORG_UNIT_TYPE_AREA)
                || orgType.equals(GeneralConstant.ORG_UNIT_TYPE_COMPANY)
                || orgType.equals(GeneralConstant.ORG_UNIT_TYPE_BAR)
                    || orgType.equals(GeneralConstant.ORG_UNIT_TYPE_QUALITY)){
                UserVO userVO = new UserVO();
                userVO.setUserName(userDTO.getName());
                userVO.setAccount(userDTO.getUsername());
                userVO.setMdPassWord(userDTO.getPassword());
                if(orgType.equals(GeneralConstant.ORG_UNIT_TYPE_QUALITY)){
                    if(userDTO.getAreaCode().equals(GeneralConstant.PROVINCE_AREA_CODE)){
                        userVO.setOrgId(GeneralConstant.PROVINCE_AREA_CODE+"90");
                    }else{
                        userVO.setOrgId(userDTO.getAreaCode()+"90");
                    }
                }else{
                    userVO.setOrgId(userDTO.getAreaCode());
                }
                userVO.setDepartment(getRptDeptCodeByName(userDTO.getDepartmentName()));
                Es10OrgDO orgDO = findOrgById(userDTO.getAreaCode());
                if (ObjectUtils.equals(orgDO, null)) {
                    log.info(">>>【RabbitMQ】保存用户--所属机构不存在[{}]",userDTO.getAreaCode());
                }else{
                    log.info(">>>【RabbitMQ】保存用户--开始："+userVO.toString());
                    boolean result=saveUser(userVO);
                    log.info(">>>【RabbitMQ】保存用户--结束："+result);
                }
            }else{
                log.info(">>>【RabbitMQ】无法识别的用户类型,终止 ---", orgType);
            }
        } catch (Exception e) {
            log.info(">>>【RabbitMQ】保存用户失败:"+e.getMessage());
            e.printStackTrace();
        }
    }
    /**
     * 【RabbitMQ】删除用户
     * @param username
     * @author liyb
     * @date 2019-02-21 13:59:36
     * @version v1.0
     */
    @Override
    public void deleteUserByMq(String username) {
        log.info(">>>>>>>>>【RabbitMQ】同步删除用户："+username+"<<<<<<<<:" );
        try{
            Es10UserDO user = findUserById(username);
            if(ObjectUtils.notEqual(user,null)) {
                int result = delUserById(username);
                log.info(">>>>>>>>>【RabbitMQ】同步删除用户--结果："+result+"<<<<<<<<:" );
            }else{
                log.info(">>>>>>>>>【RabbitMQ】同步删除用户--结果：用户不存在，无需删除！！！<<<<<<<<" );
            }
        } catch (Exception e) {
            log.info(">>>>>>>>>【RabbitMQ】同步删除用户<<<<<<<<:"+e.getMessage());
            e.printStackTrace();
        }
    }
    /**
     * 根据用户账号删除用户
     * @param userid
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int delUserById(String userid){
        Example example = new Example(Es10UserDO.class);
        example.createCriteria().andEqualTo("userid_",userid);
        int result = userMapper.deleteByExample(example);
        if (result==GeneralConstant.UPDATE_RESULT){
            delUserorgById(userid);
            return  1;
        }
        return 2;
    }
    /**
     * 根据用户账号删除用户机构关联表
     * @param userid
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    @Transactional(rollbackFor = Exception.class)
    public void delUserorgById(String userid){
        Example example = new Example(Es10UserDO.class);
        example.createCriteria().andEqualTo("userid_",userid);
        userOrgMapper.deleteByExample(example);
    }

    /**
     * 企业新增（创建机构、用户）
     * @param companyVO
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean addCompanyOrg(CompanyVO companyVO) {
        log.info(">>>>>>>>>【企业新增】企业信息："+companyVO.toString()+"<<<<<<<<<<<<<<");
        boolean orgResult =saveOrg(getOrgVOByCompanyVO(companyVO));
        if(orgResult==true){
            UserVO userVO= getUserVOByCompanyVO(companyVO);
            boolean userResult=saveUser(userVO);
            return userResult;
        }
        log.info(">>>>>>>>>【企业新增】保存失败，父节点机构代码为："+companyVO.getParent()+"企业机构代码为："+companyVO.getOrgId());
        return false;
    }
    /**
     * 企业变更
     * @param companyEditVO
     * @return boolean
     * @author liyb
     * @date 2018-12-07 11:11:40
     * @version v1.0
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean updateCompanyAccountInfo(CompanyEditVO companyEditVO) {
        log.info(">>>>>>>>>【企业变更】企业信息为<<<<<<<<"+companyEditVO.toString());
        OrgVO orgVO = new OrgVO();
        orgVO.setOrgId(companyEditVO.getOrgId());
        orgVO.setOrgName(companyEditVO.getOrgName());
        orgVO.setParent(companyEditVO.getParentId());
        orgVO.setIfBaseOrg(companyEditVO.getIfSuperiorGroup());
        orgVO.setXzqhSzd(companyEditVO.getXzqhSzd());
        log.info(">>>>>>>>>【企业变更】变更企业机构--开始："+orgVO.toString()+"<<<<<<<<");
        boolean orgResult =saveOrg(orgVO);
        log.info(">>>>>>>>>【企业变更】变更企业机构--结束："+orgResult+"<<<<<<<<");
        //说明企业上级为上级集团
        if(StringUtils.isNotEmpty(companyEditVO.getIfSuperiorGroup())){
            if(StringUtils.isNotEmpty(companyEditVO.getParentId())){
                orgMapper.updateOrgTypeInfo(companyEditVO.getParentId());
            }
        }
        if(orgResult==true){
            Es10UserDO userDO = findUserById(companyEditVO.getOldAccount());
            if (ObjectUtils.notEqual(userDO, null)) {
                //是否修改用户账号
                if(StringUtils.isNotEmpty(companyEditVO.getNewAccount())){
                    orgMapper.updateCompanyAccount(companyEditVO);
                    orgMapper.updateCompanyUserOrg(companyEditVO);
                }else{
                    orgMapper.updateCompanyAccount(companyEditVO);
                }
                return true;
            }else{
                log.info("》》》》》》》》》》旧账号不存在：" + companyEditVO.getOldAccount());
                return false;
            }
        }
        log.info(">>>>>>>>>【企业变更】变更企业机构用户失败<<<<<<<<父节点机构代码为："+companyEditVO.getParentId()+"企业机构代码为："+companyEditVO.getOrgId());
        return false;
    }
    /**
     * 保存用户
     * @param userVO
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED,rollbackFor = Exception.class)
    public boolean saveUser(UserVO userVO) {
        Es10OrgDO orgDO = findOrgById(userVO.getOrgId());
        if(ObjectUtils.notEqual(orgDO,null)){
            Es10UserDO user = findUserById(userVO.getAccount());
            Es10UserDO userDO = appendUserDO(userVO);
            log.info(">>>>>>>>>【保存用户】用户信息："+userDO.toString()+"<<<<<<<<<<<<<<<<");
            //校验账号是否存在
            if(ObjectUtils.equals(user, null)){
                int insertResult = userMapper.insert(userDO);
                if(insertResult==GeneralConstant.UPDATE_RESULT){
                    Es10UserOrgDO userorgDO = getUserOrgVOByUserVO(userVO);
                    userorgDO.setIndex_(idWorker.nextId());
                    log.info(">>>>>>>>>【新增用户】保存用户、用户与机构关联表信息为："+userorgDO.toString()+"<<<<<<<<");
                    int results= userOrgMapper.insertSelective(userorgDO);
                    if (results==GeneralConstant.UPDATE_RESULT){
                        return true;
                    }
                }
            }else{
                int updateResult = userMapper.updateByPrimaryKey(userDO);
                if(updateResult==GeneralConstant.UPDATE_RESULT){
                    Es10UserOrgDO userorgDO = getUserOrgVOByUserVO(userVO);
                    //更新 index_报错      A SERIAL column (index_) may not be updated.
                    //遇到未知情况数据库有数据,查询出来的也显示是1条记录,返回的对象为null
                    /*Es10UserOrgDO es10UserOrgDO = userOrgMapper.selectByUserid(userDO.getUserid_());
                    System.out.println("es10UserOrgDO:"+JsonUtils.serialize(es10UserOrgDO)+"   "+(es10UserOrgDO!=null));
                    if(es10UserOrgDO!=null){
                        userorgDO.setIndex_(es10UserOrgDO.getIndex_());
                        log.info(">>>>>>>>>【修改用户组织关联】更新用户、用户与机构关联表信息为："+userorgDO.toString()+"<<<<<<<<");
                        userOrgMapper.updateByPrimaryKeySelective(userorgDO);
                    }else{
                        userorgDO.setIndex_(idWorker.nextId());
                        log.info(">>>>>>>>>【新增用户组织关联】新增用户、用户与机构关联表信息为："+userorgDO.toString()+"<<<<<<<<");
                        userOrgMapper.insertSelective(userorgDO);
                    }*/
                    Es10UserOrgDO es10UserOrgDO=new Es10UserOrgDO();
                    es10UserOrgDO.setUserid_(userDO.getUserid_());
                    userOrgMapper.deleteByEntity(es10UserOrgDO);

                    es10UserOrgDO.setOrgid_(userVO.getOrgId());
                    es10UserOrgDO.setIndex_(idWorker.nextId());
                    es10UserOrgDO.setIsprime_("1");
                    userOrgMapper.insertSelective(es10UserOrgDO);
                    return true;
                }
            }
        }
        log.info(">>>>>>>>>【保存用户】保存失败，组织机构不存在<<<<<<<<组织机构代码为："+userVO.getOrgId());
        return  false;
    }
    /**
     * 修改用户密码
     * @param userid
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean updateUserPWD(UserVO userVO) {
        System.out.print(">>>>>>>修改用户密码:" + userVO.toString() + "<<<<<<<<<<<<<<");
        if(StringUtils.isNotEmpty(userVO.getAccount())&& StringUtils.isNotEmpty(userVO.getMdPassWord())){
            Es10UserDO userDO=findUserById(userVO.getAccount());
            if (ObjectUtils.notEqual(userDO,null)){
                orgMapper.updateUserPWD(userVO);
                return  true;
            }else {
                log.info("》》》》》》》》》》账号不存在："+userVO.getAccount());
                return  false;
            }
        }
        return false;
    }


    /**
     * 根据机构ID查询组织机构
     * @param orgId
     * @return Es10OrgDO
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    @Override
    public Es10OrgDO findOrgById(String orgId){
        Example example = new Example(Es10OrgDO.class);
        example.createCriteria().andEqualTo("orgid_", orgId);
        Es10OrgDO orgDO=orgMapper.selectOneByExample(example);
        if(ObjectUtils.equals(orgDO,null)){
            return null;
        }else{
            return orgDO;
        }
    }
    /**
     * 根据用户账号查询用户
     * @param userId
     * @return boolean
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    @Override
    public Es10UserDO findUserById(String userId){
        Example example = new Example(Es10UserDO.class);
        example.createCriteria().andEqualTo("userid_", userId);
        return userMapper.selectOneByExample(example);
    }
    /**
     * 根据用户账号查询用户机构关系
     * @param userId
     * @return Es10UserOrgDO
     * @author liyb
     * @date 2019-05-30 09:46:08
     * @version v1.0
     */
    @Override
    public Es10UserOrgDO findUserOrgById(String userId) {
        Example example = new Example(Es10UserOrgDO.class);
        example.createCriteria().andEqualTo("userid_", userId);
        return userOrgMapper.selectOneByExample(example);
    }

    /**
     * 根据企业信息拼接机构信息
     * @param companyVO
     * @return OrgVO
     */
    public OrgVO getOrgVOByCompanyVO(CompanyVO companyVO){
        OrgVO orgVO = new OrgVO();
        orgVO.setOrgId(companyVO.getOrgId());
        orgVO.setOrgName(companyVO.getOrgName());
        orgVO.setParent(companyVO.getParent());
        orgVO.setTel(companyVO.getTel());
        orgVO.setXzqhSzd(companyVO.getXzqhSzd());
        orgVO.setGovernor(companyVO.getGovernor());
        if(StringUtils.isNotEmpty(companyVO.getIfGroup())){
            if(companyVO.getIfGroup().equals("yes")){
            }else{
                orgVO.setIfBaseOrg("company");
            }
        }else{
            orgVO.setIfBaseOrg("company");
        }


        return orgVO;
    }
    /**
     * 根据企业信息拼接用户信息
     * @param companyVO
     * @return UserVO
     */
    public UserVO getUserVOByCompanyVO(CompanyVO companyVO){
        UserVO userVO = new UserVO();
        userVO.setAccount(companyVO.getAccount());
        userVO.setUserName(companyVO.getUserName());
        userVO.setOrgId(companyVO.getOrgId());
        userVO.setMdPassWord(companyVO.getMdPassWord());
        userVO.setDepartment(companyVO.getDepartment());
        return userVO;
    }
    /**
     * 拼接组织机构
     * @param orgVO,orgDO2
     * @return Es10OrgDO
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    public Es10OrgDO appendOrgDO (OrgVO orgVO,Es10OrgDO orgDO2){
        Es10OrgDO orgDO = new Es10OrgDO();
        orgDO.setOrgid_(orgVO.getOrgId());
        orgDO.setCaption_(orgVO.getOrgName());
        orgDO.setEnabled_("1");
        orgDO.setGovernor_(StringUtil.checkParam(orgVO.getGovernor()));
        orgDO.setTel_(StringUtil.checkParam(orgVO.getTel()));
        orgDO.setDescription_(null);
        orgDO.setCreatedate_(DateUtil.getNowDate());
        orgDO.setLocked_("0");
        orgDO.setBtype_("1");
        orgDO.setXzqhSzd(StringUtil.checkParam(orgVO.getXzqhSzd()));
        //普通企业（不包含上级集团）
        if(StringUtils.isNotEmpty(orgVO.getIfBaseOrg())){
            orgDO.setIsjc_("1");
        }else{
            orgDO.setIsjc_("0");
        }
        if(ObjectUtils.equals(orgDO2,null)){
            orgDO.setParent_("--");
            orgDO.setUpid0_("-");
            orgDO.setUpid1_("-");
            orgDO.setUpid2_("-");
            orgDO.setUpid3_("-");
            orgDO.setUpid4_("-");
            orgDO.setUpid5_("-");
            orgDO.setUpid6_("-");
            orgDO.setUpid7_("-");
            orgDO.setUpid8_("-");
            orgDO.setUpid9_("-");
            orgDO.setIsjc_("0");
        }else{
            orgDO.setParent_(orgVO.getParent());
            orgDO.setUpid0_(orgDO2.getUpid0_());
            orgDO.setUpid1_(orgDO2.getUpid1_());
            orgDO.setUpid2_(orgDO2.getUpid2_());
            orgDO.setUpid3_(orgDO2.getUpid3_());
            orgDO.setUpid4_(orgDO2.getUpid4_());
            orgDO.setUpid5_(orgDO2.getUpid5_());
            orgDO.setUpid6_(orgDO2.getUpid6_());
            orgDO.setUpid7_(orgDO2.getUpid7_());
            orgDO.setUpid8_(orgDO2.getUpid8_());
            orgDO.setUpid9_(orgDO2.getUpid9_());
        }
        return orgDO;
    }
    /**
     * 拼接UserDO
     * @param userVO
     * @return Es10UserDO
     * @author liyb
     * @date 2018-11-22 09:46:08
     * @version v1.0
     */
    public Es10UserDO appendUserDO(UserVO userVO){
        String pwd =userVO.getMdPassWord();
        Es10UserDO userDO = new Es10UserDO();
        userDO.setUserid_(userVO.getAccount());
        userDO.setCaption_(userVO.getUserName());
        if(pwd.length()!=GeneralConstant.MD5_LENGTH){
            //对密码进行 md5 加密
            String md5Password = MD5Util.md5ToHex(pwd);
            userDO.setPassword_("{"+md5Password+"}");
        }else{
            userDO.setPassword_("{"+pwd+"}");
        }
        userDO.setDepartment(userVO.getDepartment());
        userDO.setEnabled_("1");
        userDO.setEmail_("");
        userDO.setTel_("");
        return userDO;
    }
    /**
     * 根据用户信息拼接用户机构关联信息
     * @param Es10UserorgDO
     * @return UserVO
     */
    public Es10UserOrgDO getUserOrgVOByUserVO(UserVO userVO){
        Es10UserOrgDO userorgDO = new Es10UserOrgDO();
        userorgDO.setIsprime_("1");
        userorgDO.setOrgid_(userVO.getOrgId());
        userorgDO.setUserid_(userVO.getAccount());
        return userorgDO;
    }



    public String getParentAreaCode(String parentid){
        String parentAreaCode=null;
        int length = parentid.length();
        if (length==6){
            String substring = parentid.substring(4);
            if (substring.equals("00")){
                if (parentid.substring(2).equals("0000")){
                    return parentid;
                }
                String s = parentid.substring(0, 2);
                return parentAreaCode=s+"0000";
            }else if (!substring.equals("00")){
                String substring1 = parentid.substring(0, 4);
                return parentAreaCode=substring1+"00";
            }
        }
        return parentid;
    }
}
