package com.unis.ynls.irpt.server.service.impl;

import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.DateUtil;
import com.unis.ynls.irpt.common.VO.BaseFilterVO;
import com.unis.ynls.irpt.common.VO.task.CompanyRptFilterVO;
import com.unis.ynls.irpt.common.VO.task.ReportInfoVO;
import com.unis.ynls.irpt.common.VO.task.RptListFilterVO;
import com.unis.ynls.irpt.common.VO.task.RptListVO;
import com.unis.ynls.irpt.common.VO.task.TaskFilterVO;
import com.unis.ynls.irpt.common.VO.task.TaskInfoVO;
import com.unis.ynls.irpt.server.common.GeneralConstant;
import com.unis.ynls.irpt.server.mapper.TaskInfoMapper;
import com.unis.ynls.irpt.server.service.TaskInfoService;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: TaskInfoServiceImpl
 * @Description: IRPT报表管理
 * @author liyb
 * @version v1.0
 * @date 2018-12-27 14:37:36
 */
@Service
@Slf4j
@SuppressWarnings("all")
public class TaskInfoServiceImpl implements TaskInfoService {
	@Autowired
	private TaskInfoMapper taskInfoMapper;

	/**
	 * 查询指定报表已上报数量
	 * 
	 * @param taskFilterVO
	 * @return int
	 * @author liyb
	 * @date 2018-12-27 14:46:58
	 * @version v1.0
	 */
	@Override
	public Integer queryReportByConditions(TaskFilterVO taskFilterVO) {
		Map taskInfo = getTaskInfoById(taskFilterVO.getTaskId());
		String XXB_TABLENAME = String.valueOf(taskInfo.get("XXB_TABLENAME"));
		String sql = "select count(*) from " + XXB_TABLENAME + " X WHERE 1=1 AND X.TAG_='0' ";
		return taskInfoMapper.queryReportByConditions(appendCondition(taskFilterVO, sql));
	}

	/**
	 * 查询指定报表已上报信息
	 * 
	 * @param taskFilterVO
	 * @return PageInfo
	 * @author liyb
	 * @date 2018-12-27 14:46:58
	 * @version v1.0
	 */
	@Override
	public List<ReportInfoVO> queryReportInfoByConditions(TaskFilterVO taskFilterVO) {
		Map taskInfo = getTaskInfoById(taskFilterVO.getTaskId());
		String XXB_TABLENAME = String.valueOf(taskInfo.get("XXB_TABLENAME"));
		String sql = "select X.BBQ_,X.userid_,X.username_,O.ORGID_,O.CAPTION_ from " + XXB_TABLENAME + " X "
				+ " LEFT JOIN ES10_ORG O ON O.ORGID_=X.UPID_" + " WHERE 1=1 AND X.TAG_='0' ";
		List<ReportInfoVO> list = taskInfoMapper.queryReportInfoByConditions(appendCondition(taskFilterVO, sql));
		return list;
	}

	/**
	 * 获取指定报表新增报表期
	 * 
	 * @param taskId   I报表真实代码
	 * @param unitCode 机构代码
	 * @return String
	 * @author liyb
	 * @date 2019-01-25 15:42:28
	 * @version v1.0
	 */
	@Override
	public String queryReportBbqByTaskId(String taskId, String unitCode) {
		String result = "";
		// 根据报表ID获取报表信息
		List<TaskInfoVO> taskInfo = taskInfoMapper.queryTaskInfoByTaskId(taskId);
		if (taskInfo.size() > 0) {
			String taskBbqType = taskInfo.get(0).getTaskBbqType();
			String xxbTableName = taskInfo.get(0).getXxbTableName();
			if ("8".equals(taskBbqType)) {// 自由报
				// 根据组织机构代码获取最新报表期
				String sql = "SELECT T.BBQ_ FROM (SELECT X.bbq_ FROM " + xxbTableName + " X WHERE X.USERID_='"
						+ unitCode + "' ORDER BY X.BBQ_ DESC) T WHERE ROWNUM=1";
				List<Map> map = taskInfoMapper.queryBbqFromXxbByUnitCode(sql);
				result = "00000001";
				if (map.size() > 0) {
					String num = String.valueOf(Integer.parseInt(String.valueOf(map.get(0).get("BBQ_"))) + 1);
					if (num.length() < 9) {
						while (num.length() < 8) {
							StringBuffer sb = new StringBuffer();
							sb.append("0").append(num);// 左补0
							num = sb.toString();
						}
						result = num;
					}
				}
			} else if ("0".equals(taskBbqType)) {// 年报
				Integer year = DateUtil.getYearString();
				result = String.valueOf(year) + "----";
			}
			/*
			 * //201809029 增加报表期为月报 获取最新报表期方法 else if ("1".equals(taskBbqType)) {// 月报
			 * result = ParameterUtil.getMonth(new Date(), 0).substring(0, 6) + "--"; if
			 * (xxbList.size() > 0) { String num = xxbList.get(0).getBbq() == null ?
			 * ParameterUtil.getNowDate().substring(0, 6) :
			 * ParameterUtil.getMonth(ParameterUtil.string2date2(xxbList.get(0).getBbq().
			 * substring(0, 6) + "01"), 1); if (num.length() < 9) { // int len = 9 -
			 * num.length(); while (num.length() < 8) { StringBuffer sb = new
			 * StringBuffer(); // sb.append("0").append(num);// 左补0
			 * sb.append(num).append("-");// 右补0 num = sb.toString(); } result = num; } } }
			 * else if ("2".equals(taskBbqType)) { result = ParameterUtil.getYear(new
			 * Date()) + "0" + ParameterUtil.getSeason(new Date()) + "--"; if
			 * (xxbList.size() > 0) { String num = xxbList.get(0).getBbq() == null ? result
			 * : ParameterUtil.getNextBbq(xxbList.get(0).getBbq()); if (num.length() < 9) {
			 * // int len = 9 - num.length(); while (num.length() < 8) { StringBuffer sb =
			 * new StringBuffer(); // sb.append("0").append(num);// 左补0
			 * sb.append(num).append("-");// 右补0 num = sb.toString(); } result = num; } } }
			 */
		}
		return result;
	}

	/**
	 * 查询指定条件下企业是否上报
	 * 
	 * @param companyRptFilterVO 参数：报表真实ID，报表期，企业统一社会信用代码
	 * @return Integer
	 * @author liyb
	 * @date 2019-02-18 17:24:28
	 * @version v1.0
	 */
	@Override
	public Integer queryCompanyWhetherReport(CompanyRptFilterVO companyRptFilterVO) {
		Map taskInfo = getTaskInfoById(companyRptFilterVO.getRptId());
		String xxbTablename = String.valueOf(taskInfo.get("XXB_TABLENAME"));
		String bbq = companyRptFilterVO.getBbq();
		String unitCode = companyRptFilterVO.getUnitCode();
		String sql = "select X.APPROVE_INSTANCE,X.TAG_ from " + xxbTablename + " X WHERE 1=1 AND X.BBQ_='" + bbq
				+ "' AND X.USERID_='" + unitCode + "' AND X.BTYPE_='0' ";
		Map map = taskInfoMapper.queryCompanyWhetherReport(sql);
		if (ObjectUtils.notEqual(map, null)) {
			String procInstId = String.valueOf(map.get("APPROVE_INSTANCE"));
			String isSubmit = String.valueOf(map.get("TAG_"));
			if ("0".equals(isSubmit)) {
				return GeneralConstant.UPDATE_RESULT;
			} else {
				if (StringUtils.isNotEmpty(procInstId)) {
					return GeneralConstant.UPDATE_RESULT;
				} else {
					return GeneralConstant.NO_RESULT;
				}
			}
		} else {
			return GeneralConstant.NO_RESULT;
		}
	}

	/**
	 * 指定机构指定报表上报信息
	 * 
	 * @param rptListFilterVO
	 * @return List<RptListVO>
	 * @author liyb
	 * @date 2019-03-30 14:39:44
	 * @version v1.0
	 */
	@Override
	public List<RptListVO> findAllRptInfo(RptListFilterVO rptListFilterVO) throws Exception {
		Map taskInfo = getTaskInfoById(rptListFilterVO.getRptId());
		if (ObjectUtils.equals(taskInfo, null)) {
			log.info(">>>>>>>>>>>>>>>>【指定机构指定报表上报信息】报表信息查询不到：" + rptListFilterVO.toString() + "<<<<<<<<<<<<<<<<<<");
			throw new Exception("报表信息查询不到！！");
			
		}
		Object object = taskInfo.get("xxb_tablename");
		String xxbTableName = String.valueOf(taskInfo.get("xxb_tablename"));
		String unitCode = rptListFilterVO.getUnitCode();
		String sql = " SELECT T.BBQ_,'" + rptListFilterVO.getRptId()
				+ "' AS RPT_ID,T.USERID_,T.USERNAME_,T.TAG_,T.SUBMIT_TIME,T.PROC_INST_ID,T.ID_,T.ACT_NAME_,T.TASK_ID,T.ACT_ID,T.END_TIME_ FROM ("
				+ " SELECT "
				+ " Z.BTYPE_,Z.BBQ_,Z.USERID_,Z.USERNAME_,Z.TAG_, DATE_FORMAT(Z.SUBMIT_TIME, '%Y-%m-%d %H:%i:%s') AS SUBMIT_TIME ,Z.PROC_INST_ID ,"
				+ " Z.ID_,Z.END_TIME_,Z.ACT_NAME_," + " Z.TASK_ID,Z.ACT_ID,RN "
				+ " FROM ( SELECT H.BTYPE_, H.BBQ_,H.USERID_,H.USERNAME_,H.TAG_,H.SUBMIT_TIME,H.PROC_INST_ID,H.ID_,H.END_TIME_,H.ACT_NAME_, H.TASK_ID,H.ACT_ID,if(@BBQ_=H.BBQ_,@rank:=@rank+1,@rank:=1) as RN ,@BBQ_:=H.BBQ_ FROM(SELECT "
				+ "X.BTYPE_,X.BBQ_,X.USERID_,X.USERNAME_,X.TAG_,X.SUBMITDATE_ AS SUBMIT_TIME,X.APPROVE_INSTANCE AS PROC_INST_ID,A.ID_,A.END_TIME_,A.ACT_NAME_, W.TASK_ID,W.ACT_ID FROM "
				+ xxbTableName
				+ "  X LEFT JOIN ACT_HI_ACTINST A ON A.PROC_INST_ID_=X.APPROVE_INSTANCE AND A.ACT_type_='userTask' LEFT JOIN WAIT_TASKLIST W ON W.PROC_INST_ID=X.APPROVE_INSTANCE AND (W.ASSIGNEE='"
				+ rptListFilterVO.getUserAccount() + "'  OR W.CANDIDATE='" + rptListFilterVO.getUserAccount()
				+ "')  WHERE X.USERID_='" + rptListFilterVO.getUnitCode()
				+ "' AND X.BTYPE_='0' ORDER BY X.BBQ_ ,A.START_TIME_ DESC) H,(select  @BBQ_:= null ,@rank:=0) R) Z" +
				/*
				 * " LEFT JOIN ACT_HI_ACTINST A ON A.PROC_INST_ID_=X.APPROVE_INSTANCE AND A.ACT_type_='userTask'"
				 * +
				 * " LEFT JOIN WAIT_TASKLIST W ON W.PROC_INST_ID=X.APPROVE_INSTANCE AND (W.ASSIGNEE='"
				 * +rptListFilterVO.getUserAccount()+"' OR W.CANDIDATE='"+rptListFilterVO.
				 * getUserAccount()+"')" +
				 */
				") T WHERE T.RN=1" + " ORDER BY T.BBQ_ DESC";

		System.out.println("-----" + sql);
		List<RptListVO> list = taskInfoMapper.findAllRptInfo(sql);
		if (list.size() > GeneralConstant.NO_RESULT) {
			for (RptListVO rptVO : list) {
				String procInstId = rptVO.getProcInstId();
				String actHistoryId = rptVO.getActHistoryId();
				String actEndTime = rptVO.getActEndTime();
				if (StringUtils.isNotEmpty(procInstId) && StringUtils.isNotEmpty(actHistoryId)
						&& StringUtils.isNotEmpty(actEndTime)) {
					String historySql = "SELECT text_ FROM ACT_HI_DETAIL where proc_inst_id_='" + procInstId
							+ "' AND ACT_INST_ID_='" + actHistoryId + "' and NAME_='_TASK_ACTION'";
					Map map = taskInfoMapper.queryCompanyWhetherReport(historySql);
					if (ObjectUtils.notEqual(map, null)) {
						rptVO.setActName(String.valueOf(map.get("TEXT_")));
					}
				}
			}
		}
		return list;
	}

	@Override
    public List<RptListVO> findAllRptInfoShangJiJiTuan(RptListFilterVO rptListFilterVO) throws Exception {
        Map taskInfo = getTaskInfoById(rptListFilterVO.getRptId());
        if(ObjectUtils.equals(taskInfo,null)){
            log.info(">>>>>>>>>>>>>>>>【指定机构指定报表上报信息】报表信息查询不到："+rptListFilterVO.toString()+"<<<<<<<<<<<<<<<<<<");
            throw new Exception("报表信息查询不到！！");
        }
        
        Object object = taskInfo.get("xxb_tablename");
        
        String xxbTableName = String.valueOf(object);
        String unitCode = rptListFilterVO.getUnitCode();
        String sql =
                " SELECT T.BBQ_,'"+rptListFilterVO.getRptId()+"' AS RPT_ID,T.USERID_,T.USERNAME_,T.TAG_,T.SUBMIT_TIME,T.PROC_INST_ID,T.ID_,T.ACT_NAME_,T.TASK_ID,T.ACT_ID,T.END_TIME_ ,IFNULL(T.ASSIGNEE,T.CANDIDATE) as ASSIGNEE FROM (" +
                        " SELECT " +
                        " Z.BBQ_,Z.USERID_,Z.USERNAME_,Z.TAG_, DATE_FORMAT(Z.SUBMIT_TIME, '%Y-%m-%d %H:%i:%s') AS SUBMIT_TIME,Z.PROC_INST_ID," +
                        " Z.ID_,Z.END_TIME_,Z.ACT_NAME_," +
                        " Z.TASK_ID,Z.ACT_ID,Z.ASSIGNEE,Z.CANDIDATE,RN " +
                        
                        "FROM(SELECT H.BBQ_,H.USERID_,H.USERNAME_,H.TAG_,H.SUBMIT_TIME,H.PROC_INST_ID,"
                        + "H.ID_,H.END_TIME_,H.ACT_NAME_,H.TASK_ID,H.ACT_ID,H.ASSIGNEE,H.CANDIDATE,if(@BBQ_=H.BBQ_,@rank:=@rank+1,@rank:=1) as RN ,@BBQ_:=H.BBQ_  FROM (SELECT X.BBQ_,X.USERID_,X.USERNAME_,X.TAG_,X.SUBMITDATE_ AS SUBMIT_TIME,X.APPROVE_INSTANCE AS PROC_INST_ID,"
                        + "A.ID_,A.END_TIME_,A.ACT_NAME_, W.TASK_ID,W.ACT_ID,W.ASSIGNEE,W.CANDIDATE FROM "+xxbTableName+" X LEFT JOIN ACT_HI_ACTINST A ON A.PROC_INST_ID_=X.APPROVE_INSTANCE AND A.ACT_type_='userTask'"
                        		+ "LEFT JOIN WAIT_TASKLIST W ON W.PROC_INST_ID=X.APPROVE_INSTANCE WHERE X.USERID_  in ( select o.orgid_ from es10_org o where o.upid1_='"+rptListFilterVO.getUnitCodeJt()+"'  or  o.upid2_= '"+rptListFilterVO.getUnitCodeJt()+"' or o.upid3_='"+rptListFilterVO.getUnitCodeJt()+"' )  AND X.BTYPE_='0' ORDER BY X.BBQ_,A.START_TIME_ DESC ) H,(select  @BBQ_:= null ,@rank:=0) R)Z)"
					/*	
						 * " FROM (X.BBQ_,X.USERID_,X.USERNAME_,X.TAG_,X.SUBMITDATE_AS SUBMIT_TIME,X.APPROVE_INSTANCE AS PROC_INST_ID,) IF(@BBQTEM=TEM.BBQ,@rank :=@rank + 1 ,@rank := 1) AS RN ,@BBQTEM := TEM.BBQ  FROM(SELECT X1.BBQ_ ,A1.START_TIME FROM "
						 * +xxbTableName+" X1 LEFT JOIN ACT_HI_ACTINST A1 ON A1.PROC_INST_ID_=X1.APPROVE_INSTANCE AND A1.ACT_type_='userTask'"
						 * +
						 * " LEFT JOIN WAIT_TASKLIST W1 ON W1.PROC_INST_ID=X1.APPROVE_INSTANCE  ORDER BY X1.BBQ_ ,A1.START_TIME DESC ) TEM ,("
						 * + "			SELECT @rownum := 0, @grade := NULL ,@pjan := NULL ,@rank := 0"
						 * + "		) Z"
						 
						 * " ROW_NUMBER() OVER(PARTITION BY X.BBQ_ ORDER BY A.START_TIME_ DESC) AS RN"
						  +
                        " FROM "+xxbTableName+" X" +
                        " LEFT JOIN ACT_HI_ACTINST A ON A.PROC_INST_ID_=X.APPROVE_INSTANCE AND A.ACT_type_='userTask'" +
                        " LEFT JOIN WAIT_TASKLIST W ON W.PROC_INST_ID=X.APPROVE_INSTANCE WHERE X.USERID_  in ( select o.orgid_ from es10_org o where o.upid1_='"+rptListFilterVO.getUnitCodeJt()+"'  or  o.upid2_= '"+rptListFilterVO.getUnitCodeJt()+"' or o.upid3_='"+rptListFilterVO.getUnitCodeJt()+"' )  AND X.BTYPE_='0') " +*/
                        +"T WHERE T.RN=1 ";
                    if(StringUtils.isNotEmpty(rptListFilterVO.getUnitCode())){
                      sql+=" AND T.USERID_='"+rptListFilterVO.getUnitCode()+"'";
                    }
        sql+=" ORDER BY T.BBQ_ DESC";
        
        System.out.println("sql111----"+sql);
        List<RptListVO> list= taskInfoMapper.findAllRptInfo(sql);
        if(list.size()>GeneralConstant.NO_RESULT){
            for(RptListVO rptVO:list){
                String procInstId = rptVO.getProcInstId();
                String actHistoryId = rptVO.getActHistoryId();
                String actEndTime = rptVO.getActEndTime();
                if(StringUtils.isNotEmpty(procInstId)&&StringUtils.isNotEmpty(actHistoryId)&&StringUtils.isNotEmpty(actEndTime)){
                    String historySql = "SELECT text_ FROM ACT_HI_DETAIL where proc_inst_id_='"+procInstId+"' AND ACT_INST_ID_='"+actHistoryId+"' and NAME_='_TASK_ACTION'";
                    Map  map =taskInfoMapper.queryCompanyWhetherReport(historySql);
                    if(ObjectUtils.notEqual(map,null)){
                        rptVO.setActName(String.valueOf( map.get("TEXT_")));
                    }
                }
            }
        }
        return list;
    }

	/**
	 * 指定报表指定报表期上报信息
	 * 
	 * @param rptListFilterVO
	 * @return List<RptListVO>
	 * @author liyb
	 * @date 2019-04-30 14:45:33
	 * @version v1.0
	 */
	@Override
	public List<RptListVO> findRptInfoByBbqAndRptId(RptListFilterVO rptListFilterVO) throws Exception {
		Map taskInfo = getTaskInfoById(rptListFilterVO.getRptId());
		if (ObjectUtils.equals(taskInfo, null)) {
			log.info(">>>>>>>>>>>>>>>>【指定机构指定报表上报信息】报表信息查询不到：" + rptListFilterVO.toString() + "<<<<<<<<<<<<<<<<<<");
			throw new Exception("报表信息查询不到！！");
		}
		String xxbTableName = String.valueOf(taskInfo.get("XXB_TABLENAME"));
		String unitCode = rptListFilterVO.getUnitCode();
		String sql = " SELECT T.BBQ_,'" + rptListFilterVO.getRptId()
				+ "' AS RPT_ID,T.USERID_,T.USERNAME_,T.TAG_,T.SUBMIT_TIME,T.PROC_INST_ID,T.ID_,T.ACT_NAME_,T.TASK_ID,T.ACT_ID,T.END_TIME_ FROM ("
				+ " SELECT "
				+ " Z.BBQ_,Z.USERID_,Z.USERNAME_,Z.TAG_,DATE_FORMAT(Z.SUBMIT_TIME, '%Y-%m-%d %H:%i:%s') AS SUBMIT_TIME,Z.APPROVE_INSTANCE AS PROC_INST_ID,"
				+ " Z.ID_,Z.END_TIME_,Z.ACT_NAME_," + " Z.TASK_ID,Z.ACT_ID,"
				+ "RN" + " FROM (SELECT H.BBQ_,H.USERID_,H.USERNAME_,H.TAG_,H.SUBMITDATE_ AS SUBMIT_TIME,H.APPROVE_INSTANCE AS PROC_INST_ID,"
						+ "H.ID_,H.END_TIME_,H.ACT_NAME_," + " H.TASK_ID,H.ACT_ID,if(@USERID=H.USERID,@rank:=@rank+1,@rank:=1)),@USERID:=H.USERID "
								+ "FROM(SELECT X.BBQ_,X.USERID_,X.USERNAME_,X.TAG_,TO_CHAR(X.SUBMITDATE_,'YYYY-MM-DD') AS SUBMIT_TIME,X.APPROVE_INSTANCE AS PROC_INST_ID,A.ID_,A.END_TIME_,A.ACT_NAME_," + " W.TASK_ID,W.ACT_ID FROM("
										+ xxbTableName + " X LEFT JOIN ACT_HI_ACTINST A ON A.PROC_INST_ID_=X.APPROVE_INSTANCE AND A.ACT_type_='userTask'"
												+ "LEFT JOIN WAIT_TASKLIST W ON W.PROC_INST_ID=X.APPROVE_INSTANCE AND (W.ASSIGNEE='"
												+ rptListFilterVO.getUserAccount()+"' OR W.CANDIDATE='" + rptListFilterVO.getUserAccount() + "') WHERE X.BBQ_='" + rptListFilterVO.getBbq() + "ORDER BY X.USERID,A.START_TIME_ DESC')H,(select  @USERID:= null ,@rank:=0) R )Z)"
								
				/*
				 * + xxbTableName + " X" +
				 * " LEFT JOIN ACT_HI_ACTINST A ON A.PROC_INST_ID_=X.APPROVE_INSTANCE AND A.ACT_type_='userTask'"
				 * +
				 * " LEFT JOIN WAIT_TASKLIST W ON W.PROC_INST_ID=X.APPROVE_INSTANCE AND (W.ASSIGNEE='"
				 * + rptListFilterVO.getUserAccount() + "' OR W.CANDIDATE='" +
				 * rptListFilterVO.getUserAccount() + "')" + " WHERE X.BBQ_='" +
				 * rptListFilterVO.getBbq() + "') "
				 */
						+ "T WHERE T.RN=1" + " ORDER BY T.BBQ_ DESC";
		List<RptListVO> list = taskInfoMapper.findAllRptInfo(sql);
		if (list.size() > GeneralConstant.NO_RESULT) {
			for (RptListVO rptVO : list) {
				String procInstId = rptVO.getProcInstId();
				String actHistoryId = rptVO.getActHistoryId();
				String actEndTime = rptVO.getActEndTime();
				if (StringUtils.isNotEmpty(procInstId) && StringUtils.isNotEmpty(actHistoryId)
						&& StringUtils.isNotEmpty(actEndTime)) {
					String historySql = "SELECT text_ FROM ACT_HI_DETAIL where proc_inst_id_='" + procInstId
							+ "' AND ACT_INST_ID_='" + actHistoryId + "' and NAME_='_TASK_ACTION'";
					Map map = taskInfoMapper.queryCompanyWhetherReport(historySql);
					if (ObjectUtils.notEqual(map, null)) {
						rptVO.setActName(String.valueOf(map.get("TEXT_")));
					}
				}
			}
		}
		return list;
	}

	/**
	 * 根据报表期、报表真实代码、机构代码查询对应报表填报或办理链接
	 * 
	 * @param baseFilterVO
	 * @return String
	 * @author liyb
	 * @date 2019-05-07 13:46:36
	 * @version v1.0
	 */
	@Override
	public String findUrlByCondition(BaseFilterVO baseFilterVO, String pwd) throws Exception {
		String rptId = baseFilterVO.getRptId();
		Map taskInfo = getTaskInfoById(rptId);
		if (ObjectUtils.equals(taskInfo, null)) {
			log.info(">>>>>>>>>>>>>>>>【指定机构指定报表上报信息】报表信息查询不到：" + baseFilterVO.toString() + "<<<<<<<<<<<<<<<<<<");
			throw new Exception("报表信息查询不到！！");
		}
		String xxbTableName = String.valueOf(taskInfo.get("XXB_TABLENAME"));
		String unitCode = baseFilterVO.getUnitCode();
		String bbq = baseFilterVO.getBbq();
		String account = CurrentUtil.getUserAccount();
		String sql = "SELECT x.tag_,x.approve_instance,w.TASK_ID,w.ACT_ID from " + xxbTableName + " x  "
				+ "left join wait_tasklist w on w.PROC_INST_ID=x.approve_instance and (w.CANDIDATE='" + account
				+ "' or w.ASSIGNEE='" + account + "')" + "where x.btype_='0' and x.bbq_='" + bbq + "' and x.userid_='"
				+ unitCode + "'";
		List<Map> list = taskInfoMapper.queryBbqFromXxbByUnitCode(sql);
		if (list.size() > GeneralConstant.NO_RESULT) {
			Map result = list.get(GeneralConstant.NO_RESULT);
			BigDecimal tag = (BigDecimal) result.get("TAG_");
			String procInstId = (String) result.get("APPROVE_INSTANCE");
			String taskId = (String) result.get("TASK_ID");
			String actId = (String) result.get("ACT_ID");
			if (StringUtils.isEmpty(taskId)) {
				if (tag.intValue() == GeneralConstant.UPDATE_RESULT) {
					String irptSso = GeneralConstant.PROJECT_NAME_IRPT + "/oemlogin.do?id=" + account + "&pwd={" + pwd
							+ "}&target=task&task=" + rptId + "&bbq=" + bbq + "&forcelogin=true&&btype=0";
					return irptSso;
				}
			} else {
				String irSso = GeneralConstant.PROJECT_NAME_IRPT
						+ "/welcome.do?hideframe=true&hidehead=true#navigator:/esmain/workflow/workflowmgr.do?command=todotasks&taskid="
						+ actId + "&slid=" + procInstId + "&activitiId=" + taskId
						+ "&workflowShowSubmitVisible=false&rshid=workflow-dotask";
				return irSso;
			}
		} else {
			String irptSso = GeneralConstant.PROJECT_NAME_IRPT + "/oemlogin.do?id=" + account + "&pwd={" + pwd
					+ "}&target=task&task=" + rptId + "&bbq=" + bbq + "&forcelogin=true&&btype=0";
			return irptSso;
		}
		return null;
	}

	/**
	 * 根据报表ID获取报表信息
	 * 
	 * @param taskId
	 * @return Map
	 * @author liyb
	 * @date 2018-12-27 14:46:58
	 * @version v1.0
	 */
	public Map getTaskInfoById(String taskId) {
		return taskInfoMapper.getTaskInfoById(taskId);
	}

	/**
	 * 拼接查询条件
	 * 
	 * @param taskFilterVO
	 * @return String
	 */
	public String appendCondition(TaskFilterVO taskFilterVO, String sql) {
		if (StringUtils.isNotEmpty(taskFilterVO.getAreaCode())) {
			String areaCode = taskFilterVO.getAreaCode();
			if (areaCode.endsWith("0000")) {
				sql += "";
			} else if (areaCode.endsWith("00")) {
				sql += " and X.upid_ like '" + areaCode.substring(0, 4) + "%' ";
			} else {
				if (areaCode.length() > 6) {
					sql += " and X.upid_ = '" + areaCode.substring(0, 6) + "' ";
				} else {
					sql += " and X.upid_ = '" + areaCode + "' ";
				}
			}
		}
		if (StringUtils.isNotEmpty(taskFilterVO.getBbq())) {
			sql += " and X.bbq_ = '" + taskFilterVO.getBbq() + "' ";
		}
		if (StringUtils.isNotEmpty(taskFilterVO.getStartBbq())) {
			String startBbq = taskFilterVO.getStartBbq();
			if (startBbq.endsWith("----")) {
				sql += " and substr(X.bbq_,1,4) >= '" + startBbq.substring(0, 4) + "' ";
			} else if (startBbq.endsWith("--")) {
				sql += " and substr(X.bbq_,1,6) >= '" + startBbq.substring(0, 6) + "' ";
			} else {
				sql += " and bbq_ >= '" + startBbq + "' ";
			}
		}
		if (StringUtils.isNotEmpty(taskFilterVO.getEndBbq())) {
			String endBbq = taskFilterVO.getEndBbq();
			if (endBbq.endsWith("----")) {
				sql += " and substr(X.bbq_,1,4) <= '" + endBbq.substring(0, 4) + "' ";
			} else if (endBbq.endsWith("--")) {
				sql += " and substr(X.bbq_,1,6) <= '" + endBbq.substring(0, 6) + "' ";
			} else {
				sql += " and X.bbq_ <= '" + endBbq + "' ";
			}
		}
		return sql;
	}
}
